@@ -53,13 +53,9 @@ Dialog_Connection::Dialog_Connection(BaseObjectType* cobject, const Glib::RefPtr
   builder->get_widget("connection_note", m_label_note);
 }
 
-Dialog_Connection::~Dialog_Connection()
-{
-}
-
 std::shared_ptr<SharedConnection> Dialog_Connection::connect_to_server_with_connection_settings() const
 {
-  //std::cout << "debug: Dialog_Connection::connect_to_server_with_connection_settings()" << std::endl;
+  //std::cout << "debug: Dialog_Connection::connect_to_server_with_connection_settings()\n";
 
   //TODO: BusyCursor busy_cursor(get_app_window());
 
@@ -82,7 +78,7 @@ std::shared_ptr<SharedConnection> Dialog_Connection::connect_to_server_with_conn
   if(document->get_hosting_mode() == Document::HostingMode::POSTGRES_CENTRAL)
   {
     auto backend = connection_pool->get_backend();
-    auto central = dynamic_cast<ConnectionPoolBackends::PostgresCentralHosted*>(backend);
+    auto central = std::dynamic_pointer_cast<ConnectionPoolBackends::PostgresCentralHosted>(backend);
     g_assert(central);
 
     central->set_host(m_entry_host->get_text());
@@ -99,12 +95,12 @@ std::shared_ptr<SharedConnection> Dialog_Connection::connect_to_server_with_conn
   //Remember the port, 
   //to make opening faster next time,
   //and so we can tell connecting clients (using browse network) what port to use:
-  auto unconst = const_cast<Document*>(document);
+  auto unconst = std::const_pointer_cast<Document>(document);
 
   if(document->get_hosting_mode() == Document::HostingMode::POSTGRES_CENTRAL)
   {
     auto backend = connection_pool->get_backend();
-    auto central = dynamic_cast<ConnectionPoolBackends::PostgresCentralHosted*>(backend);
+    auto central = std::dynamic_pointer_cast<ConnectionPoolBackends::PostgresCentralHosted>(backend);
     g_assert(central);
 
     unconst->set_connection_port(central->get_port() );
@@ -117,7 +113,7 @@ std::shared_ptr<SharedConnection> Dialog_Connection::connect_to_server_with_conn
   else if(document->get_hosting_mode() == Document::HostingMode::POSTGRES_SELF)
   {
     auto backend = connection_pool->get_backend();
-    auto self = dynamic_cast<ConnectionPoolBackends::PostgresSelfHosted*>(backend);
+    auto self = std::dynamic_pointer_cast<ConnectionPoolBackends::PostgresSelfHosted>(backend);
     g_assert(self);
 
     unconst->set_connection_port(self->get_port() );
@@ -172,7 +168,7 @@ void Dialog_Connection::load_from_document()
     set_database_name(document->get_connection_database());
   }
   else
-    std::cerr << G_STRFUNC << ": no document" << std::endl;
+    std::cerr << G_STRFUNC << ": no document\n";
 
 }
 
