@@ -26,6 +26,7 @@
 #include <glom/import_csv/dialog_import_csv.h>
 #include <glom/import_csv/dialog_import_csv_progress.h>
 #include <libglom/appstate.h>
+#include <libglom/db_utils_export.h>
 
 #include <libglom/connectionpool.h>
 
@@ -64,6 +65,7 @@
 #include <glom/filechooser_export.h>
 #include <libglom/privs.h>
 #include <libglom/db_utils.h>
+#include <libglom/db_utils_export.h>
 #include <sstream> //For stringstream.
 #include <fstream>
 #include <glibmm/i18n.h>
@@ -537,7 +539,7 @@ void Frame_Glom::on_menu_file_export()
   if(!document)
     return;
 
-  Document::type_list_layout_groups mapGroupSequence = document->get_data_layout_groups_plus_new_fields("details", m_table_name, get_active_layout_platform(document));
+  auto mapGroupSequence = document->get_data_layout_groups_plus_new_fields("details", m_table_name, get_active_layout_platform(document));
 
   auto pWindowApp = get_app_window();
   g_assert(pWindowApp);
@@ -581,147 +583,7 @@ void Frame_Glom::on_menu_file_export()
     return;
   }
 
-  export_data_to_stream(the_stream, found_set, mapGroupSequence);
-}
-
-//TODO: Reduce copy/pasting in these export_data_to_*() methods:
-void Frame_Glom::export_data_to_vector(Document::type_example_rows& the_vector, const FoundSet& found_set, const Document::type_list_layout_groups& sequence)
-{
-  type_vecConstLayoutFields fieldsSequence = get_table_fields_to_show_for_sequence(found_set.m_table_name, sequence);
-
-  if(fieldsSequence.empty())
-  {
-    std::cerr << G_STRFUNC << ": No fields in sequence.\n";
-    return;
-  }
-
-  auto query = Utils::build_sql_select_with_where_clause(found_set.m_table_name, fieldsSequence, found_set.m_where_clause, found_set.m_extra_join, found_set.m_sort_clause);
-
-  //TODO: Lock the database (prevent changes) during export.
-  auto result = DbUtils::query_execute_select(query);
-
-  guint rows_count = 0;
-  if(result)
-    rows_count = result->get_n_rows();
-
-  if(rows_count)
-  {
-    const guint columns_count = result->get_n_columns();
-
-    for(guint row_index = 0; row_index < rows_count; ++row_index)
-    {
-        Document::type_row_data row_data;
-
-        for(guint col_index = 0; col_index < columns_count; ++col_index)
-        {
-          const auto value = result->get_value_at(col_index, row_index);
-
-          auto layout_item = fieldsSequence[col_index];
-          //if(layout_item->m_field.get_glom_type() != Field::glom_field_type::IMAGE) //This is too much data.
-          //{
-
-            //Output data in canonical SQL format, ignoring the user's locale, and ignoring the layout formatting:
-            row_data.emplace_back(value);  //TODO_Performance: reserve the size.
-
-            //if(layout_item->m_field.get_glom_type() == Field::glom_field_type::IMAGE) //This is too much data.
-            //{
-             //std::cout << "  field name=" << layout_item->get_name() << ", value=" << layout_item->m_field.sql(value) << std::endl;
-            //}
-        }
-
-        //std::cout << " row_string=" << row_string << std::endl;
-        the_vector.emplace_back(row_data); //TODO_Performance: Reserve the size.
-    }
-  }
-}
-
-void Frame_Glom::export_data_to_stream(std::ostream& the_stream, const FoundSet& found_set, const Document::type_list_layout_groups& sequence)
-{
-  type_vecConstLayoutFields fieldsSequence = get_table_fields_to_show_for_sequence(found_set.m_table_name, sequence);
-
-  if(fieldsSequence.empty())
-  {
-    std::cerr << G_STRFUNC << ": No fields in sequence.\n";
-    return;
-  }
-
-  auto query = Utils::build_sql_select_with_where_clause(found_set.m_table_name, fieldsSequence, found_set.m_where_clause, found_set.m_extra_join, found_set.m_sort_clause);
-
-  //TODO: Lock the database (prevent changes) during export.
-  Glib::RefPtr<const Gnome::Gda::DataModel> result = DbUtils::query_execute_select(query);
-
-  guint rows_count = 0;
-  if(result)
-    rows_count = result->get_n_rows();
-
-  if(rows_count)
-  {
-    const guint columns_count = result->get_n_columns();
-
-    for(guint row_index = 0; row_index < rows_count; ++row_index)
-    {
-        std::string row_string;
-
-        for(guint col_index = 0; col_index < columns_count; ++col_index)
-        {
-          const auto value = result->get_value_at(col_index, row_index);
-
-          auto layout_item = fieldsSequence[col_index];
-          //if(layout_item->m_field.get_glom_type() != Field::glom_field_type::IMAGE) //This is too much data.
-          //{
-            if(!row_string.empty())
-              row_string += ",";
-
-            //Output data in canonical SQL format, ignoring the user's locale, and ignoring the layout formatting:
-            auto field = layout_item->get_full_field_details();
-            if(!field)
-            {
-              std::cerr << G_STRFUNC << ": A field was null.\n";
-              return;
-            }
-
-            const auto field_text = field->to_file_format(value);
-
-            if(layout_item->get_glom_type() == Field::glom_field_type::IMAGE) //This is too much data.
-            {
-              // Some extra debug checks,
-              // though we believe that all these problems are now fixed in File::to_file_format():
-
-              const char* newline_to_find = "\r\n";
-              size_t pos = field_text.find_first_of(newline_to_find);
-              if(pos != std::string::npos)
-              {
-                std::cerr << G_STRFUNC << ": export: binary data field text contains an unexpected newline: " << field_text << std::endl;
-                continue;
-              }
-
-              const char* quote_to_find = "\"";
-              pos = field_text.find_first_of(quote_to_find);
-              if(pos != std::string::npos)
-              {
-                std::cerr << G_STRFUNC << ": export: binary data field text contains an unexpected quote: " << field_text << std::endl;
-                continue;
-              }
-            }
-
-            if(layout_item->get_glom_type() == Field::glom_field_type::TEXT)
-            {
-              //The CSV RFC says text may be quoted and should be if it has newlines:
-              //TODO: Escape the text?
-              row_string += ("\"" + field_text + "\"");
-            }
-            else
-              row_string += field_text;
-
-
-            //std::cout << "  field name=" << layout_item->get_name() << ", value=" << layout_item->m_field.sql(value) << std::endl;
-          //}
-        }
-
-        //std::cout << " row_string=" << row_string << std::endl;
-        the_stream << row_string << std::endl;
-    }
-  }
+  DbUtils::export_data_to_stream(document, the_stream, found_set, mapGroupSequence);
 }
 
 void Frame_Glom::on_menu_file_import()
