@@ -125,22 +125,22 @@ GlomCreateOptionGroup::GlomCreateOptionGroup()
 
 static void on_initialize_progress()
 {
-  std::cout << "Database initialization progress" << std::endl;
+  std::cout << "Database initialization progress\n";
 }
 
 static void on_startup_progress()
 {
-  std::cout << "Database startup progress" << std::endl;
+  std::cout << "Database startup progress\n";
 }
 
 static void on_recreate_progress()
 {
-  std::cout << "Database re-creation progress" << std::endl;
+  std::cout << "Database re-creation progress\n";
 }
 
 static void on_cleanup_progress()
 {
-  std::cout << "Database cleanup progress" << std::endl;
+  std::cout << "Database cleanup progress\n";
 }
 
 /** Delete a directory, if it exists, and its contents.
@@ -153,12 +153,12 @@ static bool delete_directory(const Glib::RefPtr<Gio::File>& directory)
 
   //(Recursively) Delete any child files and directories,
   //so we can delete this directory.
-  Glib::RefPtr<Gio::FileEnumerator> enumerator = directory->enumerate_children();
+  auto enumerator = directory->enumerate_children();
 
-  Glib::RefPtr<Gio::FileInfo> info = enumerator->next_file();
+  auto info = enumerator->next_file();
   while(info)
   {
-    Glib::RefPtr<Gio::File> child = directory->get_child(info->get_name());
+    auto child = directory->get_child(info->get_name());
     bool removed_child = false;
     if(child->query_file_type() == Gio::FILE_TYPE_DIRECTORY)
       removed_child = delete_directory(child);
@@ -186,7 +186,7 @@ static bool delete_directory(const std::string& uri)
   if(uri.empty())
     return true;
 
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
+  auto file = Gio::File::create_for_uri(uri);
   return delete_directory(file);
 }
 
@@ -240,7 +240,7 @@ int main(int argc, char* argv[])
     //https://bugzilla.gnome.org/show_bug.cgi?id=619445
     //This should tell us what the problem is:
     std::cerr << G_STRFUNC << ": exception from std::locale::global(std::locale(\"\")): " << ex.what() << std::endl;
-    std::cerr << G_STRFUNC << ":   This can happen if the locale is not properly installed or configured." << std::endl;
+    std::cerr << G_STRFUNC << ":   This can happen if the locale is not properly installed or configured.\n";
   }
 
   
@@ -287,7 +287,7 @@ int main(int argc, char* argv[])
   if(!input_uri.empty())
   {
     //Get a URI (file://something) from the filepath:
-    Glib::RefPtr<Gio::File> file = Gio::File::create_for_commandline_arg(input_uri);
+    auto file = Gio::File::create_for_commandline_arg(input_uri);
 
     if(!file->query_exists())
     {
@@ -312,7 +312,7 @@ int main(int argc, char* argv[])
   
   if(input_uri.empty())
   {
-    std::cerr << G_STRFUNC << ": Please specify a glom example file." << std::endl;
+    std::cerr << G_STRFUNC << ": Please specify a glom example file.\n";
     std::cerr << std::endl << context.get_help() << std::endl;
     return EXIT_FAILURE;
   }
@@ -321,14 +321,14 @@ int main(int argc, char* argv[])
   //Check the output directory path: 
   if(group.m_arg_filepath_dir_output.empty())
   {
-    std::cerr << G_STRFUNC << ": Please specify an output directory path." << std::endl;
+    std::cerr << G_STRFUNC << ": Please specify an output directory path.\n";
     std::cerr << std::endl << context.get_help() << std::endl;
     return EXIT_FAILURE;
   }
   else
   {
     //Get a URI (file://something) from the filepath:
-    Glib::RefPtr<Gio::File> file = Gio::File::create_for_commandline_arg(group.m_arg_filepath_dir_output);
+    auto file = Gio::File::create_for_commandline_arg(group.m_arg_filepath_dir_output);
 
     if(!file->query_exists())
     {
@@ -351,17 +351,17 @@ int main(int argc, char* argv[])
   //Check the output name path: 
   if(group.m_arg_filepath_name_output.empty())
   {
-    std::cerr << G_STRFUNC << ": Please specify an output name." << std::endl;
+    std::cerr << G_STRFUNC << ": Please specify an output name.\n";
     std::cerr << std::endl << context.get_help() << std::endl;
     return EXIT_FAILURE;
   }
 
 
   // Load the document:
-  Glom::Document document;
-  document.set_file_uri(input_uri);
+  auto document = std::make_shared<Glom::Document>();
+  document->set_file_uri(input_uri);
   int failure_code = 0;
-  const auto test = document.load(failure_code);
+  const auto test = document->load(failure_code);
   //std::cout << "Document load result=" << test << std::endl;
 
   if(!test)
@@ -370,7 +370,7 @@ int main(int argc, char* argv[])
     return EXIT_FAILURE;
   }
 
-  g_assert(document.get_is_example_file());;
+  g_assert(document->get_is_example_file());;
 
   auto connection_pool = Glom::ConnectionPool::get_instance();
 
@@ -389,7 +389,7 @@ int main(int argc, char* argv[])
     if(uri.empty())
       return EXIT_FAILURE;
         
-    Glib::RefPtr<Gio::File> file = Gio::File::create_for_commandline_arg(uri);
+    auto file = Gio::File::create_for_commandline_arg(uri);
     if(file->query_exists())
     {
       std::cerr << G_STRFUNC << ": The output path already exists: " << filepath_dir << std::endl;
@@ -402,20 +402,20 @@ int main(int argc, char* argv[])
   if(file_uri.empty())
     return EXIT_FAILURE;
 
-  document.set_file_uri(file_uri);
+  document->set_file_uri(file_uri);
 
   const auto self_hosting = group.m_arg_server_hostname.empty();
   if(self_hosting)
   {
-    std::cout << "Using self-hosting instead of a central database server." << std::endl;
+    std::cout << "Using self-hosting instead of a central database server.\n";
 
 #if GLOM_ENABLE_MYSQL
     if(group.m_arg_use_mysql)
-      document.set_hosting_mode(Glom::Document::HostingMode::MYSQL_SELF);
+      document->set_hosting_mode(Glom::Document::HostingMode::MYSQL_SELF);
     else
 #endif //GLOM_ENABLE_MYSQL
     {
-      document.set_hosting_mode(Glom::Document::HostingMode::POSTGRES_SELF);
+      document->set_hosting_mode(Glom::Document::HostingMode::POSTGRES_SELF);
     }
   }
   else
@@ -424,27 +424,27 @@ int main(int argc, char* argv[])
 
 #if GLOM_ENABLE_MYSQL
     if(group.m_arg_use_mysql)
-      document.set_hosting_mode(Glom::Document::HostingMode::MYSQL_CENTRAL);
+      document->set_hosting_mode(Glom::Document::HostingMode::MYSQL_CENTRAL);
     else
 #endif //GLOM_ENABLE_MYSQL
     {
-      document.set_hosting_mode(Glom::Document::HostingMode::POSTGRES_CENTRAL);
+      document->set_hosting_mode(Glom::Document::HostingMode::POSTGRES_CENTRAL);
     }
   }
    
-  document.set_is_example_file(false);
-  document.set_network_shared(false);
-  const auto saved = document.save();
+  document->set_is_example_file(false);
+  document->set_network_shared(false);
+  const auto saved = document->save();
   g_assert(saved);
 
   //Specify the backend and backend-specific details to be used by the connectionpool.
-  connection_pool->setup_from_document(&document);
+  connection_pool->setup_from_document(document);
 
   //We must specify a default username and password:
   if(self_hosting)
   {
     Glib::ustring password;
-    const auto user = Glom::Privs::get_default_developer_user_name(password, document.get_hosting_mode());
+    const auto user = Glom::Privs::get_default_developer_user_name(password, document->get_hosting_mode());
     connection_pool->set_user(user);
     connection_pool->set_password(password);
   }
@@ -459,7 +459,7 @@ int main(int argc, char* argv[])
 
 #ifdef G_OS_WIN32
     const char* password = "";
-    std::cerr << G_STRFUNC << ": Error: getpass() is not implemented in the Windows build. The connection will fail." << std::endl;
+    std::cerr << G_STRFUNC << ": Error: getpass() is not implemented in the Windows build. The connection will fail.\n";
 #else
     const auto password = ::getpass(prompt.c_str());
 #endif
@@ -469,8 +469,7 @@ int main(int argc, char* argv[])
     connection_pool->set_password(password); //TODO: Take this from stdin instead.
     
     auto backend = connection_pool->get_backend();
-    auto central = 
-      dynamic_cast<Glom::ConnectionPoolBackends::PostgresCentralHosted*>(backend);
+    auto central = std::dynamic_pointer_cast<Glom::ConnectionPoolBackends::PostgresCentralHosted>(backend);
     g_assert(central);
 
     central->set_host(group.m_arg_server_hostname);
@@ -487,13 +486,13 @@ int main(int argc, char* argv[])
     }
     
     const Glib::ustring database_name =
-      Glom::DbUtils::get_unused_database_name(document.get_connection_database());
+      Glom::DbUtils::get_unused_database_name(document->get_connection_database());
     if(database_name.empty())
     {
-      std::cerr << G_STRFUNC << ": Could not find an unused database name" << std::endl;
+      std::cerr << G_STRFUNC << ": Could not find an unused database name\n";
     }
     else
-      document.set_connection_database(database_name);
+      document->set_connection_database(database_name);
   }
         
   //Startup. For instance, create the self-hosting files if necessary:
@@ -511,7 +510,7 @@ int main(int argc, char* argv[])
   }
   g_assert(started == Glom::ConnectionPool::Backend::StartupErrors::NONE);
 
-  const auto recreated = Glom::DbUtils::recreate_database_from_document(&document, &on_recreate_progress);
+  const auto recreated = Glom::DbUtils::recreate_database_from_document(document, &on_recreate_progress);
   if(!recreated)
     cleanup();
   g_assert(recreated);
@@ -520,11 +519,11 @@ int main(int argc, char* argv[])
   std::string output_path_used;
   try
   {
-    output_path_used = Glib::filename_from_uri(document.get_file_uri());
+    output_path_used = Glib::filename_from_uri(document->get_file_uri());
   }
   catch(const Glib::ConvertError& ex)
   {
-    std::cerr << G_STRFUNC << ": Could not convert URI to output filepath: " << document.get_file_uri() << std::endl;
+    std::cerr << G_STRFUNC << ": Could not convert URI to output filepath: " << document->get_file_uri() << std::endl;
   }
    
   std::cout << "Glom file created at: " << output_path_used << std::endl;
