@@ -82,7 +82,7 @@ int main(int argc, char* argv[])
     //https://bugzilla.gnome.org/show_bug.cgi?id=619445
     //This should tell us what the problem is:
     std::cerr << G_STRFUNC << ": exception from std::locale::global(std::locale(\"\")): " << ex.what() << std::endl;
-    std::cerr << G_STRFUNC << ":   This can happen if the locale is not properly installed or configured." << std::endl;
+    std::cerr << G_STRFUNC << ":   This can happen if the locale is not properly installed or configured.\n";
   }
 
   
@@ -134,7 +134,7 @@ int main(int argc, char* argv[])
   }
 
   //Get a URI (file://something) from the filepath:
-  Glib::RefPtr<Gio::File> file_input = Gio::File::create_for_commandline_arg(input_uri);
+  auto file_input = Gio::File::create_for_commandline_arg(input_uri);
 
   //Make sure it is really a URI:
   input_uri = file_input->get_uri();
@@ -165,7 +165,7 @@ int main(int argc, char* argv[])
   }
 
   //Get a URI (file://something) from the filepath:
-  Glib::RefPtr<Gio::File> file_output = Gio::File::create_for_commandline_arg(group.m_arg_filepath_po_input);
+  auto file_output = Gio::File::create_for_commandline_arg(group.m_arg_filepath_po_input);
 
   file_type = file_output->query_file_type();
   if(file_type != Gio::FILE_TYPE_DIRECTORY)
@@ -177,10 +177,10 @@ int main(int argc, char* argv[])
 
 
   // Load the document:
-  Glom::Document document;
-  document.set_file_uri(input_uri);
+  auto document = std::make_shared<Glom::Document>();
+  document->set_file_uri(input_uri);
   int failure_code = 0;
-  const auto test = document.load(failure_code);
+  const auto test = document->load(failure_code);
   //std::cout << "Document load result=" << test << std::endl;
 
   if(!test)
@@ -190,11 +190,11 @@ int main(int argc, char* argv[])
   }
 
   //Import all .po files from the directory:
-  Glib::RefPtr<Gio::FileEnumerator> enumerator = file_output->enumerate_children();
+  auto enumerator = file_output->enumerate_children();
   Glib::RefPtr<Gio::FileInfo> info;
   while( (info = enumerator->next_file()) )
   {
-    Glib::RefPtr<Gio::File> child = file_output->get_child(info->get_name());
+    auto child = file_output->get_child(info->get_name());
     if(child->query_file_type() == Gio::FILE_TYPE_DIRECTORY)
       continue;
 
@@ -205,16 +205,16 @@ int main(int argc, char* argv[])
     if(locale_id == basename)
       continue;
     
-    document.set_allow_autosave(false); //Prevent saving while we modify the document.
+    document->set_allow_autosave(false); //Prevent saving while we modify the document.
     const bool succeeded = 
-      Glom::import_translations_from_po_file(&document, child->get_uri(), locale_id);
+      Glom::import_translations_from_po_file(document, child->get_uri(), locale_id);
     if(!succeeded)
     {
       std::cerr << Glib::ustring::compose(_("Po file import failed for locale: %1"), locale_id) << std::endl;
       return EXIT_FAILURE;
     }
 
-    if(!document.save()) {
+    if(!document->save()) {
       std::cerr << Glib::ustring::compose(_("Po file import failed during document saving for locale: %1"), locale_id) << std::endl;
       return EXIT_FAILURE;
     }
