@@ -111,26 +111,24 @@ const Glib::ustring& CsvParser::get_data(guint row, guint col) const
 
   if(row >= m_rows.size())
   {
-    //std::cerr << G_STRFUNC << ": get_data(): row out of range." << std::endl;
+    //std::cerr << G_STRFUNC << ": get_data(): row out of range.\n";
     return empty_result;
   }
 
   const auto row_data = m_rows[row];
   if(col >= row_data.size())
   {
-    //std::cerr << G_STRFUNC << ": get_data(): col out of range." << std::endl;
+    //std::cerr << G_STRFUNC << ": get_data(): col out of range.\n";
     return empty_result;
   }
 
   return row_data[col];
 }
 
-const CsvParser::type_row_strings CsvParser::fetch_next_row()
+CsvParser::type_row_strings CsvParser::fetch_next_row()
 {
-  const type_row_strings empty;
-
-  g_return_val_if_fail(m_state == CsvParser::State::PARSING, empty);
-  g_return_val_if_fail(m_state == CsvParser::State::PARSED, empty);
+  g_return_val_if_fail(m_state == CsvParser::State::PARSING, fetch_next_row());
+  g_return_val_if_fail(m_state == CsvParser::State::PARSED, fetch_next_row());
 
   // We cannot fetch the next row, but since we are still parsing we might just have to parse a bit more!
   if(m_state == CsvParser::State::PARSING && m_row_index >= m_rows.size())
@@ -142,7 +140,7 @@ const CsvParser::type_row_strings CsvParser::fetch_next_row()
 
   if(m_state == CsvParser::State::PARSED && m_row_index >= m_rows.size())
   {
-    return empty;
+    return type_row_strings();
   }
 
   if(m_row_index < m_rows.size())
@@ -150,7 +148,7 @@ const CsvParser::type_row_strings CsvParser::fetch_next_row()
     return m_rows[m_row_index++];
   }
 
-  g_return_val_if_reached(empty);
+  return type_row_strings();
 }
 
 CsvParser::type_signal_file_read_error CsvParser::signal_file_read_error() const
@@ -352,12 +350,12 @@ bool CsvParser::on_idle_parse()
 
     if(pos == outbuf)
     {
-      //std::cout << "debug: not found. stopping" << std::endl;
+      //std::cout << "debug: not found. stopping\n";
       break;
     }
 
     char ch = *pos;
-    //std::cout << "debug: ch=START" << ch << "END" << std::endl;
+    //std::cout << "debug: ch=START" << ch << "END\n";
 
     if(ch == '\0')
     {
@@ -365,7 +363,7 @@ bool CsvParser::on_idle_parse()
       // contain null bytes this only occurs when converting, for example, a UTF-16
       // file from ISO-8859-1 to UTF-8 (note that the UTF-16 file is valid ISO-8859-1 -
       // it just contains lots of nullbytes). We therefore produce an error here.
-      //std::cerr << G_STRFUNC << ": on_idle_parse(): Encoding error" << std::endl;
+      //std::cerr << G_STRFUNC << ": on_idle_parse(): Encoding error\n";
       set_state(State::ENCODING_ERROR);
       signal_encoding_error().emit();
       return false;  //Stop calling the idle handler.
@@ -388,7 +386,7 @@ bool CsvParser::on_idle_parse()
         */
       }
       //else
-      //  std::cout << "Ignoring a newline in quotes." << std::endl;
+      //  std::cout << "Ignoring a newline in quotes.\n";
 
       prev = pos + 1;
       continue;
@@ -409,7 +407,7 @@ bool CsvParser::on_idle_parse()
 
       if(!m_current_line.empty())
       {
-        //std::cout << "debug: intermediate chunk" << std::endl;
+        //std::cout << "debug: intermediate chunk\n";
         do_line_scanned(m_current_line, m_line_number);
       }
 
@@ -439,7 +437,7 @@ bool CsvParser::on_idle_parse()
     // Handle last line, if nonempty
     if(!m_current_line.empty())
     {
-      //std::cout << "debug: last chunk" << std::endl;
+      //std::cout << "debug: last chunk\n";
       do_line_scanned(m_current_line, m_line_number);
     }
 
@@ -464,7 +462,7 @@ void CsvParser::do_line_scanned(const Glib::ustring& line, guint line_number)
   if(line.empty())
    return;
 
-  m_rows.push_back(CsvParser::type_row_strings());
+  m_rows.emplace_back(CsvParser::type_row_strings());
   auto& row = m_rows.back();
 
   Glib::ustring field;
@@ -472,7 +470,7 @@ void CsvParser::do_line_scanned(const Glib::ustring& line, guint line_number)
 
   // Parse first field:
   auto line_iter = CsvParser::advance_field(line.begin(), line.end(), field);
-  row.push_back(field);
+  row.emplace_back(field);
 
   // Parse more fields:
   while(line_iter != line.end())
@@ -484,7 +482,7 @@ void CsvParser::do_line_scanned(const Glib::ustring& line, guint line_number)
     line_iter = advance_field(line_iter, line.end(), field);
 
     // Add field to current row:
-    row.push_back(field);
+    row.emplace_back(field);
   }
 
   signal_line_scanned().emit(row, line_number);
@@ -508,7 +506,7 @@ void CsvParser::on_file_read(const Glib::RefPtr<Gio::AsyncResult>& result, const
   {
     m_stream = source->read_finish(result);
 
-    m_buffer.reset(new Buffer);
+    m_buffer = std::make_unique<Buffer>();
     m_stream->read_async(m_buffer->buf, sizeof(m_buffer->buf), sigc::mem_fun(*this, &CsvParser::on_buffer_read));
   }
   catch(const Glib::Exception& ex)
@@ -524,7 +522,7 @@ void CsvParser::copy_buffer_and_continue_reading(gssize size)
   {
     m_raw.insert(m_raw.end(), m_buffer->buf, m_buffer->buf + size);
 
-    m_buffer.reset(new Buffer);
+    m_buffer = std::make_unique<Buffer>();
     m_stream->read_async(m_buffer->buf, sizeof(m_buffer->buf), sigc::mem_fun(*this, &CsvParser::on_buffer_read));
   }
   else // When size == 0 we finished reading.
