@@ -39,7 +39,7 @@ namespace
 
 // When auto-detecting the encoding, we try to read the file in these
 // encodings, in order:
-const char* AUTODETECT_ENCODINGS_CHARSETS[] = {
+constexpr const char* AUTODETECT_ENCODINGS_CHARSETS[] = {
   "UTF-8",
   "ISO-8859-1",
   "ISO-8859-15",
@@ -48,7 +48,7 @@ const char* AUTODETECT_ENCODINGS_CHARSETS[] = {
   "UCS-4"
 };
 
-const auto N_AUTODETECT_ENCODINGS_CHARSETS = sizeof(AUTODETECT_ENCODINGS_CHARSETS)/sizeof(AUTODETECT_ENCODINGS_CHARSETS[0]);
+constexpr auto N_AUTODETECT_ENCODINGS_CHARSETS = sizeof(AUTODETECT_ENCODINGS_CHARSETS)/sizeof(AUTODETECT_ENCODINGS_CHARSETS[0]);
 
 
 Glib::ustring encoding_display(const Glib::ustring& name, const Glib::ustring& charset)
@@ -117,7 +117,7 @@ Dialog_Import_CSV::Dialog_Import_CSV(BaseObjectType* cobject, const Glib::RefPtr
   auto renderer = Gtk::manage(new Gtk::CellRendererText);
   m_encoding_combo->set_model(m_encoding_model);
   m_encoding_combo->pack_start(*renderer);
-  m_encoding_combo->set_cell_data_func(*renderer, sigc::bind(sigc::mem_fun(*this, &Dialog_Import_CSV::encoding_data_func), sigc::ref(*renderer)));
+  m_encoding_combo->set_cell_data_func(*renderer, sigc::bind(sigc::mem_fun(*this, &Dialog_Import_CSV::encoding_data_func), std::ref(*renderer)));
   m_encoding_combo->set_row_separator_func(sigc::mem_fun(*this, &Dialog_Import_CSV::row_separator_func));
   m_encoding_combo->set_active(0);
 
