@@ -104,16 +104,14 @@ void SharedConnection::close()
 }
 
 //init_db_details static data:
-ConnectionPool* ConnectionPool::m_instance = nullptr;
+std::shared_ptr<ConnectionPool> ConnectionPool::m_instance;
 
 ConnectionPool::ConnectionPool()
 :
   m_epc_publisher(nullptr),
   m_dialog_epc_progress(nullptr),
-  m_backend(nullptr),
   m_sharedconnection_refcount(0),
   m_ready_to_connect(false),
-  m_pFieldTypes(nullptr),
   m_show_debug_output(false),
   m_auto_server_shutdown(true),
   m_fake_connection(false)
@@ -122,64 +120,62 @@ ConnectionPool::ConnectionPool()
 
 ConnectionPool::~ConnectionPool()
 {
-  delete m_pFieldTypes;
-  m_pFieldTypes = nullptr;
 }
 
 //static
-ConnectionPool* ConnectionPool::get_instance()
+std::shared_ptr<ConnectionPool> ConnectionPool::get_instance()
 {
   //TODO: Synchronize this for threads?
   if(m_instance)
     return m_instance;
   else
   {
-    m_instance = new ConnectionPool();
+    m_instance = std::make_shared<ConnectionPool>();
     return m_instance;
   }
 }
 
-void ConnectionPool::setup_from_document(const Document* document)
+void ConnectionPool::setup_from_document(const std::shared_ptr<const Document>& document)
 {
   switch(document->get_hosting_mode())
   {
   case Document::HostingMode::POSTGRES_SELF:
     {
-      auto backend = new ConnectionPoolBackends::PostgresSelfHosted;
+      auto backend = std::make_shared<ConnectionPoolBackends::PostgresSelfHosted>();
       backend->set_database_directory_uri(document->get_connection_self_hosted_directory_uri());
-      set_backend(std::shared_ptr<ConnectionPool::Backend>(backend));
+      set_backend(backend);
     }
     break;
   case Document::HostingMode::POSTGRES_CENTRAL:
     {
-      auto backend = new ConnectionPoolBackends::PostgresCentralHosted;
+      auto backend = std::make_shared<ConnectionPoolBackends::PostgresCentralHosted>();
       backend->set_host(document->get_connection_server());
       backend->set_port(document->get_connection_port());
       backend->set_try_other_ports(document->get_connection_try_other_ports());
-      set_backend(std::shared_ptr<ConnectionPool::Backend>(backend));
+      set_backend(backend);
     }
     break;
   case Document::HostingMode::SQLITE:
     {
-      auto backend = new ConnectionPoolBackends::Sqlite;
+      auto backend = std::make_shared<ConnectionPoolBackends::Sqlite>();
       backend->set_database_directory_uri(document->get_connection_self_hosted_directory_uri());
-      set_backend(std::shared_ptr<ConnectionPool::Backend>(backend));
+      set_backend(backend);
     }
     break;
   case Document::HostingMode::MYSQL_SELF:
     {
-      auto backend = new ConnectionPoolBackends::MySQLSelfHosted;
+      auto backend = std::make_shared<ConnectionPoolBackends::MySQLSelfHosted>();
       backend->set_database_directory_uri(document->get_connection_self_hosted_directory_uri());
-      set_backend(std::shared_ptr<ConnectionPool::Backend>(backend));
+      set_backend(backend);
     }
     break;
   case Document::HostingMode::MYSQL_CENTRAL:
     {
-      auto backend = new ConnectionPoolBackends::MySQLCentralHosted;
+      auto backend = std::make_shared<ConnectionPoolBackends::MySQLCentralHosted>();
       backend->set_host(document->get_connection_server());
       backend->set_port(document->get_connection_port());
       backend->set_try_other_ports(document->get_connection_try_other_ports());
-      set_backend(std::shared_ptr<ConnectionPool::Backend>(backend));
+      set_backend(backend);
     }
     break;
 
@@ -199,8 +195,7 @@ void ConnectionPool::setup_from_document(const Document* document)
 
 void ConnectionPool::delete_instance()
 {
-  delete m_instance;
-  m_instance = nullptr;
+  m_instance.reset();
 }
 
 bool ConnectionPool::get_ready_to_connect() const
@@ -213,26 +208,25 @@ void ConnectionPool::set_ready_to_connect(bool val)
   m_ready_to_connect = val;
 }
 
-void ConnectionPool::set_backend(std::shared_ptr<Backend> backend)
+void ConnectionPool::set_backend(const std::shared_ptr<Backend>& backend)
 {
   m_backend = backend;
 }
 
-ConnectionPool::Backend* ConnectionPool::get_backend()
+std::shared_ptr<ConnectionPool::Backend> ConnectionPool::get_backend()
 {
-  return m_backend.get();
+  return m_backend;
 }
 
-const ConnectionPool::Backend* ConnectionPool::get_backend() const
+std::shared_ptr<const ConnectionPool::Backend> ConnectionPool::get_backend() const
 {
-  return m_backend.get();
+  return m_backend;
 }
 
 bool ConnectionPool::get_backend_supports_cursor() const
 {
   //TODO: Is there a generic libgda way to discover this?
-  const auto sqlite_backend =
-    dynamic_cast<const ConnectionPoolBackends::Sqlite*>(get_backend());
+  const auto sqlite_backend = std::dynamic_pointer_cast<const ConnectionPoolBackends::Sqlite>(get_backend());
   return !sqlite_backend;
 }
 
@@ -245,9 +239,9 @@ std::shared_ptr<SharedConnection> ConnectionPool::get_and_connect()
   if(!connection_pool)
     return result;
 
-  if(!(connection_pool->m_backend.get()))
+  if(!(connection_pool->m_backend))
   {
-    std::cerr << G_STRFUNC << ": m_backend is null." << std::endl;
+    std::cerr << G_STRFUNC << ": m_backend is null.\n";
     return result; //TODO: Return a failure_type::NO_BACKEND error?, though that would be tedious.
   }
 
@@ -276,7 +270,7 @@ static sigc::connection connection_cached_finished_connection;
 
 static bool on_connection_pool_cache_timeout()
 {
-  //std::cout << "DEBUG: Clearing connection cache." << std::endl;
+  //std::cout << "DEBUG: Clearing connection cache.\n";
 
   //Forget the cached connection after a few seconds:
   connection_cached.reset();
@@ -287,10 +281,10 @@ static bool on_connection_pool_cache_timeout()
 
 std::shared_ptr<SharedConnection> ConnectionPool::connect()
 {
-  //std::cout << G_STRFUNC << ": debug" << std::endl;
+  //std::cout << G_STRFUNC << ": debug\n";
 
   //Don't try to connect if we don't have a backend to connect to.
-  g_return_val_if_fail(m_backend.get(), std::shared_ptr<SharedConnection>());
+  g_return_val_if_fail(m_backend, std::shared_ptr<SharedConnection>());
 
   if(get_ready_to_connect() || m_fake_connection)
   {
@@ -317,7 +311,7 @@ std::shared_ptr<SharedConnection> ConnectionPool::connect()
       m_sharedconnection_refcount++;
 
       //Store the connection in a cache for a few seconds to avoid unnecessary disconnections/reconnections:
-      //std::cout << "DEBUG: Stored connection cache." << std::endl;
+      //std::cout << "DEBUG: Stored connection cache.\n";
       connection_cached = sharedConnection;
       connection_cached_timeout_connection.disconnect(); //Stop the existing timeout if it has not run yet.
       connection_cached_timeout_connection = Glib::signal_timeout().connect_seconds(&on_connection_pool_cache_timeout, 30 /* seconds */);
@@ -330,8 +324,8 @@ std::shared_ptr<SharedConnection> ConnectionPool::connect()
 
       {
         //Allow get_meta_store_data() to succeed:
-        //Hopefully this (and the update_meta_store_for_table() calls) is all we need.
-        //std::cout << "DEBUG: Calling update_meta_store_data_types() ..." << std::endl;
+        //Hopefully this (and the update_meta_store_table() calls) is all we need.
+        //std::cout << "DEBUG: Calling update_meta_store_data_types() ...\n";
         try
         {
           m_refGdaConnection->update_meta_store_data_types();
@@ -346,37 +340,19 @@ std::shared_ptr<SharedConnection> ConnectionPool::connect()
             std::cerr << G_STRFUNC << ": update_meta_store_data_types() failed: " << ex.what() << std::endl;
           }
         }
-        //std::cout << "DEBUG: ... update_meta_store_data_types() has finished." << std::endl;
+        //std::cout << "DEBUG: ... update_meta_store_data_types() has finished.\n";
 
-        //std::cout << "DEBUG: Calling update_meta_store_table_names() ..." << std::endl;
+        //std::cout << "DEBUG: Calling update_meta_store_table_names() ...\n";
 
-        try
-        {
-          //update_meta_store_table_names() has been known to throw an exception.
-          //Glom is mostly unusable when it fails, but that's still better than a crash.
-          //std::cout << G_STRFUNC << ": Before update_meta_store_table_name()" << std::endl;
-          const auto test = m_refGdaConnection->update_meta_store_table_names(m_backend->get_public_schema_name());
-          if(!test && !m_fake_connection)
-          {
-            std::cerr << G_STRFUNC << ": update_meta_store_table_names() failed without an exception." << std::endl;
-          }
+        if(!update_meta_store_for_table_names()) {
+          std::cerr << G_STRFUNC << ": update_meta_store_table_names() failed without an exception.\n";
         }
-        catch(const Glib::Error& ex)
-        {
-          //If the connection was not opened, because it is a fake connection,
-          //then we should not be surprised that this fails,
-          //and a warning will only be useful later when get_meta_store_data() fails when used in get_table_names_from_database().
-          if(!m_fake_connection)
-          {
-            std::cerr << G_STRFUNC << ": update_meta_store_table_names() failed: " << ex.what() << std::endl;
-          }
-        }
-        //std::cout << "DEBUG: ... update_meta_store_table_names() has finished." << std::endl;
+        //std::cout << "DEBUG: ... update_meta_store_table_names() has finished.\n";
 
         // Connection succeeded
         // Create the fieldtypes member if it has not already been done:
-        if(!m_pFieldTypes)
-          m_pFieldTypes = new FieldTypes(m_refGdaConnection);
+        if(!m_field_types)
+          m_field_types = std::make_shared<FieldTypes>(m_refGdaConnection);
 
 #ifndef G_OS_WIN32
         //Let other clients discover this server via avahi:
@@ -395,7 +371,7 @@ std::shared_ptr<SharedConnection> ConnectionPool::connect()
   }
   else
   {
-    //std::cerr << G_STRFUNC << ": not ready to connect." << std::endl;
+    //std::cerr << G_STRFUNC << ": not ready to connect.\n";
   }
 
   return std::shared_ptr<SharedConnection>();
@@ -403,7 +379,7 @@ std::shared_ptr<SharedConnection> ConnectionPool::connect()
 
 void ConnectionPool::create_database(const SlotProgress& slot_progress, const Glib::ustring& database_name)
 {
-  if(m_backend.get())
+  if(m_backend)
     m_backend->create_database(slot_progress, database_name, get_user(), get_password());
 }
 
@@ -412,7 +388,7 @@ void ConnectionPool::set_user(const Glib::ustring& value)
   if(value.empty())
   {
 #ifdef GLOM_CONNECTION_DEBUG
-    std::cout << "debug: " << G_STRFUNC << ": user is empty." << std::endl;
+    std::cout << "debug: " << G_STRFUNC << ": user is empty.\n";
 #endif
   }
 
@@ -424,7 +400,7 @@ void ConnectionPool::set_user(const Glib::ustring& value)
 
 bool ConnectionPool::save_backup(const SlotProgress& slot_progress, const std::string& path_dir)
 {
-  g_assert(m_backend.get());
+  g_assert(m_backend);
 
   const auto old_uri = m_backend->get_database_directory_uri();
 
@@ -450,7 +426,7 @@ bool ConnectionPool::save_backup(const SlotProgress& slot_progress, const std::s
 
 bool ConnectionPool::convert_backup(const SlotProgress& slot_progress, const std::string& backup_data_file_path)
 {
-  g_assert(m_backend.get());
+  g_assert(m_backend);
 
   const auto result = m_backend->convert_backup(slot_progress, backup_data_file_path, m_user, m_password, m_database);
   if(!result)
@@ -507,24 +483,24 @@ Glib::ustring ConnectionPool::get_database() const
   return m_database;
 }
 
-const FieldTypes* ConnectionPool::get_field_types() const
+std::shared_ptr<const FieldTypes> ConnectionPool::get_field_types() const
 {
   //TODO: Investigate this:
-  //if(!m_pFieldTypes)
-  //  std::cerr << G_STRFUNC << ": m_pFieldTypes is null but this should never happen." << std::endl;
+  //if(!m_field_types)
+  //  std::cerr << G_STRFUNC << ": m_field_types is null but this should never happen.\n";
 
-  return m_pFieldTypes;
+  return m_field_types;
 }
 
 Gnome::Gda::SqlOperatorType ConnectionPool::get_string_find_operator() const
 {
-  g_assert(m_backend.get());
+  g_assert(m_backend);
   return m_backend->get_string_find_operator();
 }
 
 void ConnectionPool::invalidate_connection()
 {
-  //std::cerr << G_STRFUNC << ": debug" << std::endl;
+  //std::cerr << G_STRFUNC << ": debug\n";
   connection_cached.reset();
   connection_cached_timeout_connection.disconnect();
   connection_cached_finished_connection.disconnect();
@@ -535,8 +511,7 @@ void ConnectionPool::invalidate_connection()
   m_refGdaConnection.reset();
   m_sharedconnection_refcount = 0;
 
-  delete m_pFieldTypes;
-  m_pFieldTypes = nullptr;
+  m_field_types.reset();
 }
 
 void ConnectionPool::on_sharedconnection_finished()
@@ -551,7 +526,7 @@ void ConnectionPool::on_sharedconnection_finished()
   {
     //There should be no copies of the m_refConnection, so the Gnome::Gda::Connection destructor should
     //run when we clear this last RefPtr of it, but we will explicitly close it just in case.
-    //std::cerr << G_STRFUNC << ": closing GdaConnection" << std::endl;
+    //std::cerr << G_STRFUNC << ": closing GdaConnection\n";
     m_refGdaConnection->close();
 
     m_refGdaConnection.reset();
@@ -568,11 +543,11 @@ void ConnectionPool::on_sharedconnection_finished()
 //static
 bool ConnectionPool::handle_error_cerr_only()
 {
-  std::shared_ptr<SharedConnection> sharedconnection = get_and_connect();
+  auto sharedconnection = get_and_connect();
 
   if(sharedconnection)
   {
-    Glib::RefPtr<Gnome::Gda::Connection> gda_connection = sharedconnection->get_gda_connection();
+    auto gda_connection = sharedconnection->get_gda_connection();
 
     const auto list_errors = gda_connection->get_events();
 
@@ -630,7 +605,7 @@ static void on_linux_signal(int signum)
 
 ConnectionPool::StartupErrors ConnectionPool::startup(const SlotProgress& slot_progress, bool network_shared)
 {
-  if(!m_backend.get())
+  if(!m_backend)
     return Backend::StartupErrors::FAILED_UNKNOWN_REASON;
 
   const auto started = m_backend->startup(slot_progress, network_shared);
@@ -668,7 +643,7 @@ bool ConnectionPool::cleanup(const SlotProgress& slot_progress)
   //And make sure that connect() tries to make a new connection:
   invalidate_connection();
       
-  if(m_backend.get())
+  if(m_backend)
     result = m_backend->cleanup(slot_progress);
 
 #ifndef G_OS_WIN32
@@ -689,7 +664,7 @@ bool ConnectionPool::cleanup(const SlotProgress& slot_progress)
 
 bool ConnectionPool::set_network_shared(const SlotProgress& slot_progress, bool network_shared)
 {
-  if(m_backend.get())
+  if(m_backend)
     return m_backend->set_network_shared(slot_progress, network_shared);
   else
     return false;
@@ -783,12 +758,12 @@ bool ConnectionPool::change_columns(const Glib::ustring& table_name, const type_
   //Add or remove any auto-increment rows:
   //The new auto-increment row would actually be added automatically,
   //but this makes it available even before a record has been added. 
-  type_vec_const_fields::const_iterator iter_old = old_fields.begin();
-  type_vec_const_fields::const_iterator iter_new = new_fields.begin();
+  auto iter_old = old_fields.begin();
+  auto iter_new = new_fields.begin();
   while( (iter_old != old_fields.end()) && (iter_new != new_fields.end()) )
   {
-    const std::shared_ptr<const Field> field_old = *iter_old;
-    const std::shared_ptr<const Field> field_new = *iter_new;
+    const auto field_old = *iter_old;
+    const auto field_new = *iter_new;
     if(field_old && field_new
       && field_old->get_auto_increment() != field_new->get_auto_increment())
     {
@@ -807,19 +782,19 @@ bool ConnectionPool::change_columns(const Glib::ustring& table_name, const type_
 
 ConnectionPool::InitErrors ConnectionPool::initialize(const SlotProgress& slot_progress, bool network_shared)
 {
-  if(m_backend.get())
+  if(m_backend)
     return m_backend->initialize(slot_progress, get_user(), get_password(), network_shared);
   else
     return Backend::InitErrors::OTHER;
 }
 
-Document* ConnectionPool::get_document()
+std::shared_ptr<Document> ConnectionPool::get_document()
 {
   if(!m_slot_get_document)
   {
     //Don't bother warning because all the code that calls get_document() checks 
     //for 0 and responds reasonably.
-    //std::cerr << G_STRFUNC << ": m_slot_get_document is null." << std::endl;
+    //std::cerr << G_STRFUNC << ": m_slot_get_document is null.\n";
     return nullptr;
   }
 
@@ -839,7 +814,7 @@ EpcContents* ConnectionPool::on_publisher_document_requested(EpcPublisher* /* pu
     return nullptr;
 
   const auto contents = document->get_contents();
-  //std::cout << "debug: " << G_STRFUNC << ": returning: " << std::endl << "  " << contents << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": returning: \n" << "  " << contents << std::endl;
   return epc_contents_new_dup ("text/plain", (void*)contents.c_str(), -1);
 }
 
@@ -864,16 +839,16 @@ gboolean ConnectionPool::on_publisher_document_authentication(EpcAuthContext* co
 
   //Attempt a connection with this username/password:
   std::shared_ptr<ExceptionConnection> error;
-  Glib::RefPtr<Gnome::Gda::Connection> connection = connection_pool->m_backend->connect(connection_pool->get_database(), user_name, password);
+  auto connection = connection_pool->m_backend->connect(connection_pool->get_database(), user_name, password);
 
   if(connection)
   {
-    //std::cout << "debug: " << G_STRFUNC << ": succeeded." << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": succeeded.\n";
     return true; //Succeeded.
   }
   else
   {
-    //std::cout << "debug: " << G_STRFUNC << ": failed." << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": failed.\n";
     return false; //Failed.
   }
 }
@@ -924,7 +899,7 @@ void ConnectionPool::avahi_start_publishing()
   if(m_epc_publisher)
     return;
 #ifdef GLOM_CONNECTION_DEBUG
-  std::cout << "debug: ConnectionPool::avahi_start_publishing" << std::endl;
+  std::cout << "debug: ConnectionPool::avahi_start_publishing\n";
 #endif
 
   //Publish the document contents over HTTPS (discoverable via avahi):
@@ -979,7 +954,7 @@ void ConnectionPool::avahi_stop_publishing()
   if(!m_epc_publisher)
     return;
 #ifdef GLOM_CONNECTION_DEBUG
-  std::cout << "debug: ConnectionPool::avahi_stop_publishing" << std::endl;
+  std::cout << "debug: ConnectionPool::avahi_stop_publishing\n";
 #endif
 
 #ifndef G_OS_WIN32
@@ -1019,4 +994,33 @@ void ConnectionPool::set_fake_connection()
   set_password("glom_fake_password");
 }
 
+bool ConnectionPool::update_meta_store_for_table_names()
+{
+  try
+  {
+    //update_meta_store_table_names() has been known to throw an exception.
+    //Glom is mostly unusable when it fails, but that's still better than a crash.
+    //std::cout << G_STRFUNC << ": Before update_meta_store_table_name()\n";
+    const auto test = m_refGdaConnection->update_meta_store_table_names(m_backend->get_public_schema_name());
+    if(!test && !m_fake_connection)
+    {
+      std::cerr << G_STRFUNC << ": update_meta_store_table_names() failed without an exception.\n";
+      return false;
+    }
+  }
+  catch(const Glib::Error& ex)
+  {
+    //If the connection was not opened, because it is a fake connection,
+    //then we should not be surprised that this fails,
+    //and a warning will only be useful later when get_meta_store_data() fails when used in get_table_names_from_database().
+    if(!m_fake_connection)
+    {
+      std::cerr << G_STRFUNC << ": update_meta_store_table_names() failed: " << ex.what() << std::endl;
+      return false;
+    }
+  }
+
+  return true;
+}
+
 } //namespace Glom
