@@ -18,6 +18,7 @@
  * Boston, MA 02110-1301 USA.
  */
 
+#include <libglom/algorithms_utils.h>
 #include <libglom/data_structure/field.h>
 #include <libglom/connectionpool.h>
 #include <libglom/data_structure/glomconversions.h>
@@ -56,10 +57,6 @@ Field::Field(const Field& src)
   operator=(src);
 }
 
-Field::~Field()
-{
-}
-
 Field& Field::operator=(const Field& src)
 {
   TranslatableItem::operator=(src);
@@ -135,7 +132,7 @@ Glib::RefPtr<const Gnome::Gda::Column> Field::get_field_info() const
   return m_field_info;
 }
 
-static const FieldTypes* get_field_types()
+static std::shared_ptr<const FieldTypes> get_field_types()
 {
   auto connection_pool = ConnectionPool::get_instance();
   if(!connection_pool)
@@ -164,12 +161,12 @@ void Field::set_field_info(const Glib::RefPtr<Gnome::Gda::Column>& fieldinfo)
   {
     cur_type = get_gda_type_for_glom_type(glom_type);
 
-    const auto pFieldTypes = get_field_types();
+    const auto field_types = get_field_types();
 
-    if(pFieldTypes)
+    if(field_types)
     {
       while(cur_type != new_type && cur_type != G_TYPE_NONE)
-        cur_type = pFieldTypes->get_fallback_type_for_gdavaluetype(cur_type);
+        cur_type = field_types->get_fallback_type_for_gdavaluetype(cur_type);
     }
   }
 
@@ -182,7 +179,7 @@ void Field::set_field_info(const Glib::RefPtr<Gnome::Gda::Column>& fieldinfo)
     // Check that the default value is consistent with the field's type
     if(!value.is_null() && value.get_value_type() != get_gda_data_type_with_fallback(value))
     {
-      std::cerr << G_STRFUNC << ": New field's default value type (" << g_type_name(value.get_value_type()) << " does not match field type (" << g_type_name(get_gda_type_for_glom_type(get_glom_type())) << "). Resetting default value." << std::endl;
+      std::cerr << G_STRFUNC << ": New field's default value type (" << g_type_name(value.get_value_type()) << " does not match field type (" << g_type_name(get_gda_type_for_glom_type(get_glom_type())) << "). Resetting default value.\n";
       m_field_info->set_default_value(Gnome::Gda::Value());
     }
   }
@@ -191,13 +188,13 @@ void Field::set_field_info(const Glib::RefPtr<Gnome::Gda::Column>& fieldinfo)
 GType Field::get_gda_data_type_with_fallback(const Gnome::Gda::Value& value)
 {
   auto cur_type = get_gda_type_for_glom_type(get_glom_type());
-  const auto pFieldTypes = get_field_types();
+  const auto field_types = get_field_types();
 
   // Take into account that value might be one of the fallback types
-  if(pFieldTypes)
+  if(field_types)
   {
     while(cur_type != value.get_value_type() && cur_type != G_TYPE_NONE)
-      cur_type = pFieldTypes->get_fallback_type_for_gdavaluetype(cur_type);
+      cur_type = field_types->get_fallback_type_for_gdavaluetype(cur_type);
   }
 
   return cur_type;
@@ -243,7 +240,7 @@ Glib::ustring Field::sql(const Gnome::Gda::Value& value, const Glib::RefPtr<Gnom
   Glib::RefPtr<const Gnome::Gda::ServerProvider> provider = connection->get_provider();
   if(!provider)
   {
-    std::cerr << G_STRFUNC << ": The ServerProvider was null." << std::endl;
+    std::cerr << G_STRFUNC << ": The ServerProvider was null.\n";
     return Glib::ustring();
   } 
 
@@ -257,7 +254,7 @@ Glib::ustring Field::sql(const Gnome::Gda::Value& value, const Glib::RefPtr<Gnom
   }
   else
   {
-    std::cerr << G_STRFUNC << ": The DataHandler was null." << std::endl;
+    std::cerr << G_STRFUNC << ": The DataHandler was null.\n";
     return Glib::ustring();
   }
 }
@@ -324,7 +321,7 @@ Glib::ustring Field::to_file_format(const Gnome::Gda::Value& value, glom_field_t
     if(!str)
       return Glib::ustring();
 
-    auto result = Glib::ustring(Glib::ScopedPtr<char>(str).get());
+    auto result = Glib::ustring(Glib::make_unique_ptr_gfree(str).get());
 
     //Correction for text representations of image (binary) data:
     //Avoid arbitrary newlines in this text.
@@ -462,6 +459,8 @@ Gnome::Gda::SqlOperatorType Field::sql_find_operator() const
       return Gnome::Gda::SQL_OPERATOR_TYPE_EQ;
     }
   }
+
+  return Gnome::Gda::SQL_OPERATOR_TYPE_EQ;
 }
 
 
@@ -539,15 +538,15 @@ Glib::ustring Field::get_sql_type() const
     auto pConnectionPool = ConnectionPool::get_instance();
     if(pConnectionPool)
     {
-      const auto pFieldTypes = pConnectionPool->get_field_types();
-      if(pFieldTypes)
+      const auto field_types = pConnectionPool->get_field_types();
+      if(field_types)
       {
         const auto fieldType = m_field_info->get_g_type();
-        strType = pFieldTypes->get_string_name_for_gdavaluetype(fieldType);
+        strType = field_types->get_string_name_for_gdavaluetype(fieldType);
       }
       else
       {
-        std::cerr << G_STRFUNC << ": get_field_types() returned null" << std::endl;
+        std::cerr << G_STRFUNC << ": get_field_types() returned null\n";
       }
     }
 
@@ -690,8 +689,8 @@ void Field::init_map()
     type_list_conversion_targets list_conversions( {
       Field::glom_field_type::BOOLEAN,
       Field::glom_field_type::TEXT} );
-    //to_date(numeric) was supported in 8.2 but not in 8.3: list_conversions.push_back(Field::glom_field_type::DATE);
-    //to_timestamp(numeric) was supported in 8.2 but not in 8.3: list_conversions.push_back(Field::glom_field_type::TIME);
+    //to_date(numeric) was supported in 8.2 but not in 8.3: list_conversions.emplace_back(Field::glom_field_type::DATE);
+    //to_timestamp(numeric) was supported in 8.2 but not in 8.3: list_conversions.emplace_back(Field::glom_field_type::TIME);
     m_map_conversions[Field::glom_field_type::NUMERIC] = list_conversions;
 
     //Text:
@@ -706,15 +705,15 @@ void Field::init_map()
     list_conversions = {
       Field::glom_field_type::TEXT,
       Field::glom_field_type::NUMERIC};
-    //to_timestamp(numeric) was supported in 8.2 but not in 8.3: list_conversions.push_back(Field::glom_field_type::DATE);
-    //to_timestamp(numeric) was supported in 8.2 but not in 8.3: list_conversions.push_back(Field::glom_field_type::TIME);
+    //to_timestamp(numeric) was supported in 8.2 but not in 8.3: list_conversions.emplace_back(Field::glom_field_type::DATE);
+    //to_timestamp(numeric) was supported in 8.2 but not in 8.3: list_conversions.emplace_back(Field::glom_field_type::TIME);
     m_map_conversions[Field::glom_field_type::BOOLEAN] = list_conversions;
 
     //Date:
     list_conversions = {
       Field::glom_field_type::TEXT};
-    //to_number(textcat()) was supported in 8.2 but not in 8.3: list_conversions.push_back(Field::glom_field_type::NUMERIC);
-    //to_number(textcat()) was supported in 8.2 but not in 8.3: list_conversions.push_back(Field::glom_field_type::BOOLEAN);
+    //to_number(textcat()) was supported in 8.2 but not in 8.3: list_conversions.emplace_back(Field::glom_field_type::NUMERIC);
+    //to_number(textcat()) was supported in 8.2 but not in 8.3: list_conversions.emplace_back(Field::glom_field_type::BOOLEAN);
     m_map_conversions[Field::glom_field_type::DATE] = list_conversions;
 
     //Time:
@@ -736,8 +735,7 @@ bool Field::get_conversion_possible(glom_field_type field_type_src, glom_field_t
   if(iterFind != m_map_conversions.end())
   {
     const auto list_conversions = iterFind->second;
-    auto iterConversionFind = std::find(list_conversions.begin(), list_conversions.end(), field_type_dest);
-    if(iterConversionFind != list_conversions.end())
+    if(Utils::find_exists(list_conversions, field_type_dest))
       return true; //Success: conversion found.
   }
   
@@ -785,6 +783,7 @@ Glib::ustring Field::get_type_name_ui(glom_field_type glom_type)
   return result;
 }
 
+//TODO: Performance, though this is a small map.
 //static:
 Field::glom_field_type Field::get_type_for_ui_name(const Glib::ustring& glom_type)
 {
@@ -840,7 +839,7 @@ Field::type_list_strings Field::get_calculation_relationships() const
       {
         Glib::ustring::size_type pos_start = pos_find + prefix_size;
         const auto field_name = m_calculation.substr(pos_start, pos_find_end - pos_start);
-        result.push_back(field_name);
+        result.emplace_back(field_name);
         index = pos_find_end + 1;
       }
     }
