@@ -34,16 +34,11 @@ LayoutItem_CalendarPortal::LayoutItem_CalendarPortal(const LayoutItem_CalendarPo
 {
 }
 
-LayoutItem_CalendarPortal::~LayoutItem_CalendarPortal()
-{
-}
-
 LayoutItem* LayoutItem_CalendarPortal::clone() const
 {
   return new LayoutItem_CalendarPortal(*this);
 }
 
-
 LayoutItem_CalendarPortal& LayoutItem_CalendarPortal::operator=(const LayoutItem_CalendarPortal& src)
 {
   LayoutItem_Portal::operator=(src);
@@ -68,7 +63,7 @@ void LayoutItem_CalendarPortal::change_field_item_name(const Glib::ustring& tabl
 {
   LayoutItem_Portal::change_field_item_name(table_name, field_name, field_name_new);
   
-  std::shared_ptr<const Relationship> relationship = get_relationship();
+  auto relationship = get_relationship();
         
   if(relationship && (relationship->get_to_table() == table_name) && (m_date_field->get_name() == field_name))
       m_date_field->set_name(field_name_new); //Change it.
