@@ -27,6 +27,7 @@
 #include <libglom/data_structure/numeric_format.h>
 #include <libglom/data_structure/relationship.h>
 #include <libglom/data_structure/layout/custom_title.h>
+#include <libglom/algorithms_utils.h>
 
 namespace Glom
 {
@@ -51,7 +52,6 @@ public:
   LayoutItem_Field(LayoutItem_Field&& src) = delete;
   LayoutItem_Field& operator=(const LayoutItem_Field& src);
   LayoutItem_Field& operator=(LayoutItem_Field&& src) = delete;
-  virtual ~LayoutItem_Field();
 
   LayoutItem* clone() const override;
 
@@ -166,9 +166,9 @@ private:
  */
 template
 <typename T_Container>
-auto find_if_layout_item_field_is_same_field(T_Container& container, const std::shared_ptr<const LayoutItem_Field>& layout_item) -> decltype(container.begin())
+bool find_if_layout_item_field_is_same_field_exists(T_Container& container, const std::shared_ptr<const LayoutItem_Field>& layout_item)
 {
-  return std::find_if(container.begin(), container.end(),
+  return Utils::find_if_exists(container,
     [&layout_item](const typename T_Container::value_type& element)
     {
       //Assume that element is a shared_ptr<>.
