@@ -35,8 +35,9 @@ public:
 
   StaticText();
   StaticText(const StaticText& src);
+  StaticText(StaticText&& src) = delete;
   StaticText& operator=(const StaticText& src);
-  virtual ~StaticText();
+  StaticText& operator=(StaticText&& src) = delete;
 
   bool operator==(const StaticText& src) const;
 };
