@@ -34,10 +34,6 @@ UsesRelationship::UsesRelationship(const UsesRelationship& src)
 {
 }
 
-UsesRelationship::~UsesRelationship()
-{
-}
-
 bool UsesRelationship::operator==(const UsesRelationship& src) const
 {
   return (m_relationship == src.m_relationship)
@@ -147,7 +143,7 @@ Glib::ustring UsesRelationship::get_title_used(const Glib::ustring& parent_table
 
 Glib::ustring UsesRelationship::get_title_singular_used(const Glib::ustring& parent_table_title, const Glib::ustring& locale) const
 {
-  std::shared_ptr<const Relationship> used = m_related_relationship;
+  auto used = m_related_relationship;
   if(!used)
     used = m_relationship;
 
