@@ -38,8 +38,6 @@ Document::Document()
 
 Document::~Document()
 {
-  //Tell views to forget the document -  to null their pointers to it. We should maybe use the Document via a sharing smartpointer instead.
-  signal_forget_.emit();
 }
 
 Glib::ustring Document::get_file_uri() const
@@ -273,7 +271,7 @@ bool Document::write_to_disk()
 {
   if(m_file_uri.empty())
   {
-    std::cerr << G_STRFUNC << ": m_file_uri is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": m_file_uri is empty.\n";
     return false;
   }
 
@@ -503,12 +501,4 @@ Document::type_signal_modified& Document::signal_modified()
   return signal_modified_;
 }
 
-Document::type_signal_forget& Document::signal_forget()
-{
-  return signal_forget_;
-}
-
-
-
-
 } //namespace
