@@ -45,17 +45,17 @@ public:
    */
   bool save();
 
-  enum LoadFailureCodes
+  enum class LoadFailureCodes
   {
-    LOAD_FAILURE_CODE_NONE = 0,
-    LOAD_FAILURE_CODE_NOT_FOUND = 1,
-    LOAD_FAILURE_CODE_LAST = 20 //arbitrary large number. Anything after this is for the application's custom codes.
+    NONE = 0,
+    NOT_FOUND = 1,
+    LAST = 20 //arbitrary large number. Anything after this is for the application's custom codes.
   };
 
   /* Loads data from disk, using the URI (set with set_file_uri()) then asks the View to update itself.
    * bool indicates success.
    * @param failure_code Used to return an error code that is understood by your application.
-   * Custom error codes should be greater than LOAD_FAILURE_CODE_LAST.
+   * Custom error codes should be greater than LoadFailureCodes::CODE_LAST.
    */
   bool load(int& failure_code);
 
@@ -107,13 +107,6 @@ public:
    */
   type_signal_modified& signal_modified();
 
-  typedef sigc::signal<void> type_signal_forget;
-
-  /** This signal is emitted when the view should forget the document.
-   * This is used internally, and you should not need to use it yourself.
-   */
-  type_signal_forget& signal_forget();
-
   ///Allow app to update icons/title bar.
 
 protected:
@@ -139,7 +132,6 @@ protected:
   ViewBase* m_pView;
 
   type_signal_modified signal_modified_;
-  type_signal_forget signal_forget_;
 
   bool m_bModified;
   bool m_bIsNew; //see get_is_new().
