@@ -19,6 +19,7 @@
  */
 
 #include "privs.h"
+#include <libglom/algorithms_utils.h>
 #include <libglom/standard_table_prefs_fields.h>
 #include <libglom/db_utils.h>
 #include <libglom/utils.h>
@@ -38,12 +39,12 @@ Privs::type_vec_strings Privs::get_database_groups()
 {
   type_vec_strings result;
 
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+  auto builder =
       Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
   builder->select_add_field("groname", "pg_group");
   builder->select_add_target("pg_group");
 
-  Glib::RefPtr<Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(builder);
+  auto data_model = DbUtils::query_execute_select(builder);
   if(data_model)
   {
     const auto rows_count = data_model->get_n_rows();
@@ -51,7 +52,7 @@ Privs::type_vec_strings Privs::get_database_groups()
     {
       const auto value = data_model->get_value_at(0, row);
       const auto name = value.get_string();
-      result.push_back(name);
+      result.emplace_back(name);
     }
   }
 
@@ -64,8 +65,7 @@ bool Privs::get_default_developer_user_exists(Document::HostingMode hosting_mode
   const auto default_user = get_default_developer_user_name(default_password, hosting_mode);
 
   const auto users = get_database_users();
-  type_vec_strings::const_iterator iterFind = std::find(users.begin(), users.end(), default_user);
-  if(iterFind != users.end())
+  if(Utils::find_exists(users, default_user))
     return true; //We assume that the password is what it should be and that it has developer rights.
 
   return false; //The default user is not there.
@@ -115,12 +115,12 @@ Privs::type_vec_strings Privs::get_database_users(const Glib::ustring& group_nam
   if(group_name.empty())
   {
     //pg_shadow contains the users. pg_users is a view of pg_shadow without the password.
-    Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+    auto builder =
       Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
     builder->select_add_field("usename", "pg_shadow");
     builder->select_add_target("pg_shadow");
 
-    Glib::RefPtr<Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(builder);
+    auto data_model = DbUtils::query_execute_select(builder);
     if(data_model)
     {
       const auto rows_count = data_model->get_n_rows();
@@ -128,13 +128,13 @@ Privs::type_vec_strings Privs::get_database_users(const Glib::ustring& group_nam
       {
         const auto value = data_model->get_value_at(0, row);
         const auto name = value.get_string();
-        result.push_back(name);
+        result.emplace_back(name);
       }
     }
   }
   else
   {
-    Glib::RefPtr<Gnome::Gda::SqlBuilder> builderGroup =
+    auto builderGroup =
       Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
     builderGroup->select_add_field("groname", "pg_group");
     builderGroup->select_add_field("grolist", "pg_group");
@@ -144,7 +144,7 @@ Privs::type_vec_strings Privs::get_database_users(const Glib::ustring& group_nam
         builderGroup->add_field_id("groname", "pg_group"),
         builderGroup->add_expr(group_name)));
     //TODO: Show SQL.
-    Glib::RefPtr<Gnome::Gda::DataModel> data_model_group = DbUtils::query_execute_select(builderGroup);
+    auto data_model_group = DbUtils::query_execute_select(builderGroup);
     if(data_model_group && data_model_group->get_n_rows())
     {
       const auto rows_count = data_model_group->get_n_rows();
@@ -161,7 +161,7 @@ Privs::type_vec_strings Privs::get_database_users(const Glib::ustring& group_nam
         for(const auto& userId: vecUserIds)
         {
           //TODO_Performance: Can we do this in one SQL SELECT?
-          Glib::RefPtr<Gnome::Gda::SqlBuilder> builderUser =
+          auto builderUser =
             Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
           builderUser->select_add_field("usename", "pg_user");
           builderUser->select_add_target("pg_user");
@@ -169,12 +169,12 @@ Privs::type_vec_strings Privs::get_database_users(const Glib::ustring& group_nam
             builderUser->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
               builderUser->add_field_id("usesysid", "pg_user"),
               builderUser->add_expr(userId)));
-          Glib::RefPtr<Gnome::Gda::DataModel> data_model_user = DbUtils::query_execute_select(builderUser);
+          auto data_model_user = DbUtils::query_execute_select(builderUser);
           if(data_model_user && data_model_user->get_n_rows() && data_model_user->get_n_columns())
           {
             const auto value_user = data_model_user->get_value_at(0, 0);
             //std::cout << G_STRFUNC << "DEBUG:  username=" << value.get_string() << std::endl; 
-            result.push_back(value_user.get_string());
+            result.emplace_back(value_user.get_string());
           }
           else
           {
@@ -250,7 +250,7 @@ bool Privs::set_table_privileges(const Glib::ustring& group_name, const Glib::us
   const auto test = DbUtils::query_execute_string(strQuery);
   if(!test)
   {
-    std::cerr << G_STRFUNC << ": GRANT failed." << std::endl;
+    std::cerr << G_STRFUNC << ": GRANT failed.\n";
     return false;
   }
 
@@ -263,7 +263,7 @@ bool Privs::set_table_privileges(const Glib::ustring& group_name, const Glib::us
     priv_autoincrements.m_edit = true;
     if(!set_table_privileges(group_name, GLOM_STANDARD_TABLE_AUTOINCREMENTS_TABLE_NAME, priv_autoincrements))
     {
-      std::cerr << G_STRFUNC << ": GRANT failed on autoincrements table." << std::endl;
+      std::cerr << G_STRFUNC << ": GRANT failed on autoincrements table.\n";
       return false;
     }
   }
@@ -285,11 +285,11 @@ static Glib::RefPtr<Gnome::Gda::Connection> get_connection()
 
   if(!sharedconnection)
   {
-    std::cerr << G_STRFUNC << ": No connection yet." << std::endl;
+    std::cerr << G_STRFUNC << ": No connection yet.\n";
     return Glib::RefPtr<Gnome::Gda::Connection>();
   }
 
-  Glib::RefPtr<Gnome::Gda::Connection> gda_connection = sharedconnection->get_gda_connection();
+  auto gda_connection = sharedconnection->get_gda_connection();
 
   return gda_connection;
 }
@@ -309,16 +309,16 @@ Privileges Privs::get_table_privileges(const Glib::ustring& group_name, const Gl
   }
 
   //Get the permissions:
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+  auto builder =
     Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
 
   const Glib::ustring function_name = "has_table_privilege";
   std::vector<Gnome::Gda::SqlBuilder::Id> args_base;
 
-  Glib::RefPtr<Gnome::Gda::Connection> connection = get_connection();
+  auto connection = get_connection();
   if(!connection)
   {
-    std::cerr << G_STRFUNC << ": : Could not get a connection." << std::endl;
+    std::cerr << G_STRFUNC << ": : Could not get a connection.\n";
     return result;
   }
 
@@ -328,40 +328,40 @@ Privileges Privs::get_table_privileges(const Glib::ustring& group_name, const Gl
   //However, note that libgda does seem to escape characters here (for instance, changing ' to '').
   //const Glib::ustring group_name_for_arg = connection->quote_sql_identifier(group_name);
   const Glib::ustring group_name_for_arg = group_name;
-  args_base.push_back(builder->add_expr(group_name_for_arg));
+  args_base.emplace_back(builder->add_expr(group_name_for_arg));
 
   //The table name must be quoted if it needs to be quoted,
   //but not quoted if it is does not need to be quoted,
   //because it must match how it was created, and libgda probably did not quote it unless necessary.
   const auto table_name_for_arg = connection->quote_sql_identifier(table_name);
-  args_base.push_back(builder->add_expr(table_name_for_arg));
+  args_base.emplace_back(builder->add_expr(table_name_for_arg));
 
   std::vector<Gnome::Gda::SqlBuilder::Id> args = args_base;
-  args.push_back(builder->add_expr("SELECT"));
+  args.emplace_back(builder->add_expr("SELECT"));
   builder->add_field_value_id(builder->add_function(function_name, args));
   args = args_base;
-  args.push_back(builder->add_expr("UPDATE"));
+  args.emplace_back(builder->add_expr("UPDATE"));
   builder->add_field_value_id(builder->add_function(function_name, args));
   args = args_base;
-  args.push_back(builder->add_expr("INSERT"));
+  args.emplace_back(builder->add_expr("INSERT"));
   builder->add_field_value_id(builder->add_function(function_name, args));
   args = args_base;
-  args.push_back(builder->add_expr("DELETE"));
+  args.emplace_back(builder->add_expr("DELETE"));
   builder->add_field_value_id(builder->add_function(function_name, args));
 
   //const Glib::ustring sql_debug = Utils::sqlbuilder_get_full_query(builder);
   //std::cout << "DEBUG: " << sql_debug << std::endl;
 
-  Glib::RefPtr<Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(builder);
+  auto data_model = DbUtils::query_execute_select(builder);
   if(!data_model || (data_model->get_n_rows() <= 0))
   {
-    std::cerr << G_STRFUNC << ": The query returned no data." << std::endl;
+    std::cerr << G_STRFUNC << ": The query returned no data.\n";
     return result;
   }
 
   if(data_model->get_n_columns() < 4)
   {
-    std::cerr << G_STRFUNC << ": The query did not return enough columns." << std::endl;
+    std::cerr << G_STRFUNC << ": The query did not return enough columns.\n";
     return result;
   }
 
@@ -405,7 +405,7 @@ Privs::type_vec_strings Privs::get_groups_of_user(const Glib::ustring& user)
     if(get_user_is_in_group(user, group))
     {
       //Add the group to the result:
-      result.push_back(group);
+      result.emplace_back(group);
     }
   }
 
@@ -415,8 +415,7 @@ Privs::type_vec_strings Privs::get_groups_of_user(const Glib::ustring& user)
 bool Privs::get_user_is_in_group(const Glib::ustring& user, const Glib::ustring& group)
 {
   const auto users = get_database_users(group);
-  type_vec_strings::const_iterator iterFind = std::find(users.begin(), users.end(), user);
-  return (iterFind != users.end());
+  return Utils::find_exists(users, user);
 }
 
 bool Privs::on_privs_privileges_cache_timeout(const Glib::ustring& table_name)
@@ -438,7 +437,7 @@ Privileges Privs::get_current_privs(const Glib::ustring& table_name)
 {
   if(table_name.empty())
   {
-    std::cerr << G_STRFUNC << ": table_name is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": table_name is empty.\n";
     return Privileges();
   }
   
@@ -449,10 +448,10 @@ Privileges Privs::get_current_privs(const Glib::ustring& table_name)
 
   //Return a cached value if possible.
   //(If it is in the cache then it's fairly recent)
-  type_map_privileges::const_iterator iter = m_privileges_cache.find(table_name);
+  const auto iter = m_privileges_cache.find(table_name);
   if(iter != m_privileges_cache.end())
   {
-    //std::cout << "debug: " << G_STRFUNC << ": Returning cache." << std::endl;
+    //std::cout << "debug: " << G_STRFUNC << ": Returning cache.\n";
     return iter->second;
   }
 
@@ -460,21 +459,20 @@ Privileges Privs::get_current_privs(const Glib::ustring& table_name)
   //Get the up-to-date privileges from the database:
   Privileges result;
 
-  //std::cout << "debug: " << G_STRFUNC << ": Getting non-cached." << std::endl;
+  //std::cout << "debug: " << G_STRFUNC << ": Getting non-cached.\n";
 
   auto connection_pool = ConnectionPool::get_instance();
   const auto current_user = connection_pool->get_user();
 
   //Is the user in the special developers group?
   /*
-  type_vec_strings developers = get_database_users(GLOM_STANDARD_GROUP_NAME_DEVELOPER);
-  type_vec_strings::const_iterator iterFind = std::find(developers.begin(), developers.end(), current_user);
-  if(iterFind != developers.end())
+  const auto developers = get_database_users(GLOM_STANDARD_GROUP_NAME_DEVELOPER);
+  if(Utils::find_exists(developers, current_user))
   {
     result.m_developer = true;
   }
   */
-  std::shared_ptr<SharedConnection> sharedconnection = connection_pool->connect();
+  auto sharedconnection = connection_pool->connect();
   if(sharedconnection && sharedconnection->get_gda_connection()->supports_feature(Gnome::Gda::CONNECTION_FEATURE_USERS))
   {
     //Get the "true" rights for any groups that the user is in:
