@@ -66,7 +66,7 @@ boost::python::object PyGlomRecord::get_connection()
   {
     if(!_PyGObject_API)
     {
-      std::cerr << G_STRFUNC << ": pyggobject does not seem to be initialized properly." << std::endl;
+      std::cerr << G_STRFUNC << ": pyggobject does not seem to be initialized properly.\n";
       return result;
     }
 
@@ -115,7 +115,7 @@ boost::python::object PyGlomRecord::getitem(const boost::python::object& cppitem
 {
   const std::string key = boost::python::extract<std::string>(cppitem);
 
-  PyGlomRecord::type_map_field_values::const_iterator iterFind = m_map_field_values.find(key);
+  const auto iterFind = m_map_field_values.find(key);
   if(iterFind != m_map_field_values.end())
   {
     return glom_pygda_value_as_boost_pyobject(iterFind->second);
@@ -139,7 +139,7 @@ void PyGlomRecord::setitem(const boost::python::object& key, const boost::python
   if(extractor.check())
     field_name = extractor;
 
-  std::shared_ptr<const Field> field = m_document->get_field(m_table_name, field_name);
+  auto field = m_document->get_field(m_table_name, field_name);
   if(!field)
   {
      std::cerr << G_STRFUNC << ": field=" << field_name << " not found in table=" << m_table_name << std::endl;
@@ -170,17 +170,17 @@ void PyGlomRecord::setitem(const boost::python::object& key, const boost::python
   //Set the value in the database:
   if(!m_key_field || Conversions::value_is_empty(m_key_field_value))
   {
-    std::cerr << G_STRFUNC << ": The primary key name and value is not set. This would be a Glom bug." << std::endl;
+    std::cerr << G_STRFUNC << ": The primary key name and value is not set. This would be a Glom bug.\n";
     return;
   }
 
   if(!m_connection)
   {
-    std::cerr << G_STRFUNC << ": The connection is null. This would be a Glom bug." << std::endl;
+    std::cerr << G_STRFUNC << ": The connection is null. This would be a Glom bug.\n";
     return;
   }
 
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+  auto builder =
     Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
   builder->set_table(m_table_name);
   builder->add_field_value_as_value(field->get_name(), field_value);
@@ -205,13 +205,13 @@ void PyGlomRecord::setitem(const boost::python::object& key, const boost::python
 
   if(!updated)
   {
-    std::cerr << G_STRFUNC << ": UPDATE failed." << std::endl;
+    std::cerr << G_STRFUNC << ": UPDATE failed.\n";
   }
 
   //TODO: Do dependent calculations and lookups. Or just do them for all fields for this record when finishing the script?
 }
 
-void PyGlomRecord::set_fields(const PyGlomRecord::type_map_field_values& field_values, const Document* document, const Glib::ustring& table_name, const std::shared_ptr<const Field>& key_field, const Gnome::Gda::Value& key_field_value, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection)
+void PyGlomRecord::set_fields(const PyGlomRecord::type_map_field_values& field_values, const std::shared_ptr<const Document>& document, const Glib::ustring& table_name, const std::shared_ptr<const Field>& key_field, const Gnome::Gda::Value& key_field_value, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection)
 {
   m_map_field_values = field_values;
   /* Just for debugging:
