@@ -63,33 +63,33 @@ boost::python::object PyGlomRelated::getitem(const boost::python::object& cppite
       else
       {
         //If the relationship exists:
-        PyGlomRelated::type_map_relationships::const_iterator iterFind = m_map_relationships.find(key);
+        const auto iterFind = m_map_relationships.find(key);
         if(iterFind != m_map_relationships.end())
         {
           //Get the value of the from_key in the parent record.
-          std::shared_ptr<Relationship> relationship = iterFind->second;
+          auto relationship = iterFind->second;
           const auto from_key = relationship->get_from_field();
 
           boost::python::extract<PyGlomRecord*> extractor_record(m_record);
           if(extractor_record.check())
           {
             PyGlomRecord* record = extractor_record;
-            PyGlomRecord::type_map_field_values::const_iterator iterFromKey = record->m_map_field_values.find(from_key);
+            const auto iterFromKey = record->m_map_field_values.find(from_key);
             if(iterFromKey != record->m_map_field_values.end())
             {
               const Gnome::Gda::Value& from_key_value = iterFromKey->second;
 
               //TODO_Performance:
               //Get the full field details so we can sqlize its value:
-              std::shared_ptr<const Field> from_key_field = record->m_document->get_field(record->m_table_name, from_key);
+              auto from_key_field = record->m_document->get_field(record->m_table_name, from_key);
               if(from_key_field)
               {
                 //Return a new RelatedRecord:
-                auto pyRelatedRecord = new PyGlomRelatedRecord();
+                auto pyRelatedRecord = std::unique_ptr<PyGlomRelatedRecord>();
                 pyRelatedRecord->set_relationship(iterFind->second, from_key_value, record->m_document);
 
                 //Store it in the cache:
-                boost::python::object objectRelatedRecord(pyRelatedRecord);
+                boost::python::object objectRelatedRecord(pyRelatedRecord.release());
                 m_map_relatedrecords[key] = objectRelatedRecord;
 
                 return objectRelatedRecord;
