@@ -59,7 +59,7 @@ boost::python::object PyGlomRelatedRecord::getitem(const boost::python::object&
 {
   const std::string field_name = boost::python::extract<std::string>(cppitem);
 
-  PyGlomRelatedRecord::type_map_field_values::const_iterator iterFind = m_map_field_values.find(field_name);
+  const auto iterFind = m_map_field_values.find(field_name);
   if(iterFind != m_map_field_values.end())
   {
     //If the value has already been stored, then just return it again:
@@ -76,7 +76,7 @@ boost::python::object PyGlomRelatedRecord::getitem(const boost::python::object&
   }
 
   //Check whether the field exists in the table.
-  std::shared_ptr<const Field> field = m_document->get_field(m_relationship->get_to_table(), field_name);
+  auto field = m_document->get_field(m_relationship->get_to_table(), field_name);
   if(!field)
   {
     std::cerr << G_STRFUNC << ": field " << field_name << " not found in table " << m_relationship->get_to_table() << std::endl;
@@ -87,7 +87,7 @@ boost::python::object PyGlomRelatedRecord::getitem(const boost::python::object&
   {
     //Try to get the value from the database:
     //const Glib::ustring parent_key_name;
-    std::shared_ptr<SharedConnection> sharedconnection = ConnectionPool::get_instance()->connect();
+    auto sharedconnection = ConnectionPool::get_instance()->connect();
 
     if(!sharedconnection)
     {
@@ -95,7 +95,7 @@ boost::python::object PyGlomRelatedRecord::getitem(const boost::python::object&
       return boost::python::object();
     }
 
-    Glib::RefPtr<Gnome::Gda::Connection> gda_connection = sharedconnection->get_gda_connection();
+    auto gda_connection = sharedconnection->get_gda_connection();
 
     const Glib::ustring related_key_name = m_relationship->get_to_field();
 
@@ -107,7 +107,7 @@ boost::python::object PyGlomRelatedRecord::getitem(const boost::python::object&
     }
 
     //Get the single value from the related records:
-    Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+    auto builder =
       Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
     builder->select_add_field(field_name, related_table);
     builder->select_add_target(related_table);
@@ -131,7 +131,7 @@ boost::python::object PyGlomRelatedRecord::getitem(const boost::python::object&
     }*/
 
     // TODO: Does this behave well if this throws an exception?
-    Glib::RefPtr<Gnome::Gda::DataModel> datamodel = gda_connection->statement_execute_select_builder(builder);
+    auto datamodel = gda_connection->statement_execute_select_builder(builder);
     if(datamodel && datamodel->get_n_rows())
     {
       const Gnome::Gda::Value value = datamodel->get_value_at(0, 0);
@@ -143,7 +143,7 @@ boost::python::object PyGlomRelatedRecord::getitem(const boost::python::object&
     }
     else if(!datamodel)
     {
-      std::cerr << G_STRFUNC << ": The datamodel was null." << std::endl;
+      std::cerr << G_STRFUNC << ": The datamodel was null.\n";
       ConnectionPool::handle_error_cerr_only();
       RelatedRecord_HandlePythonError();
     }
@@ -153,7 +153,7 @@ boost::python::object PyGlomRelatedRecord::getitem(const boost::python::object&
     }
   }
 
-  std::cerr << G_STRFUNC << ": return null." << std::endl;
+  std::cerr << G_STRFUNC << ": return null.\n";
   return boost::python::object();
 }
 
@@ -169,7 +169,7 @@ boost::python::object PyGlomRelatedRecord::generic_aggregate(const std::string&
   }
 
   //Check whether the field exists in the table.
-  std::shared_ptr<Field> field = m_document->get_field(m_relationship->get_to_table(), field_name);
+  auto field = m_document->get_field(m_relationship->get_to_table(), field_name);
   if(!field)
   {
     g_warning("RelatedRecord_sum: field %s not found in table %s", field_name.c_str(), m_relationship->get_to_table().c_str());
@@ -178,14 +178,14 @@ boost::python::object PyGlomRelatedRecord::generic_aggregate(const std::string&
 
   //Try to get the value from the database:
   //const Glib::ustring parent_key_name;
-  std::shared_ptr<SharedConnection> sharedconnection = ConnectionPool::get_instance()->connect();
+  auto sharedconnection = ConnectionPool::get_instance()->connect();
   if(!sharedconnection)
   {
     g_warning("RelatedRecord_sum: no connection.");
     return boost::python::object();
   }
 
-  Glib::RefPtr<Gnome::Gda::Connection> gda_connection = sharedconnection->get_gda_connection();
+  auto gda_connection = sharedconnection->get_gda_connection();
 
   const Glib::ustring related_key_name = m_relationship->get_to_field();
 
@@ -196,7 +196,7 @@ boost::python::object PyGlomRelatedRecord::generic_aggregate(const std::string&
   }
 
   //Get the aggregate value from the related records:
-  Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+  auto builder =
     Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
 
   const Gnome::Gda::SqlBuilder::Id id_function = builder->add_function(aggregate, builder->add_id(field_name)); //TODO: It would be nice to specify the table here too.
@@ -210,7 +210,7 @@ boost::python::object PyGlomRelatedRecord::generic_aggregate(const std::string&
 
 
   //std::cout << "PyGlomRelatedRecord: Executing:  " << sql_query << std::endl;
-  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = gda_connection->statement_execute_select_builder(builder);
+  auto datamodel = gda_connection->statement_execute_select_builder(builder);
 
   // Ignore the error: The case that the command execution didn't return
   // a datamodel is handled below.
@@ -257,7 +257,10 @@ boost::python::object PyGlomRelatedRecord::max(const std::string& field_name) co
   return generic_aggregate(field_name, "max");
 }
 
-void PyGlomRelatedRecord::set_relationship(const std::shared_ptr<const Relationship>& relationship, const Gnome::Gda::Value& from_key_value, const Document* document)
+void PyGlomRelatedRecord::set_relationship(
+  const std::shared_ptr<const Relationship>& relationship,
+  const Gnome::Gda::Value& from_key_value,
+  const std::shared_ptr<const Document>& document)
 {
   m_relationship = relationship;
   m_from_key_value = from_key_value;
