@@ -38,10 +38,6 @@ ReportBuilder::ReportBuilder(const std::locale& locale)
   m_locale_id = Utils::locale_simplify(locale.name());
 }
 
-ReportBuilder::~ReportBuilder()
-{
-}
-
 bool ReportBuilder::report_build_headerfooter(const FoundSet& found_set, xmlpp::Element& parent_node, const std::shared_ptr<LayoutGroup>& group)
 {
   //Add XML node:
@@ -51,48 +47,48 @@ bool ReportBuilder::report_build_headerfooter(const FoundSet& found_set, xmlpp::
   type_vecLayoutItems itemsToGet;
   for(const auto& item : group->m_list_items)
   {
-    std::shared_ptr<LayoutItem_Text> item_text = std::dynamic_pointer_cast<LayoutItem_Text>(item);
+    auto item_text = std::dynamic_pointer_cast<LayoutItem_Text>(item);
     if(item_text)
     {
       if(!report_build_records_text(found_set, *node, item_text))
       {
-        std::cerr << G_STRFUNC << ": report_build_records_text() failed." << std::endl;
+        std::cerr << G_STRFUNC << ": report_build_records_text() failed.\n";
         return false;
       }
     }
     else
     {
-      std::shared_ptr<LayoutItem_Image> item_image = std::dynamic_pointer_cast<LayoutItem_Image>(item);
+      auto item_image = std::dynamic_pointer_cast<LayoutItem_Image>(item);
       if(item_image)
       {
         if(!report_build_records_image(found_set, *node, item_image))
         {
-          std::cerr << G_STRFUNC << ": report_build_records_image() failed." << std::endl;
+          std::cerr << G_STRFUNC << ": report_build_records_image() failed.\n";
           return false;
         }
       }
       else
       {
-        std::shared_ptr<LayoutItem_Field> pField = std::dynamic_pointer_cast<LayoutItem_Field>(item);
+        auto pField = std::dynamic_pointer_cast<LayoutItem_Field>(item);
         if(pField)
         {
           guint col_index = 0; //ignored.
           if(!report_build_records_field(found_set, *node, pField, Glib::RefPtr<Gnome::Gda::DataModel>(), 0, col_index))
           {
-            std::cerr << G_STRFUNC << ": report_build_records_field() failed." << std::endl;
+            std::cerr << G_STRFUNC << ": report_build_records_field() failed.\n";
             return false;
           }
         }
         else
         {
-          std::shared_ptr<LayoutItem_VerticalGroup> vertical_group = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(item);
+          auto vertical_group = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(item);
           if(vertical_group)
           {
             //Reuse (a bit hacky) this function for the header and footer:
             guint col_index = 0; //Ignored, because the model is null.
             if(!report_build_records_vertical_group(found_set, *node, vertical_group, Glib::RefPtr<Gnome::Gda::DataModel>(), 0, col_index))
             {
-              std::cerr << G_STRFUNC << ": report_build_records_vertical_group() failed." << std::endl;
+              std::cerr << G_STRFUNC << ": report_build_records_vertical_group() failed.\n";
               return false;
             }
           }
@@ -113,31 +109,31 @@ bool ReportBuilder::report_build_summary(const FoundSet& found_set, xmlpp::Eleme
   type_vecLayoutItems itemsToGet;
   for(const auto& item : summary->m_list_items)
   {
-    std::shared_ptr<LayoutItem_GroupBy> pGroupBy = std::dynamic_pointer_cast<LayoutItem_GroupBy>(item);
+    auto pGroupBy = std::dynamic_pointer_cast<LayoutItem_GroupBy>(item);
     if(pGroupBy)
     {
       //Recurse, adding a sub-groupby block:
       if(!report_build_groupby(found_set, *node, pGroupBy))
       {
-        std::cerr << G_STRFUNC << ": report_build_groupby() failed." << std::endl;
+        std::cerr << G_STRFUNC << ": report_build_groupby() failed.\n";
         return false;
       }
     }
     else
     {
-      std::shared_ptr<LayoutItem_Summary> pSummary = std::dynamic_pointer_cast<LayoutItem_Summary>(item);
+      auto pSummary = std::dynamic_pointer_cast<LayoutItem_Summary>(item);
       if(pSummary)
       {
         //Recurse, adding a summary block:
         if(!report_build_summary(found_set, *node, pSummary))
         {
-          std::cerr << G_STRFUNC << ": report_build_summary() failed." << std::endl;
+          std::cerr << G_STRFUNC << ": report_build_summary() failed.\n";
           return false;
         }
       }
       else
       {
-        itemsToGet.push_back( glom_sharedptr_clone(item) );
+        itemsToGet.emplace_back( glom_sharedptr_clone(item) );
       }
     }
   }
@@ -153,7 +149,7 @@ bool ReportBuilder::report_build_summary(const FoundSet& found_set, xmlpp::Eleme
     //Rows, with data:
     if(!report_build_records(found_set_used, *node, itemsToGet))
     {
-      std::cerr << G_STRFUNC << ": report_build_records() failed." << std::endl;
+      std::cerr << G_STRFUNC << ": report_build_records() failed.\n";
       return false;
     }
   }
@@ -169,31 +165,31 @@ bool ReportBuilder::report_build_groupby_children(const FoundSet& found_set, xml
   type_vecLayoutItems itemsToGet;
   for(const auto& item : group_by->m_list_items)
   {
-    std::shared_ptr<LayoutItem_GroupBy> pGroupBy = std::dynamic_pointer_cast<LayoutItem_GroupBy>(item);
+    auto pGroupBy = std::dynamic_pointer_cast<LayoutItem_GroupBy>(item);
     if(pGroupBy)
     {
       //Recurse, adding a sub-groupby block:
       if(!report_build_groupby(found_set, node, pGroupBy))
       {
-        std::cerr << G_STRFUNC << ": report_build_groupby() failed." << std::endl;
+        std::cerr << G_STRFUNC << ": report_build_groupby() failed.\n";
         return false;
       }
     }
     else
     {
-      std::shared_ptr<LayoutItem_Summary> pSummary = std::dynamic_pointer_cast<LayoutItem_Summary>(item);
+      auto pSummary = std::dynamic_pointer_cast<LayoutItem_Summary>(item);
       if(pSummary)
       {
         //Recurse, adding a summary block:
         if(!report_build_summary(found_set, node, pSummary))
         {
-          std::cerr << G_STRFUNC << ": report_build_summary() failed." << std::endl;
+          std::cerr << G_STRFUNC << ": report_build_summary() failed.\n";
           return false;
         }
       }
       else
       {
-        itemsToGet.push_back( glom_sharedptr_clone(item) );
+        itemsToGet.emplace_back( glom_sharedptr_clone(item) );
       }
     }
   }
@@ -205,7 +201,7 @@ bool ReportBuilder::report_build_groupby_children(const FoundSet& found_set, xml
     found_set_records.m_sort_clause = group_by->get_fields_sort_by();
     if(!report_build_records(found_set_records, node, itemsToGet))
     {
-      std::cerr << G_STRFUNC << ": report_build_records() failed." << std::endl;
+      std::cerr << G_STRFUNC << ": report_build_records() failed.\n";
       return false;
     }
   }
@@ -218,13 +214,13 @@ bool ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
   //Get the possible heading values.
   if(group_by->get_has_field_group_by())
   {
-    std::shared_ptr<LayoutItem_Field> field_group_by = group_by->get_field_group_by();
+    auto field_group_by = group_by->get_field_group_by();
     DbUtils::layout_item_fill_field_details(get_document(), found_set_parent.m_table_name, field_group_by);
 
     //Get the possible group values, ignoring repeats by using GROUP BY.
     const auto group_field_table_name = field_group_by->get_table_used(found_set_parent.m_table_name);
 
-    Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+    auto builder =
       Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
     builder->select_add_field(field_group_by->get_name(), group_field_table_name);
     builder->select_add_target(group_field_table_name);
@@ -236,10 +232,10 @@ bool ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
 
     builder->select_group_by( builder->add_field_id(field_group_by->get_name(), group_field_table_name) ); //TODO: And restrict to the current found set.
 
-    Glib::RefPtr<Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(builder);
+    auto datamodel = DbUtils::query_execute_select(builder);
     if(!datamodel)
     {
-      std::cerr << G_STRFUNC << ": The SQL query failed." << std::endl;
+      std::cerr << G_STRFUNC << ": The SQL query failed.\n";
       return false; 
     }
     else
@@ -276,17 +272,14 @@ bool ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
         {
           auto nodeSecondaryFields = nodeGroupBy->add_child_element("secondary_fields");
 
-          type_vecLayoutItems itemsToGet;
-          for(const auto& item : group_by->get_secondary_fields()->m_list_items)
-          {
-            itemsToGet.push_back( glom_sharedptr_clone(item) );
-          }
+          type_vecLayoutItems itemsToGet =
+            copy_with_cloned_items(group_by->get_secondary_fields()->m_list_items);
 
           if(!itemsToGet.empty())
           {
             if(!report_build_records(found_set_records, *nodeSecondaryFields, itemsToGet, true /* one record only */))
             {
-              std::cerr << G_STRFUNC << ": report_build_records() failed." << std::endl;
+              std::cerr << G_STRFUNC << ": report_build_records() failed.\n";
               return false;
             }
           }
@@ -295,7 +288,7 @@ bool ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
         //Get data and add child rows:
         if(!report_build_groupby_children(found_set_records, *nodeGroupBy, group_by))
         {
-          std::cerr << G_STRFUNC << ": report_build_groupby_children() failed." << std::endl;
+          std::cerr << G_STRFUNC << ": report_build_groupby_children() failed.\n";
           return false;
         }
       }
@@ -303,7 +296,7 @@ bool ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
   }
   else
   {
-    //There is no group-by field, so ouput all the found records.
+    //There is no group-by field, so output all the found records.
     //For instance, the user could use the GroupBy part just to specify a sort, though that would be a bit of a hack:
     auto nodeGroupBy = parent_node.add_child_element(group_by->get_report_part_id()); //We need this to create the HTML table.
     XmlUtils::set_node_attribute_value_as_decimal_double(nodeGroupBy, "border_width", group_by->get_border_width());
@@ -317,20 +310,20 @@ bool ReportBuilder::report_build_records_get_fields(const FoundSet& found_set, c
 {
   for(const auto& item : group->m_list_items)
   {
-    std::shared_ptr<LayoutItem_VerticalGroup> pVerticalGroup = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(item);
+    auto pVerticalGroup = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(item);
     if(pVerticalGroup)
     {
       if(!report_build_records_get_fields(found_set, pVerticalGroup, items))
       {
-        std::cerr << G_STRFUNC << ": report_build_records_get_fields() failed." << std::endl;
+        std::cerr << G_STRFUNC << ": report_build_records_get_fields() failed.\n";
         return false;
       }
     }
     else
     {
-      std::shared_ptr<LayoutItem_Field> pField = std::dynamic_pointer_cast<LayoutItem_Field>(item);
+      auto pField = std::dynamic_pointer_cast<LayoutItem_Field>(item);
       if(pField)
-        items.push_back(pField);
+        items.emplace_back(pField);
     }
   }
 
@@ -344,7 +337,7 @@ bool ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
     //Add Field headings:
     for(const auto& layout_item : items)
     {
-      std::shared_ptr<LayoutItem_Field> layoutitem_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
+      auto layoutitem_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
 
       //This adds a field heading (and therefore, column) for fields, or for a vertical group.
       auto nodeFieldHeading = parent_node.add_child_element("field_heading");
@@ -359,18 +352,18 @@ bool ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
     Utils::type_vecLayoutFields fieldsToGet;
     for(const auto& layout_item : items)
     {
-      std::shared_ptr<LayoutItem_Field> layoutitem_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
+      auto layoutitem_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
       if(layoutitem_field)
-        fieldsToGet.push_back(layoutitem_field);
+        fieldsToGet.emplace_back(layoutitem_field);
       else
       {
-        std::shared_ptr<LayoutItem_VerticalGroup> vertical_group = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(layout_item);
+        auto vertical_group = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(layout_item);
         if(vertical_group)
         {
           //Get all the fields in this group:
           if(!report_build_records_get_fields(found_set, vertical_group, fieldsToGet))
           {
-            std::cerr << G_STRFUNC << ": report_build_records_get_fields() failed." << std::endl;
+            std::cerr << G_STRFUNC << ": report_build_records_get_fields() failed.\n";
             return false;
           }
         }
@@ -382,15 +375,15 @@ bool ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
     if(one_record_only)
       limit = 1;
 
-    Glib::RefPtr<Gnome::Gda::SqlBuilder> sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name,
+    auto sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name,
       fieldsToGet,
       found_set.m_where_clause, std::shared_ptr<const Relationship>() /* extra_join */, found_set.m_sort_clause,
       limit);
 
-    Glib::RefPtr<Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(sql_query);
+    auto datamodel = DbUtils::query_execute_select(sql_query);
     if(!datamodel)
     {
-      std::cerr << G_STRFUNC << ": The SLQ query failed." << std::endl;
+      std::cerr << G_STRFUNC << ": The SLQ query failed.\n";
       return false; 
     }
     else
@@ -404,34 +397,34 @@ bool ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
         guint colField = 0;
         for(const auto& item : items)
         {
-          std::shared_ptr<LayoutItem_Field> field = std::dynamic_pointer_cast<LayoutItem_Field>(item);
+          auto field = std::dynamic_pointer_cast<LayoutItem_Field>(item);
           if(field)
           {
             if(!report_build_records_field(found_set, *nodeRow, field, datamodel, row, colField))
             {
-              std::cerr << G_STRFUNC << ": report_build_records_field() failed." << std::endl;
+              std::cerr << G_STRFUNC << ": report_build_records_field() failed.\n";
               return false;
             }
           }
           else
           {
-            std::shared_ptr<LayoutItem_Text> item_text = std::dynamic_pointer_cast<LayoutItem_Text>(item);
+            auto item_text = std::dynamic_pointer_cast<LayoutItem_Text>(item);
             if(item_text)
             {
               if(!report_build_records_text(found_set, *nodeRow, item_text))
               {
-                std::cerr << G_STRFUNC << ": report_build_records_text() failed." << std::endl;
+                std::cerr << G_STRFUNC << ": report_build_records_text() failed.\n";
                 return false;
               }
             }
             else
             {
-              std::shared_ptr<LayoutItem_VerticalGroup> item_verticalgroup = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(item);
+              auto item_verticalgroup = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(item);
               if(item_verticalgroup)
               {
                 if(!report_build_records_vertical_group(found_set, *nodeRow, item_verticalgroup, datamodel, row, colField))
                 {
-                  std::cerr << G_STRFUNC << ": report_build_records_vertical_group() failed." << std::endl;
+                  std::cerr << G_STRFUNC << ": report_build_records_vertical_group() failed.\n";
                   return false;
                 }
               }
@@ -466,15 +459,15 @@ bool ReportBuilder::report_build_records_field(const FoundSet& found_set, xmlpp:
   {
     //In this case it can only be a system preferences field.
     //So let's get that data here:
-    Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
+    auto builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
     builder->set_table(field->get_table_used(found_set.m_table_name));
     builder->select_add_field(field->get_name(), found_set.m_table_name);
     builder->select_set_limit(1);
-    Glib::RefPtr<Gnome::Gda::DataModel> datamodel_syspref = DbUtils::query_execute_select(builder);
+    auto datamodel_syspref = DbUtils::query_execute_select(builder);
 
     if(!datamodel_syspref)
     {
-      std::cerr << G_STRFUNC << ": The SQL query failed." << std::endl;
+      std::cerr << G_STRFUNC << ": The SQL query failed.\n";
       return false;
     }
 
@@ -541,34 +534,34 @@ bool ReportBuilder::report_build_records_vertical_group(const FoundSet& found_se
 
   for(const auto& item : group->m_list_items)
   {
-    std::shared_ptr<LayoutItem_VerticalGroup> pVerticalGroup = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(item);
+    auto pVerticalGroup = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(item);
     if(pVerticalGroup)
     {
       if(!report_build_records_vertical_group(found_set, *nodeGroupVertical, pVerticalGroup, datamodel, row, field_index))
       {
-        std::cerr << G_STRFUNC << ": report_build_records_vertical_group() failed." << std::endl;
+        std::cerr << G_STRFUNC << ": report_build_records_vertical_group() failed.\n";
         return false;
       }
     }
     else
     {
-      std::shared_ptr<LayoutItem_Field> pField = std::dynamic_pointer_cast<LayoutItem_Field>(item);
+      auto pField = std::dynamic_pointer_cast<LayoutItem_Field>(item);
       if(pField)
       {
         if(!report_build_records_field(found_set, *nodeGroupVertical, pField, datamodel, row, field_index, true /* vertical, so we get a row for each field too. */))
         {
-          std::cerr << G_STRFUNC << ": report_build_records_field() failed." << std::endl;
+          std::cerr << G_STRFUNC << ": report_build_records_field() failed.\n";
           return false;
         }
       }
       else
       {
-        std::shared_ptr<LayoutItem_Text> pText = std::dynamic_pointer_cast<LayoutItem_Text>(item);
+        auto pText = std::dynamic_pointer_cast<LayoutItem_Text>(item);
         if(pText)
         {
           if(!report_build_records_text(found_set, *nodeGroupVertical, pText, true))
           {
-            std::cerr << G_STRFUNC << ": report_build_records_text() failed." << std::endl;
+            std::cerr << G_STRFUNC << ": report_build_records_text() failed.\n";
             return false;
           }
         }
@@ -588,7 +581,7 @@ std::string ReportBuilder::report_build_and_save(const FoundSet& found_set, cons
   const auto temp_uri = Utils::get_temp_file_uri("glom_printout", "html");
   std::cout << G_STRFUNC << ": temp_uri=" << temp_uri << std::endl;
 
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(temp_uri);
+  auto file = Gio::File::create_for_uri(temp_uri);
   Glib::RefPtr<Gio::FileOutputStream> stream;
 
   //Create the file if it does not already exist:
@@ -636,12 +629,12 @@ Glib::ustring ReportBuilder::report_build(const FoundSet& found_set, const std::
   //Create a DOM Document with the XML:
   xmlpp::DomParser dom_parser;;
 
-  auto pDocument = dom_parser.get_document();
-  auto nodeRoot = pDocument->get_root_node();
+  auto document = dom_parser.get_document();
+  auto nodeRoot = document->get_root_node();
   if(!nodeRoot)
   {
     //Add it if it isn't there already:
-    nodeRoot = pDocument->create_root_node("report_print");
+    nodeRoot = document->create_root_node("report_print");
   }
 
   Glib::ustring table_title = get_document()->get_table_title(found_set.m_table_name, m_locale_id);
@@ -661,50 +654,50 @@ Glib::ustring ReportBuilder::report_build(const FoundSet& found_set, const std::
 
   type_vecLayoutItems itemsToGet_TopLevel;
 
-  const std::shared_ptr<const LayoutGroup> group = report->get_layout_group();
+  const auto group = report->get_layout_group();
   for(const auto& pPart : group->m_list_items)
   {
     //The Group, and the details for each record in the group:
-    std::shared_ptr<LayoutItem_GroupBy> pGroupBy = std::dynamic_pointer_cast<LayoutItem_GroupBy>(pPart);
+    auto pGroupBy = std::dynamic_pointer_cast<LayoutItem_GroupBy>(pPart);
     if(pGroupBy)
     {
       if(!report_build_groupby(found_set, *nodeParent, pGroupBy))
       {
-        std::cerr << G_STRFUNC << ": report_build_groupby() failed." << std::endl;
+        std::cerr << G_STRFUNC << ": report_build_groupby() failed.\n";
         return Glib::ustring();
       }
     }
     else
     {
-      std::shared_ptr<LayoutItem_Summary> pSummary = std::dynamic_pointer_cast<LayoutItem_Summary>(pPart);
+      auto pSummary = std::dynamic_pointer_cast<LayoutItem_Summary>(pPart);
       if(pSummary)
       {
         //Recurse, adding a summary block:
         if(!report_build_summary(found_set, *nodeParent, pSummary))
         {
-          std::cerr << G_STRFUNC << ": report_build_summary() failed." << std::endl;
+          std::cerr << G_STRFUNC << ": report_build_summary() failed.\n";
           return Glib::ustring();
         }
       }
       else
       {
-        std::shared_ptr<LayoutGroup> pGroup = std::dynamic_pointer_cast<LayoutGroup>(pPart);
+        auto pGroup = std::dynamic_pointer_cast<LayoutGroup>(pPart);
         if(pGroup)
         {
-          std::shared_ptr<LayoutItem_Header> pHeader = std::dynamic_pointer_cast<LayoutItem_Header>(pPart);
-          std::shared_ptr<LayoutItem_Footer> pFooter = std::dynamic_pointer_cast<LayoutItem_Footer>(pPart);
+          auto pHeader = std::dynamic_pointer_cast<LayoutItem_Header>(pPart);
+          auto pFooter = std::dynamic_pointer_cast<LayoutItem_Footer>(pPart);
           if(pHeader || pFooter)
           {
             //Recurse, adding a summary block:
             if(!report_build_headerfooter(found_set, *nodeParent, pGroup))
             {
-              std::cerr << G_STRFUNC << ": report_build_headerfooter() failed." << std::endl;
+              std::cerr << G_STRFUNC << ": report_build_headerfooter() failed.\n";
               return Glib::ustring();
             }
           }
         }
         else
-          itemsToGet_TopLevel.push_back( glom_sharedptr_clone(pPart) );
+          itemsToGet_TopLevel.emplace_back( glom_sharedptr_clone(pPart) );
       }
     }
   }
@@ -715,12 +708,12 @@ Glib::ustring ReportBuilder::report_build(const FoundSet& found_set, const std::
     auto nodeGroupBy = nodeParent->add_child_element("ungrouped_records");
     if(!report_build_records(found_set, *nodeGroupBy, itemsToGet_TopLevel))
     {
-      std::cerr << G_STRFUNC << ": report_build_records() failed." << std::endl;
+      std::cerr << G_STRFUNC << ": report_build_records() failed.\n";
       return Glib::ustring();
     }
   }
 
-  return GlomXslUtils::transform(*pDocument, "print_report_to_html.xsl");
+  return GlomXslUtils::transform(*document, "print_report_to_html.xsl");
 }
 
 static void fill_standard_list_report_fill(const std::shared_ptr<Report>& report, const std::shared_ptr<const LayoutGroup>& layout_group)
@@ -741,7 +734,7 @@ static void fill_standard_list_report_fill(const std::shared_ptr<Report>& report
   }
 }
 
-std::shared_ptr<Report> ReportBuilder::create_standard_list_report(const Document* document, const Glib::ustring& table_name)
+std::shared_ptr<Report> ReportBuilder::create_standard_list_report(const std::shared_ptr<const Document>& document, const Glib::ustring& table_name)
 {
   auto result = std::make_shared<Report>();
   result->set_name("list");
@@ -759,12 +752,12 @@ std::shared_ptr<Report> ReportBuilder::create_standard_list_report(const Documen
   return result;
 }
 
-void ReportBuilder::set_document(Document* document)
+void ReportBuilder::set_document(const std::shared_ptr<Document>& document)
 {
   m_document = document;
 }
 
-Document* ReportBuilder::get_document()
+std::shared_ptr<Document> ReportBuilder::get_document()
 {
   return m_document;
 }
