@@ -183,13 +183,13 @@ Glib::ustring get_po_context_for_item(const std::shared_ptr<const TranslatableIt
   return result;
 }
 
-bool write_pot_file(Document* document, const Glib::ustring& pot_file_uri)
+bool write_pot_file(const std::shared_ptr<Document>& document, const Glib::ustring& pot_file_uri)
 {
   //A .pot file 
   return write_translations_to_po_file(document, pot_file_uri, Glib::ustring() /* no locale */);
 }
 
-bool write_translations_to_po_file(Document* document, const Glib::ustring& po_file_uri, const Glib::ustring& translation_locale, const Glib::ustring& locale_name)
+bool write_translations_to_po_file(const std::shared_ptr<Document>& document, const Glib::ustring& po_file_uri, const Glib::ustring& translation_locale, const Glib::ustring& locale_name)
 {
   std::string filename;
 
@@ -212,7 +212,7 @@ bool write_translations_to_po_file(Document* document, const Glib::ustring& po_f
 
   for(const auto& the_pair : document->get_translatable_items())
   {
-    std::shared_ptr<TranslatableItem> item = the_pair.first;
+    auto item = the_pair.first;
     if(!item)
       continue;
 
@@ -244,7 +244,7 @@ bool write_translations_to_po_file(Document* document, const Glib::ustring& po_f
   return true;
 }
 
-bool import_translations_from_po_file(Document* document, const Glib::ustring& po_file_uri, const Glib::ustring& translation_locale)
+bool import_translations_from_po_file(const std::shared_ptr<Document>& document, const Glib::ustring& po_file_uri, const Glib::ustring& translation_locale)
 {
   std::string filename;
 
