@@ -212,7 +212,7 @@ bool Box_Data_Calendar_Related::fill_from_database()
 
     auto sql_query = Utils::build_sql_select_with_where_clause(m_found_set.m_table_name, m_FieldsShown, where_clause, m_found_set.m_extra_join, m_found_set.m_sort_clause);
     //std::cout << "DEBUG: sql_query=" << sql_query << std::endl;
-    Glib::RefPtr<const Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(sql_query);
+    auto datamodel = DbUtils::query_execute_select(sql_query);
     if(!(datamodel))
       return true;
 
