@@ -37,14 +37,14 @@ namespace Glom
 class Box_Data_Details : public Box_Data
 {
 public:
-  Box_Data_Details(bool bWithNavButtons = true);
+  explicit Box_Data_Details(bool bWithNavButtons = true);
   virtual ~Box_Data_Details();
 
   bool init_db_details(const FoundSet& found_set, const Glib::ustring& layout_platform, const Gnome::Gda::Value& primary_key_value);
-  virtual bool refresh_data_from_database_with_primary_key(const Gnome::Gda::Value& primary_key_value);
-  virtual bool refresh_data_from_database_blank();
+  bool refresh_data_from_database_with_primary_key(const Gnome::Gda::Value& primary_key_value);
+  bool refresh_data_from_database_blank();
 
-  virtual void print_layout();
+  void print_layout() override;
 
 
   //Signals:
@@ -76,22 +76,21 @@ protected:
 
   //Implementations of pure virtual methods from Base_DB_Table_Data:
 public:
-  virtual Gnome::Gda::Value get_primary_key_value_selected() const; //Value in the primary key's cell.
+  Gnome::Gda::Value get_primary_key_value_selected() const override; //Value in the primary key's cell.
 
 protected:
-  virtual void set_primary_key_value(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& value);
-  virtual Gnome::Gda::Value get_primary_key_value(const Gtk::TreeModel::iterator& row) const; //Actual primary key value of this record.
+  void set_primary_key_value(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& value) override;
+  Gnome::Gda::Value get_primary_key_value(const Gtk::TreeModel::iterator& row) const override; //Actual primary key value of this record.
 
-  virtual Gnome::Gda::Value get_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field) const;
-  virtual void set_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
-  virtual void set_entered_field_data(const Gtk::TreeModel::iterator& row, const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
+  Gnome::Gda::Value get_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field) const override;
+  void set_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value) override;
+  void set_entered_field_data(const Gtk::TreeModel::iterator& row, const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value) override;
 
 
-  virtual bool fill_from_database() override;
-  virtual void create_layout();
-  //virtual void fill_related();
+  bool fill_from_database() override;
+  void create_layout() override;
 
-  virtual std::shared_ptr<Field> get_field_primary_key() const;
+  std::shared_ptr<Field> get_field_primary_key() const override;
   void set_found_set_from_primary_key_value();
 
 private:
@@ -107,17 +106,17 @@ private:
 
 protected:
 
-  virtual void on_userlevel_changed(AppState::userlevels user_level) override;
+  void on_userlevel_changed(AppState::userlevels user_level) override;
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  virtual void on_flowtable_layout_changed();
+  void on_flowtable_layout_changed();
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   //Signal handler: The last 2 args are bind-ed.
-  virtual void on_related_record_added(Gnome::Gda::Value key_value, Glib::ustring strFromKeyName);
+  void on_related_record_added(Gnome::Gda::Value key_value, Glib::ustring strFromKeyName);
 
   //Signal handler: The last arg is bind-ed.
-  //virtual void on_related_user_requested_details(Gnome::Gda::Value key_value, Glib::ustring table_name);
+  //void on_related_user_requested_details(Gnome::Gda::Value key_value, Glib::ustring table_name);
 
   //This is virtual so it can be overriden in Box_Data_Details_Find.
   virtual void on_flowtable_field_edited(const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& value);
@@ -129,15 +128,15 @@ protected:
 
   void on_flowtable_script_button_clicked(const std::shared_ptr<const LayoutItem_Button>& layout_item);
 
-  virtual void recalculate_fields_for_related_records(const Glib::ustring& relationship_name);
+  void recalculate_fields_for_related_records(const Glib::ustring& relationship_name);
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  virtual Dialog_Layout* create_layout_dialog() const override;
-  virtual void prepare_layout_dialog(Dialog_Layout* dialog) override;
+  Dialog_Layout* create_layout_dialog() const override;
+  void prepare_layout_dialog(Dialog_Layout* dialog) override;
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   std::shared_ptr<Field> m_field_primary_key;
- virtual void show_all_vfunc() override;
+ void show_all_vfunc() override;
 
   Gnome::Gda::Value m_primary_key_value;
 
