@@ -42,14 +42,6 @@ ComboAsRadioButtons::ComboAsRadioButtons()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   setup_menu(this);
 #endif // !GLOM_ENABLE_CLIENT_ONLY
-
-  init();
-}
-
-void ComboAsRadioButtons::init()
-{
-  //if(m_glom_type == Field::glom_field_type::NUMERIC)
-   // get_entry()->set_alignment(1.0); //Align numbers to the right.
 }
 
 void ComboAsRadioButtons::set_choices_with_second(const type_list_values_with_second& list_values)
@@ -62,7 +54,7 @@ void ComboAsRadioButtons::set_choices_with_second(const type_list_values_with_se
   }
   m_map_buttons.clear();
 
-  std::shared_ptr<LayoutItem_Field> layout_item =
+  auto layout_item =
     std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
   const auto format = layout_item->get_formatting_used();
   std::shared_ptr<const Relationship> choice_relationship;
@@ -88,11 +80,11 @@ void ComboAsRadioButtons::set_choices_with_second(const type_list_values_with_se
       const auto extra_values = the_pair.second;
       if(layout_choice_extra && !extra_values.empty())
       {
-        type_list_values::const_iterator iterValues = extra_values.begin();
+        auto iterValues = extra_values.begin();
         for(const auto& item : extra_fields)
         {
           if(iterValues != extra_values.end()) {
-            const std::shared_ptr<const LayoutItem_Field> item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
+            const auto item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
             if(item_field)
             {
               const Gnome::Gda::Value value = *iterValues; //TODO: Use a vector instead?
@@ -134,7 +126,7 @@ void ComboAsRadioButtons::set_choices_fixed(const Formatting::type_list_values&
   Gtk::RadioButton::Group group;
   for(const auto& choicevalue : list_values)
   {
-    std::shared_ptr<const LayoutItem_Field> layout_item = std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
+    auto layout_item = std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
     if(layout_item)
     {
       Gnome::Gda::Value value;
@@ -153,7 +145,7 @@ void ComboAsRadioButtons::set_choices_fixed(const Formatting::type_list_values&
   }
 }
 
-void ComboAsRadioButtons::set_choices_related(const Document* document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value)
+void ComboAsRadioButtons::set_choices_related(const std::shared_ptr<const Document>& document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value)
 {
   const Utils::type_list_values_with_second list_values =
     Utils::get_choice_values(document, layout_field, foreign_key_value);
@@ -179,7 +171,7 @@ void ComboAsRadioButtons::check_for_change()
   //Validate the input:
   bool success = false;
 
-  std::shared_ptr<const LayoutItem_Field> layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
+  auto layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
   const auto value = Conversions::parse_value(layout_item->get_glom_type(), new_text, layout_item->get_formatting_used().m_numeric_format, success);
 
   if(success)
@@ -203,7 +195,7 @@ void ComboAsRadioButtons::check_for_change()
 
 void ComboAsRadioButtons::set_value(const Gnome::Gda::Value& value)
 {
-  std::shared_ptr<const LayoutItem_Field> layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
+  auto layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
   if(!layout_item)
     return;
 
@@ -236,7 +228,7 @@ void ComboAsRadioButtons::set_text(const Glib::ustring& text)
 
 Gnome::Gda::Value ComboAsRadioButtons::get_value() const
 {
-  std::shared_ptr<const LayoutItem_Field> layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
+  auto layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
   bool success = false;
 
   const auto text = get_text();
@@ -261,7 +253,7 @@ Glib::ustring ComboAsRadioButtons::get_text() const
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void ComboAsRadioButtons::show_context_menu(GdkEventButton *button_event)
 {
-  std::cout << "ComboAsRadioButtons::show_context_menu()" << std::endl;
+  std::cout << "ComboAsRadioButtons::show_context_menu()\n";
   auto pApp = get_appwindow();
   if(pApp)
   {
