@@ -39,21 +39,12 @@ namespace DataWidgetChildren
 
 ComboChoices::ComboChoices()
 {
-  init();
 }
 
-void ComboChoices::init()
-{
-}
-
-ComboChoices::~ComboChoices()
-{
-}
-
-bool ComboChoices::refresh_data_from_database_with_foreign_key(const Document* /* document */, const Gnome::Gda::Value& /* foreign_key_value */)
+bool ComboChoices::refresh_data_from_database_with_foreign_key(const std::shared_ptr<const Document>& /* document */, const Gnome::Gda::Value& /* foreign_key_value */)
 {
   /** TODO:
-  std::shared_ptr<LayoutItem_Field> layout_item =
+  auto layout_item =
     std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
 
   if(!layout_item || Conversions::value_is_empty(foreign_key_value))
@@ -73,17 +64,17 @@ bool ComboChoices::refresh_data_from_database_with_foreign_key(const Document* /
   return true;
 }
 
-void ComboChoices::set_choices_related(const Document* /* document */, const std::shared_ptr<const LayoutItem_Field>& /* layout_field */, const Gnome::Gda::Value& /* foreign_key_value */)
+void ComboChoices::set_choices_related(const std::shared_ptr<const Document>& /* document */, const std::shared_ptr<const LayoutItem_Field>& /* layout_field */, const Gnome::Gda::Value& /* foreign_key_value */)
 {
   /* TODO:
   type_list_values_with_second list_values;
 
-  std::shared_ptr<LayoutItem_Field> layout_item =
+  auto layout_item =
     std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
   if(layout_item)
   {
     bool choice_show_all = false;
-    const std::shared_ptr<const Relationship> choice_relationship =
+    const auto choice_relationship =
       layout_item->get_formatting_used().get_choices_related_relationship(choice_show_all);
 
     //Set the values now because if it will be the same regardless of the foreign key value.
