@@ -43,8 +43,6 @@ public:
   ///You must call set_layout_item() to specify the field type and formatting of the main column.
   explicit ComboChoices(const std::shared_ptr<LayoutItem_Field>& field_second);
 
-  virtual ~ComboChoices();
-
   /** Set a list of choice values, for instance for a list of custom choices.
    * You should first call set_layout_item() to provide formatting details.
    */
@@ -58,16 +56,15 @@ public:
    *
    * See also refresh_data_from_database_with_foreign_key().
    */
-  virtual void set_choices_related(const Document* document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value) = 0;
+  virtual void set_choices_related(const std::shared_ptr<const Document>& document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value) = 0;
 
   /** Update a choices widget's list of related choices if a relevant value in its parent table has changed.
    *
    * @param foreign_key_value: The value that should be found in this table.
    */
-  bool refresh_data_from_database_with_foreign_key(const Document* document, const Gnome::Gda::Value& foreign_key_value);
+  bool refresh_data_from_database_with_foreign_key(const std::shared_ptr<const Document>& document, const Gnome::Gda::Value& foreign_key_value);
 
 protected:
-  void init();
 
   //Gnome::Gda::Value m_value; //The last-stored value. We have this because the displayed value might be unparseable.
 };
