@@ -42,7 +42,7 @@ DbTreeModelWithExtraText::DbTreeModelWithExtraText(const FoundSet& found_set, co
   int column_index = 0;
   for(const auto& item : layout_items)
   {
-    const std::shared_ptr<const LayoutItem_Field> item_field = 
+    const auto item_field = 
       std::dynamic_pointer_cast<const LayoutItem_Field>(item);
     if(item_field)
     {
@@ -60,7 +60,7 @@ DbTreeModelWithExtraText::DbTreeModelWithExtraText(const FoundSet& found_set, co
   }
   else
   {
-    std::cerr << G_STRFUNC << ": The first field was found in the list." << std::endl;
+    std::cerr << G_STRFUNC << ": The first field was found in the list.\n";
   }
 }
 
@@ -105,7 +105,7 @@ void DbTreeModelWithExtraText::get_value_vfunc(const TreeModel::iterator& iter,
     
     if(m_column_index_first == -1)
     {
-      std::cerr << G_STRFUNC << ": m_column_index_first is not set." << std::endl;
+      std::cerr << G_STRFUNC << ": m_column_index_first is not set.\n";
       //TODO: This then causes a crash later. Find out why.
     }
     else
