@@ -40,10 +40,6 @@ Dialog_InitialPassword::Dialog_InitialPassword(BaseObjectType* cobject, const Gl
   builder->get_widget("entry_password_confirm", m_entry_password_confirm);
 }
 
-Dialog_InitialPassword::~Dialog_InitialPassword()
-{
-}
-
 Glib::ustring Dialog_InitialPassword::get_user() const
 {
   return m_entry_user->get_text();
@@ -72,7 +68,7 @@ void Dialog_InitialPassword::load_from_document()
     m_entry_user->set_text(user);
   }
   else
-    std::cerr << G_STRFUNC << ": no document" << std::endl;
+    std::cerr << G_STRFUNC << ": no document\n";
 
 }
 
