@@ -63,7 +63,7 @@ Dialog_ChooseField::Dialog_ChooseField(BaseObjectType* cobject, const Glib::RefP
 
     m_treeview->signal_row_activated().connect( sigc::mem_fun(*this, &Dialog_ChooseField::on_row_activated) );
 
-    Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview->get_selection();
+    auto refSelection = m_treeview->get_selection();
     if(refSelection)
     {
       refSelection->signal_changed().connect( sigc::mem_fun(*this, &Dialog_ChooseField::on_treeview_selection_changed) );
@@ -73,11 +73,7 @@ Dialog_ChooseField::Dialog_ChooseField(BaseObjectType* cobject, const Glib::RefP
   show_all_children();
 }
 
-Dialog_ChooseField::~Dialog_ChooseField()
-{
-}
-
-void Dialog_ChooseField::set_document(Document* document, const Glib::ustring& table_name, const std::shared_ptr<const LayoutItem_Field>& field)
+void Dialog_ChooseField::set_document(const std::shared_ptr<Document>& document, const Glib::ustring& table_name, const std::shared_ptr<const LayoutItem_Field>& field)
 {
   set_document(document, table_name);
 
@@ -97,7 +93,7 @@ void Dialog_ChooseField::set_document(Document* document, const Glib::ustring& t
   //If one start field was specified, then multiple selection would not make 
   //much sense. The caller probably wants single selection.
   //Make this explicit in the API if that is not always suitable.
-  Glib::RefPtr<Gtk::TreeView::Selection> selection = m_treeview->get_selection();
+  auto selection = m_treeview->get_selection();
   selection->set_mode((field && !(field->get_name().empty()))
     ? Gtk::SELECTION_SINGLE : Gtk::SELECTION_MULTIPLE); 
    
@@ -128,7 +124,7 @@ void Dialog_ChooseField::set_document(Document* document, const Glib::ustring& t
   }
 }
 
-void Dialog_ChooseField::set_document(Document* document, const Glib::ustring& table_name)
+void Dialog_ChooseField::set_document(const std::shared_ptr<Document>& document, const Glib::ustring& table_name)
 {
   m_document = document;
   m_table_name = table_name;
@@ -136,15 +132,15 @@ void Dialog_ChooseField::set_document(Document* document, const Glib::ustring& t
 
   if(!m_document)
   {
-    std::cerr << G_STRFUNC << ": document is null" << std::endl;
+    std::cerr << G_STRFUNC << ": document is null\n";
   }
 
   if(table_name.empty())
   {
-    std::cerr << G_STRFUNC << ": table_name is empty" << std::endl;
+    std::cerr << G_STRFUNC << ": table_name is empty\n";
   }
   
-  Glib::RefPtr<Gtk::TreeView::Selection> selection = m_treeview->get_selection();
+  auto selection = m_treeview->get_selection();
   selection->set_mode(Gtk::SELECTION_MULTIPLE); 
    
 
@@ -190,7 +186,7 @@ void Dialog_ChooseField::select_item(const Field& field)
     if(field_item.get_name() == field.get_name())
     {
       //Select the item:
-      Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview->get_selection();
+      auto refTreeSelection = m_treeview->get_selection();
       if(refTreeSelection)
         refTreeSelection->select(iter);
     }
@@ -232,14 +228,14 @@ Dialog_ChooseField::type_list_field_items Dialog_ChooseField::get_fields_chosen(
   type_list_field_items list_fields;
 
   //Field:
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview->get_selection();
+  auto refTreeSelection = m_treeview->get_selection();
   if(!refTreeSelection)
     return list_fields;
     
   //Relationship:
   //Note that a null relationship means that the parent table was selected instead.
   std::shared_ptr<Relationship> related_relationship;
-  std::shared_ptr<Relationship> relationship = m_combo_relationship->get_selected_relationship(related_relationship);
+  auto relationship = m_combo_relationship->get_selected_relationship(related_relationship);
 
   for(const auto& path : refTreeSelection->get_selected_rows())
   {
@@ -250,7 +246,7 @@ Dialog_ChooseField::type_list_field_items Dialog_ChooseField::get_fields_chosen(
 
     // Setup a LayoutItem_Field for the Field, 
     // so is_same_field() can work:
-    std::shared_ptr<LayoutItem_Field> field = std::make_shared<LayoutItem_Field>();
+    auto field = std::make_shared<LayoutItem_Field>();
     field->set_relationship(relationship);
     field->set_related_relationship(related_relationship);
       
@@ -272,7 +268,7 @@ Dialog_ChooseField::type_list_field_items Dialog_ChooseField::get_fields_chosen(
 
     field->set_name(row[m_ColumnsFields.m_col_name]);
     
-    list_fields.push_back(field);
+    list_fields.emplace_back(field);
   }
 
   return list_fields;
@@ -292,7 +288,7 @@ void Dialog_ChooseField::on_checkbutton_related_relationships_toggled()
 
   //Preserve the selection:
   std::shared_ptr<Relationship> related_relationship;
-  std::shared_ptr<Relationship> relationship = m_combo_relationship->get_selected_relationship(related_relationship);
+  auto relationship = m_combo_relationship->get_selected_relationship(related_relationship);
 
   //Refresh the list, hiding or showing the child relationships:
   m_combo_relationship->set_relationships(m_document, m_table_name, show_related_relationships);
@@ -302,19 +298,19 @@ void Dialog_ChooseField::on_checkbutton_related_relationships_toggled()
 
 void Dialog_ChooseField::on_combo_relationship_changed()
 {
-  std::shared_ptr<Relationship> relationship = m_combo_relationship->get_selected_relationship();
+  auto relationship = m_combo_relationship->get_selected_relationship();
 
-  auto pDocument = m_document;
-  if(pDocument)
+  auto document = m_document;
+  if(document)
   {
     //Show the list of fields from this relationship:
 
     Document::type_vec_fields vecFields;
     if(!relationship)
-      vecFields = pDocument->get_table_fields(m_table_name);
+      vecFields = document->get_table_fields(m_table_name);
     else
     {
-      vecFields = pDocument->get_table_fields(relationship->get_to_table());
+      vecFields = document->get_table_fields(relationship->get_to_table());
     }
 
     m_model->clear();
@@ -334,7 +330,7 @@ void Dialog_ChooseField::on_combo_relationship_changed()
 void Dialog_ChooseField::on_treeview_selection_changed()
 {
 #if 0
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview->get_selection();
+  auto refSelection = m_treeview->get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
