@@ -39,15 +39,14 @@ public:
   static const bool glade_developer;
   
   Dialog_ChooseField(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
-  virtual ~Dialog_ChooseField();
 
   /**
    * @param document The document, so that the dialog can load the previous layout, and save changes.
    * @param table_name The table name.
    * @param field The starting field information.
    */
-  void set_document(Document* document, const Glib::ustring& table_name, const std::shared_ptr<const LayoutItem_Field>& field);
-  void set_document(Document* document, const Glib::ustring& table_name);
+  void set_document(const std::shared_ptr<Document>& document, const Glib::ustring& table_name, const std::shared_ptr<const LayoutItem_Field>& field);
+  void set_document(const std::shared_ptr<Document>& document, const Glib::ustring& table_name);
 
 
   //void select_item(const std::shared_ptr<const Field>& field);
@@ -88,7 +87,7 @@ private:
   Glib::ustring m_table_name;
   std::shared_ptr<LayoutItem_Field> m_start_field; //stored so we can preserve extra information that's not changed here.
 
-  Document* m_document;
+  std::shared_ptr<Document> m_document;
 };
 
 } //namespace Glom
