@@ -100,12 +100,7 @@ Dialog_Layout_Calendar_Related::Dialog_Layout_Calendar_Related(BaseObjectType* c
     m_label_table_title->hide(); // We don't use this (it's from the base class).
 }
 
-Dialog_Layout_Calendar_Related::~Dialog_Layout_Calendar_Related()
-{
-}
-
-
-void Dialog_Layout_Calendar_Related::init_with_portal(const Glib::ustring& layout, const Glib::ustring& layout_platform, Document* document, const std::shared_ptr<const LayoutItem_CalendarPortal>& portal)
+void Dialog_Layout_Calendar_Related::init_with_portal(const Glib::ustring& layout, const Glib::ustring& layout_platform, const std::shared_ptr<Document>& document, const std::shared_ptr<const LayoutItem_CalendarPortal>& portal)
 {
   m_portal = glom_sharedptr_clone(portal);
 
@@ -116,7 +111,7 @@ void Dialog_Layout_Calendar_Related::init_with_portal(const Glib::ustring& layou
   init_with_tablename(layout, layout_platform, document, from_table);
 }
 
-void Dialog_Layout_Calendar_Related::init_with_tablename(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document* document, const Glib::ustring& from_table)
+void Dialog_Layout_Calendar_Related::init_with_tablename(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, const std::shared_ptr<Document>& document, const Glib::ustring& from_table)
 {
   if(!m_portal)
   {
@@ -168,13 +163,13 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
     }
 
     //Set the table name and title:
-    //std::shared_ptr<LayoutItem_CalendarPortal> portal_temp = m_portal;
+    //auto portal_temp = m_portal;
     m_combo_relationship->set_selected_relationship(m_portal->get_relationship(), m_portal->get_related_relationship());
 
     Document::type_list_layout_groups mapGroups;
     if(m_portal)
     {
-      mapGroups.push_back(m_portal);
+      mapGroups.emplace_back(m_portal);
       document->fill_layout_field_details(related_table_name, mapGroups); //Update with full field information.
     }
 
@@ -185,12 +180,12 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
 
     for(const auto& group : mapGroups)
     {
-      std::shared_ptr<const LayoutGroup> portal = std::dynamic_pointer_cast<const LayoutItem_CalendarPortal>(group);
+      auto portal = std::dynamic_pointer_cast<const LayoutItem_CalendarPortal>(group);
       if(portal)
       {
         for(const auto& item : group->m_list_items)
         {
-          std::shared_ptr<const LayoutGroup> groupInner = std::dynamic_pointer_cast<const LayoutGroup>(item);
+          auto groupInner = std::dynamic_pointer_cast<const LayoutGroup>(item);
 
           if(groupInner)
             add_group(Gtk::TreeModel::iterator() /* null == top-level */, groupInner);
@@ -214,7 +209,7 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
   bool navigation_is_automatic = false;
   if(m_portal->get_navigation_type() == LayoutItem_Portal::navigation_type::SPECIFIC)
   {
-    std::shared_ptr<UsesRelationship> navrel = m_portal->get_navigation_relationship_specific();
+    auto navrel = m_portal->get_navigation_relationship_specific();
     //std::cout << "debug navrel=" << navrel->get_relationship()->get_name() << std::endl;
     m_combo_navigation_specify->set_selected_relationship(navrel->get_relationship(), navrel->get_related_relationship());
   }
@@ -249,9 +244,9 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
 
   m_label_navigation_automatic->set_text(automatic_navigation_description);
 
-  std::shared_ptr<Field> debugfield = m_portal->get_date_field();
+  auto debugfield = m_portal->get_date_field();
   if(!debugfield)
-    std::cout << "debug: " << G_STRFUNC << ": date field is NULL" << std::endl;
+    std::cout << "debug: " << G_STRFUNC << ": date field is NULL\n";
   else
     std::cout << "debug: " << G_STRFUNC << ": date field:" << debugfield->get_name() << std::endl;
 
@@ -294,7 +289,7 @@ void Dialog_Layout_Calendar_Related::save_to_document()
       std::shared_ptr<Relationship> rel, rel_related;
       rel = m_combo_navigation_specify->get_selected_relationship(rel_related);
 
-      std::shared_ptr<UsesRelationship> uses_rel = std::make_shared<UsesRelationship>();
+      auto uses_rel = std::make_shared<UsesRelationship>();
       uses_rel->set_relationship(rel);
       uses_rel->set_related_relationship(rel_related);
 
@@ -304,16 +299,16 @@ void Dialog_Layout_Calendar_Related::save_to_document()
     }
     else
     {
-      //std::cout << "debug: set_navigation_relationship_specific(false, none)" << std::endl;
+      //std::cout << "debug: set_navigation_relationship_specific(false, none)\n";
       std::shared_ptr<UsesRelationship> none;
       m_portal->set_navigation_relationship_specific(none);
     }
 
     m_portal->set_date_field( m_combobox_date_field->get_selected_field() );
 
-    std::shared_ptr<Field> debugfield = m_portal->get_date_field();
+    auto debugfield = m_portal->get_date_field();
     if(!debugfield)
-      std::cout << "debug: " << G_STRFUNC << ": date field is NULL" << std::endl;
+      std::cout << "debug: " << G_STRFUNC << ": date field is NULL\n";
     else
       std::cout << "debug: " << G_STRFUNC << ": date field:" << debugfield->get_name() << std::endl;
   }
@@ -330,7 +325,7 @@ void Dialog_Layout_Calendar_Related::on_combo_relationship_changed()
     return;
 
   std::shared_ptr<Relationship> relationship_related;
-  std::shared_ptr<Relationship> relationship = m_combo_relationship->get_selected_relationship(relationship_related);
+  auto relationship = m_combo_relationship->get_selected_relationship(relationship_related);
   if(relationship)
   {
     //Clear the list of fields if the relationship has changed, because the fields could not possible be correct for the new table:
@@ -356,7 +351,7 @@ void Dialog_Layout_Calendar_Related::on_combo_relationship_changed()
 
 std::shared_ptr<Relationship> Dialog_Layout_Calendar_Related::get_relationship() const
 {
-  std::cout << "debug: I wonder if this function is used." << std::endl;
+  std::cout << "debug: I wonder if this function is used.\n";
   return m_combo_relationship->get_selected_relationship();
 }
 
@@ -390,7 +385,7 @@ void Dialog_Layout_Calendar_Related::on_button_add_field()
       row[m_model_items->m_columns.m_col_layout_item] = field;
 
       //Scroll to, and select, the new row:
-      Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+      auto refTreeSelection = m_treeview_fields->get_selection();
       if(refTreeSelection)
         refTreeSelection->select(iter);
 
@@ -401,7 +396,7 @@ void Dialog_Layout_Calendar_Related::on_button_add_field()
 
 void Dialog_Layout_Calendar_Related::on_button_edit()
 {
-  Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+  auto refTreeSelection = m_treeview_fields->get_selection();
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
@@ -410,10 +405,10 @@ void Dialog_Layout_Calendar_Related::on_button_edit()
     {
       Gtk::TreeModel::Row row = *iter;
       std::shared_ptr<LayoutItem> layout_item = row[m_model_items->m_columns.m_col_layout_item];
-      std::shared_ptr<LayoutItem_Field> field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
+      auto field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
 
       //Get the chosen field:
-      std::shared_ptr<LayoutItem_Field> field_chosen = offer_field_list_select_one_field(field, m_portal->get_table_used(m_table_name), this);
+      auto field_chosen = offer_field_list_select_one_field(field, m_portal->get_table_used(m_table_name), this);
       if(field_chosen)
       {
         //Set the field details in the layout treeview:
@@ -422,7 +417,7 @@ void Dialog_Layout_Calendar_Related::on_button_edit()
 
         //Scroll to, and select, the new row:
         /*
-        Glib::RefPtr<Gtk::TreeView::Selection> refTreeSelection = m_treeview_fields->get_selection();
+        auto refTreeSelection = m_treeview_fields->get_selection();
         if(refTreeSelection)
           refTreeSelection->select(iter);
 
