@@ -47,7 +47,7 @@ PrintLayoutToolbarButton::PrintLayoutToolbarButton(const std::string& icon_name,
   g_object_set_data(G_OBJECT(gobj()), "glom-type", GINT_TO_POINTER(type));
 
   std::vector<Gtk::TargetEntry> targetentries;
-  targetentries.push_back(Gtk::TargetEntry(get_target()));
+  targetentries.emplace_back(Gtk::TargetEntry(get_target()));
 
   drag_source_set(targetentries, Gdk::MODIFIER_MASK, 
                   Gdk::ACTION_COPY | Gdk::ACTION_MOVE);
@@ -55,10 +55,6 @@ PrintLayoutToolbarButton::PrintLayoutToolbarButton(const std::string& icon_name,
   set_label(title);
 }
 
-PrintLayoutToolbarButton::~PrintLayoutToolbarButton()
-{
-}
-
 PrintLayoutToolbarButton::enumItems PrintLayoutToolbarButton::get_item_type_from_selection_data(const Glib::RefPtr<Gdk::DragContext>& drag_context, const Gtk::SelectionData& selection_data)
 {
   PrintLayoutToolbarButton::enumItems result = enumItems::INVALID;
