@@ -97,7 +97,7 @@ Window_PrintLayout_Edit::Window_PrintLayout_Edit(BaseObjectType* cobject, const
     sigc::mem_fun(*this, &Window_PrintLayout_Edit::on_spinbutton_height));
 
   const Gtk::TargetEntry target_rule(DRAG_TARGET_NAME_RULE, Gtk::TARGET_SAME_APP, 0);
-  m_drag_targets_rule.push_back(target_rule);
+  m_drag_targets_rule.emplace_back(target_rule);
 
   //The rulers are not in the glade file because they use an unusual widget 
   //that Glade wouldn't usually know about:
@@ -150,7 +150,7 @@ Window_PrintLayout_Edit::Window_PrintLayout_Edit(BaseObjectType* cobject, const
   //TODO: Does this need to be a member variable?
   m_drag_targets_all = m_drag_targets_rule;
   const auto toolbar_target = Gtk::ToolPalette::get_drag_target_item();
-  m_drag_targets_all.push_back(toolbar_target);
+  m_drag_targets_all.emplace_back(toolbar_target);
 
   //Note that we don't use Gtk::DEST_DEFAULT_DEFAULTS because that would prevent our signal handlers from being used:
   m_canvas.drag_dest_set(m_drag_targets_all, Gtk::DEST_DEFAULT_HIGHLIGHT, Gdk::ACTION_COPY);
@@ -194,7 +194,7 @@ Window_PrintLayout_Edit::Window_PrintLayout_Edit(BaseObjectType* cobject, const
 
 void Window_PrintLayout_Edit::init_menu()
 {
-  Glib::RefPtr<Gio::SimpleActionGroup> action_group = Gio::SimpleActionGroup::create();
+  auto action_group = Gio::SimpleActionGroup::create();
 
   add_action("pagesetup",
     sigc::mem_fun(*this, &Window_PrintLayout_Edit::on_menu_file_page_setup));
@@ -271,17 +271,18 @@ void Window_PrintLayout_Edit::init_menu()
   insert_action_group("printlayout", action_group);
 
   //Get the menu:
-  Glib::RefPtr<Glib::Object> object =
+  auto object =
     m_builder->get_object("Menubar");
-  Glib::RefPtr<Gio::Menu> gmenu =
+  auto gmenu =
     Glib::RefPtr<Gio::Menu>::cast_dynamic(object);
   if(!gmenu)
     g_warning("GMenu not found");
 
   //Menubar:
-  auto pMenuBar = new Gtk::MenuBar(gmenu);
-  m_box_menu->pack_start(*pMenuBar, Gtk::PACK_SHRINK);
-  pMenuBar->show();
+  auto menubar = std::make_unique<Gtk::MenuBar>(gmenu);
+  menubar->show();
+  m_box_menu->pack_start(*(Gtk::manage(menubar.release())), Gtk::PACK_SHRINK);
+
 
   //TODO: Create a generic checking method to test that
   //  all actions from the action group are in the GMenu?
@@ -369,7 +370,7 @@ std::shared_ptr<LayoutItem> Window_PrintLayout_Edit::create_empty_item(PrintLayo
 
   if(item_type == PrintLayoutToolbarButton::enumItems::FIELD)
   {
-    std::shared_ptr<LayoutItem_Field> layout_item_derived  = std::make_shared<LayoutItem_Field>();
+    auto layout_item_derived  = std::make_shared<LayoutItem_Field>();
     layout_item = layout_item_derived;
     layout_item->set_print_layout_position(0, 0,
       PrintLayoutUtils::ITEM_WIDTH_WIDE, PrintLayoutUtils::ITEM_HEIGHT);
@@ -379,7 +380,7 @@ std::shared_ptr<LayoutItem> Window_PrintLayout_Edit::create_empty_item(PrintLayo
   }
   else if(item_type == PrintLayoutToolbarButton::enumItems::TEXT)
   {
-    std::shared_ptr<LayoutItem_Text> layout_item_derived = std::make_shared<LayoutItem_Text>();
+    auto layout_item_derived = std::make_shared<LayoutItem_Text>();
 
     // Note to translators: This is the default contents of a text item on a print layout: 
     layout_item_derived->set_text_original(_("text")); //TODO: Choose some other longer default because this is hidden under the drag icon?
@@ -395,20 +396,20 @@ std::shared_ptr<LayoutItem> Window_PrintLayout_Edit::create_empty_item(PrintLayo
   }
   else if(item_type == PrintLayoutToolbarButton::enumItems::LINE_HORIZONTAL)
   {
-    std::shared_ptr<LayoutItem_Line> layout_item_derived = std::make_shared<LayoutItem_Line>();
+    auto layout_item_derived = std::make_shared<LayoutItem_Line>();
     layout_item_derived->set_coordinates(0, 0,
       PrintLayoutUtils::ITEM_WIDTH_WIDE * 2, 0);
     layout_item = layout_item_derived;
   }
   else if(item_type == PrintLayoutToolbarButton::enumItems::LINE_VERTICAL)
   {
-    std::shared_ptr<LayoutItem_Line> layout_item_derived = std::make_shared<LayoutItem_Line>();
+    auto layout_item_derived = std::make_shared<LayoutItem_Line>();
     layout_item_derived->set_coordinates(0, 0, 0, PrintLayoutUtils::ITEM_WIDTH_WIDE * 2);
     layout_item = layout_item_derived;
   }
   else if(item_type == PrintLayoutToolbarButton::enumItems::PORTAL)
   {
-    std::shared_ptr<LayoutItem_Portal> portal = std::make_shared<LayoutItem_Portal>();
+    auto portal = std::make_shared<LayoutItem_Portal>();
     portal->set_print_layout_row_height(10); //Otherwise it will be 0, which is useless.
     layout_item = portal;
     layout_item->set_print_layout_position(0, 0,
@@ -422,7 +423,7 @@ std::shared_ptr<LayoutItem> Window_PrintLayout_Edit::create_empty_item(PrintLayo
   //Set a default text style and size:
   //12pt text seems sane. It is what OpenOffice/LibreOffice and Abiword use:
   //Serif (rather than sans-serif) is sane for body text:
-  std::shared_ptr<LayoutItem_WithFormatting> with_formatting = 
+  auto with_formatting = 
     std::dynamic_pointer_cast<LayoutItem_WithFormatting>(layout_item);
   if(with_formatting)
     with_formatting->m_formatting.set_text_format_font("Serif 12");
@@ -484,7 +485,7 @@ void Window_PrintLayout_Edit::on_canvas_drag_data_received(const Glib::RefPtr<Gd
   const auto item_type = PrintLayoutToolbarButton::get_item_type_from_selection_data(drag_context, selection_data);
   if(item_type == PrintLayoutToolbarButton::enumItems::INVALID)
   {
-    std::cerr << G_STRFUNC << ": item_type was invalid" << std::endl;
+    std::cerr << G_STRFUNC << ": item_type was invalid\n";
     return;
   }
 
@@ -493,7 +494,7 @@ void Window_PrintLayout_Edit::on_canvas_drag_data_received(const Glib::RefPtr<Gd
     //Create the temporary drag item if necessary:
     if(!m_layout_item_dropping)
     {
-      std::shared_ptr<LayoutItem> layout_item = create_empty_item(item_type);
+      auto layout_item = create_empty_item(item_type);
 
       //Show it on the canvas, at the position:
       if(layout_item)
@@ -516,14 +517,14 @@ void Window_PrintLayout_Edit::on_canvas_drag_data_received(const Glib::RefPtr<Gd
     m_canvas.drag_unhighlight();
 
     //Add the item to the canvas:
-    std::shared_ptr<LayoutItem> layout_item = create_empty_item(item_type);
+    auto layout_item = create_empty_item(item_type);
     if(!layout_item)
     {
-      std::cerr << G_STRFUNC << ": layout_item is null." << std::endl;
+      std::cerr << G_STRFUNC << ": layout_item is null.\n";
       return;
     }
 
-    Glib::RefPtr<CanvasLayoutItem> item =
+    auto item =
       create_canvas_layout_item_and_add(layout_item);
     item->snap_position(item_x, item_y);
     item->set_xy(item_x, item_y);
@@ -557,10 +558,10 @@ Window_PrintLayout_Edit::~Window_PrintLayout_Edit()
 
 void Window_PrintLayout_Edit::update_table_title()
 {
-  const auto document = dynamic_cast<const Document*>(get_document());
+  const auto document = std::dynamic_pointer_cast<const Document>(get_document());
   if(!document)
   {
-    std::cerr << G_STRFUNC << ": document was null" << std::endl;
+    std::cerr << G_STRFUNC << ": document was null\n";
     return;
   }
 
@@ -652,15 +653,15 @@ std::shared_ptr<PrintLayout> Window_PrintLayout_Edit::get_print_layout()
   m_print_layout->get_layout_group()->remove_all_items();
 
   //The Header and Footer parts are implicit (they are the whole header or footer treeview)
-  std::shared_ptr<LayoutItem_Header> header = std::make_shared<LayoutItem_Header>();
-  std::shared_ptr<LayoutGroup> group_temp = header;
+  auto header = std::make_shared<LayoutItem_Header>();
+  auto group_temp = header;
   fill_print_layout_parts(group_temp, m_model_parts_header);
   if(header->get_items_count())
     m_print_layout->get_layout_group()->add_item(header);
 
   fill_print_layout_parts(m_print_layout->get_layout_group(), m_model_parts_main);
 
-  std::shared_ptr<LayoutItem_Footer> footer = std::make_shared<LayoutItem_Footer>();
+  auto footer = std::make_shared<LayoutItem_Footer>();
   group_temp = footer;
   fill_print_layout_parts(group_temp, m_model_parts_footer);
   if(footer->get_items_count())
@@ -682,7 +683,7 @@ void Window_PrintLayout_Edit::on_context_menu_insert_text()
 
 void Window_PrintLayout_Edit::setup_context_menu()
 {
-  Glib::RefPtr<Gio::SimpleActionGroup> action_group = Gio::SimpleActionGroup::create();
+  auto action_group = Gio::SimpleActionGroup::create();
 
   action_group->add_action("insert-field",
     sigc::mem_fun(*this, &Window_PrintLayout_Edit::on_context_menu_insert_field) );
@@ -699,14 +700,14 @@ void Window_PrintLayout_Edit::setup_context_menu()
   insert_action_group("context", action_group);
 
   //Get the menu:
-  Glib::RefPtr<Glib::Object> object =
+  auto object =
     m_builder->get_object("ContextMenu");
-  Glib::RefPtr<Gio::Menu> gmenu =
+  auto gmenu =
     Glib::RefPtr<Gio::Menu>::cast_dynamic(object);
   if(!gmenu)
     g_warning("GMenu not found");
 
-  m_context_menu = new Gtk::Menu(gmenu);
+  m_context_menu = std::make_unique<Gtk::Menu>(gmenu);
   m_context_menu->attach_to_widget(*this);
 }
 
@@ -727,7 +728,7 @@ bool Window_PrintLayout_Edit::on_canvas_motion_notify_event(GdkEventMotion* moti
 void Window_PrintLayout_Edit::on_canvas_show_context_menu(guint button, guint32 activate_time)
 {
   //TODO: This is never called when right-clicking on the canvas.
-  //std::cout << G_STRFUNC << ": debug" << std::endl;
+  //std::cout << G_STRFUNC << ": debug\n";
 
   if(m_context_menu)
     m_context_menu->popup(button, activate_time);
@@ -735,12 +736,12 @@ void Window_PrintLayout_Edit::on_canvas_show_context_menu(guint button, guint32
 
 bool Window_PrintLayout_Edit::get_is_item_at(double x, double y)
 {
-  Glib::RefPtr<Goocanvas::Item> item_hit = m_canvas.get_item_at(x, y, false);
+  auto item_hit = m_canvas.get_item_at(x, y, false);
   if(!item_hit)
    return false;
 
-  const auto layout_item = Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(item_hit);
-  return (bool)layout_item;
+  auto layout_item = Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(item_hit);
+  return layout_item;
 }
 
 void Window_PrintLayout_Edit::set_default_position(const std::shared_ptr<LayoutItem>& item)
@@ -771,7 +772,7 @@ void Window_PrintLayout_Edit::set_default_position(const std::shared_ptr<LayoutI
 
 void Window_PrintLayout_Edit::on_menu_insert_field()
 {
-  std::shared_ptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::enumItems::FIELD);
+  auto layout_item = create_empty_item(PrintLayoutToolbarButton::enumItems::FIELD);
 
   // Note to translators: This is the default contents of a text item on a print layout: 
   set_default_position(layout_item);
@@ -781,7 +782,7 @@ void Window_PrintLayout_Edit::on_menu_insert_field()
 
 void Window_PrintLayout_Edit::on_menu_insert_text()
 {
-  std::shared_ptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::enumItems::TEXT);
+  auto layout_item = create_empty_item(PrintLayoutToolbarButton::enumItems::TEXT);
   set_default_position(layout_item);
 
   create_canvas_layout_item_and_add(layout_item);
@@ -789,7 +790,7 @@ void Window_PrintLayout_Edit::on_menu_insert_text()
 
 void Window_PrintLayout_Edit::on_menu_insert_image()
 {
-  std::shared_ptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::enumItems::IMAGE);
+  auto layout_item = create_empty_item(PrintLayoutToolbarButton::enumItems::IMAGE);
   // Note to translators: This is the default contents of a text item on a print layout: 
   //layout_item->set_text_original(_("text"));
   set_default_position(layout_item);
@@ -799,7 +800,7 @@ void Window_PrintLayout_Edit::on_menu_insert_image()
 
 void Window_PrintLayout_Edit::on_menu_insert_relatedrecords()
 {
-  std::shared_ptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::enumItems::PORTAL);
+  auto layout_item = create_empty_item(PrintLayoutToolbarButton::enumItems::PORTAL);
   set_default_position(layout_item);
 
   create_canvas_layout_item_and_add(layout_item);
@@ -807,7 +808,7 @@ void Window_PrintLayout_Edit::on_menu_insert_relatedrecords()
 
 void Window_PrintLayout_Edit::on_menu_insert_line_horizontal()
 {
-  std::shared_ptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::enumItems::LINE_HORIZONTAL);
+  auto layout_item = create_empty_item(PrintLayoutToolbarButton::enumItems::LINE_HORIZONTAL);
 
   /*
   double item_x = m_drop_x;
@@ -824,7 +825,7 @@ void Window_PrintLayout_Edit::on_menu_insert_line_horizontal()
 
 void Window_PrintLayout_Edit::on_menu_insert_line_vertical()
 {
-  std::shared_ptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::enumItems::LINE_VERTICAL);
+  auto layout_item = create_empty_item(PrintLayoutToolbarButton::enumItems::LINE_VERTICAL);
 
   create_canvas_layout_item_and_add(layout_item);
 }
@@ -842,17 +843,17 @@ void Window_PrintLayout_Edit::on_menu_insert_create_standard()
   if(response != Gtk::RESPONSE_OK)
     return;
 
-  const auto document = dynamic_cast<const Document*>(get_document());
+  const auto document = std::dynamic_pointer_cast<const Document>(get_document());
   if(!document)
   {
-    std::cerr << G_STRFUNC << ": document was null" << std::endl;
+    std::cerr << G_STRFUNC << ": document was null\n";
     return;
   }
 
-  Glib::RefPtr<Gtk::PageSetup> page_setup = m_canvas.get_page_setup();
+  auto page_setup = m_canvas.get_page_setup();
   if(!page_setup)
   {
-    std::cerr << G_STRFUNC << ": page_setup was null" << std::endl;
+    std::cerr << G_STRFUNC << ": page_setup was null\n";
     return;
   }
   
@@ -1003,10 +1004,10 @@ void Window_PrintLayout_Edit::on_menu_view_zoom(int parameter)
 
 void Window_PrintLayout_Edit::on_menu_file_page_setup()
 {
-  Glib::RefPtr<Gtk::PageSetup> page_setup = m_canvas.get_page_setup();
+  auto page_setup = m_canvas.get_page_setup();
 
   //Show the page setup dialog, asking it to start with the existing settings:
-  Glib::RefPtr<Gtk::PrintSettings> print_settings = Gtk::PrintSettings::create(); //TODO: Do we really need to get this from the user and store it?
+  auto print_settings = Gtk::PrintSettings::create(); //TODO: Do we really need to get this from the user and store it?
   page_setup = Gtk::run_page_setup_dialog(*this, page_setup, print_settings);
 
   //Save the chosen page setup dialog for use when printing, previewing, or
@@ -1020,12 +1021,12 @@ void Window_PrintLayout_Edit::on_menu_file_print_preview()
 {
   //Save any recent changes in the document,
   //so that the preview will show them:
-  auto document = dynamic_cast<Document*>(get_document());
+  auto document = std::dynamic_pointer_cast<Document>(get_document());
   if(!document)
     return;
 
   const auto original_name = get_original_name();
-  std::shared_ptr<PrintLayout> print_layout = get_print_layout();
+  auto print_layout = get_print_layout();
   if(print_layout && (original_name != get_name()))
     document->remove_print_layout(m_table_name, original_name);
 
@@ -1055,10 +1056,10 @@ void Window_PrintLayout_Edit::on_menu_edit_copy()
     if(item)
       item->update_layout_position_from_canvas();
 
-    std::shared_ptr<LayoutItem> cloned = 
+    auto cloned = 
       glom_sharedptr_clone(item->get_layout_item());
 
-    m_layout_items_to_paste.push_back(cloned);
+    m_layout_items_to_paste.emplace_back(cloned);
   }
 
   m_action_edit_paste->set_enabled();
@@ -1094,7 +1095,7 @@ void Window_PrintLayout_Edit::on_menu_edit_paste()
 
 Glib::RefPtr<CanvasLayoutItem> Window_PrintLayout_Edit::create_canvas_layout_item_and_add(const std::shared_ptr<LayoutItem>& layout_item)
 {
-  Glib::RefPtr<CanvasLayoutItem> canvas_item = CanvasLayoutItem::create();
+  auto canvas_item = CanvasLayoutItem::create();
   m_canvas.add_canvas_layout_item(canvas_item);
   canvas_item->set_layout_item(layout_item);
   
@@ -1107,7 +1108,7 @@ void Window_PrintLayout_Edit::on_menu_edit_delete()
 {
   while(!m_layout_items_selected.empty())
   {
-    Glib::RefPtr<CanvasLayoutItem> item = m_layout_items_selected[0];
+    auto item = m_layout_items_selected[0];
     if(item)
       m_canvas.remove_canvas_layout_item(item);
   }
@@ -1132,7 +1133,7 @@ void Window_PrintLayout_Edit::on_menu_align_top()
   for(auto iter = m_layout_items_selected.begin();
     iter != m_layout_items_selected.end(); ++iter)
   {
-    Glib::RefPtr<CanvasLayoutItem> selected_item = *iter;
+    auto selected_item = *iter;
     if(!selected_item)
       continue;
 
@@ -1166,7 +1167,7 @@ void Window_PrintLayout_Edit::on_menu_align_bottom()
   for(auto iter = m_layout_items_selected.begin();
     iter != m_layout_items_selected.end(); ++iter)
   {
-    Glib::RefPtr<CanvasLayoutItem> selected_item = *iter;
+    auto selected_item = *iter;
     if(!selected_item)
       continue;
 
@@ -1212,7 +1213,7 @@ void Window_PrintLayout_Edit::on_menu_align_left()
   for(auto iter = m_layout_items_selected.begin();
     iter != m_layout_items_selected.end(); ++iter)
   {
-    Glib::RefPtr<CanvasLayoutItem> selected_item = *iter;
+    auto selected_item = *iter;
     if(!selected_item)
       continue;
 
@@ -1246,7 +1247,7 @@ void Window_PrintLayout_Edit::on_menu_align_right()
   for(auto iter = m_layout_items_selected.begin();
     iter != m_layout_items_selected.end(); ++iter)
   {
-    Glib::RefPtr<CanvasLayoutItem> selected_item = *iter;
+    auto selected_item = *iter;
 
     if(!selected_item)
       continue;
@@ -1392,8 +1393,6 @@ void Window_PrintLayout_Edit::get_dimensions_of_multiple_selected_items(double&
 
 void Window_PrintLayout_Edit::on_canvas_selection_changed()
 {
-  Canvas_PrintLayout::type_vec_items items = m_canvas.get_selected_items();
-
   //Forget about any previously selected items:
   m_layout_items_selected.clear();
   for(auto item : m_connections_items_selected_moved)
@@ -1402,17 +1401,16 @@ void Window_PrintLayout_Edit::on_canvas_selection_changed()
   }
   m_connections_items_selected_moved.clear();
   
-
-  for(Canvas_PrintLayout::type_vec_items::const_iterator iter = items.begin();
-    iter != items.end(); ++iter)
+  const auto items = m_canvas.get_selected_items();
+  for(const auto& base_item : items)
   {
-    Glib::RefPtr<CanvasLayoutItem> item = Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(*iter);
+    auto item = Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(base_item);
     if(!item)
       continue;
 
     //Cache the selected items and handle their signal_moved signals:
-    m_layout_items_selected.push_back(item);
-    m_connections_items_selected_moved.push_back(
+    m_layout_items_selected.emplace_back(item);
+    m_connections_items_selected_moved.emplace_back(
       item->signal_moved().connect(
         sigc::mem_fun(*this, &Window_PrintLayout_Edit::on_selected_item_moved)));
   }
@@ -1562,7 +1560,7 @@ void Window_PrintLayout_Edit::on_spinbutton_width()
   if(m_layout_items_selected.empty())
     return;
 
-  Glib::RefPtr<CanvasLayoutItem> item = m_layout_items_selected[0];
+  auto item = m_layout_items_selected[0];
 
   double width = 0;
   double height = 0;
@@ -1581,7 +1579,7 @@ void Window_PrintLayout_Edit::on_spinbutton_height()
   if(m_layout_items_selected.empty())
     return;
 
-  Glib::RefPtr<CanvasLayoutItem> item = m_layout_items_selected[0];
+  auto item = m_layout_items_selected[0];
 
   double width = 0;
   double height = 0;
