@@ -162,7 +162,7 @@ Dialog_Layout_Report::Dialog_Layout_Report(BaseObjectType* cobject, const Glib::
     m_treeview_available_parts->set_headers_visible(false); //There's only one column, so this is not useful.
 
     //Respond to changes of selection:
-    Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_available_parts->get_selection();
+    auto refSelection = m_treeview_available_parts->get_selection();
     if(refSelection)
     {
       refSelection->signal_changed().connect( sigc::mem_fun(*this, &Dialog_Layout_Report::on_treeview_available_parts_selection_changed) );
@@ -226,7 +226,7 @@ void Dialog_Layout_Report::setup_model(Gtk::TreeView& treeview, Glib::RefPtr<typ
   //  sigc::bind( sigc::mem_fun(*this, &Dialog_Layout_Report::on_treeview_cell_edited_numeric), m_model_parts_main->m_columns.m_col_columns_count) );
 
   //Respond to changes of selection:
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = treeview.get_selection();
+  auto refSelection = treeview.get_selection();
   if(refSelection)
   {
     refSelection->signal_changed().connect( sigc::mem_fun(*this, &Dialog_Layout_Report::on_treeview_parts_selection_changed) );
@@ -242,7 +242,7 @@ std::shared_ptr<LayoutGroup> Dialog_Layout_Report::fill_group(const Gtk::TreeMod
     Gtk::TreeModel::Row row = *iter;
 
     std::shared_ptr<LayoutItem> pItem = row[model->m_columns.m_col_item];
-    std::shared_ptr<LayoutGroup> pGroup = std::dynamic_pointer_cast<LayoutGroup>(pItem);
+    auto pGroup = std::dynamic_pointer_cast<LayoutGroup>(pItem);
     if(pGroup)
     {
       //Make sure that it contains the child items:
@@ -267,7 +267,7 @@ void Dialog_Layout_Report::fill_group_children(const std::shared_ptr<LayoutGroup
       std::shared_ptr<LayoutItem> item = child_row[model->m_columns.m_col_item];
 
       //Recurse:
-      std::shared_ptr<LayoutGroup> child_group = std::dynamic_pointer_cast<LayoutGroup>(item);
+      auto child_group = std::dynamic_pointer_cast<LayoutGroup>(item);
       if(child_group)
         fill_group_children(child_group, child_row, model);
 
@@ -282,11 +282,11 @@ void Dialog_Layout_Report::add_group_children(const Glib::RefPtr<type_model>& mo
 {
   for(const auto& item : group->m_list_items)
   {
-    std::shared_ptr<const LayoutGroup> child_group = std::dynamic_pointer_cast<const LayoutGroup>(item);
+    auto child_group = std::dynamic_pointer_cast<const LayoutGroup>(item);
     if(child_group)
     {
-      std::shared_ptr<const LayoutItem_Header> header = std::dynamic_pointer_cast<const LayoutItem_Header>(item);
-      std::shared_ptr<const LayoutItem_Footer> footer = std::dynamic_pointer_cast<const LayoutItem_Footer>(item);
+      auto header = std::dynamic_pointer_cast<const LayoutItem_Header>(item);
+      auto footer = std::dynamic_pointer_cast<const LayoutItem_Footer>(item);
 
       //Special-case the header and footer so that their items go into the separate treeviews:
       if(header)
@@ -334,7 +334,7 @@ void Dialog_Layout_Report::add_group(const Glib::RefPtr<type_model>& model_parts
   }
 }
 
-//void Dialog_Layout_Report::set_document(const Glib::ustring& layout, Document* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields)
+//void Dialog_Layout_Report::set_document(const Glib::ustring& layout, const std::shared_ptr<Document>& document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields)
 void Dialog_Layout_Report::set_report(const Glib::ustring& table_name, const std::shared_ptr<const Report>& report)
 {
   m_modified = false;
@@ -391,7 +391,7 @@ void Dialog_Layout_Report::enable_buttons()
   bool enable_add = false;
 
   //Available Parts:
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelectionAvailable = m_treeview_available_parts->get_selection();
+  auto refSelectionAvailable = m_treeview_available_parts->get_selection();
   if(refSelectionAvailable)
   {
     auto iter = refSelectionAvailable->get_selected();
@@ -413,10 +413,10 @@ void Dialog_Layout_Report::enable_buttons()
   if(!treeview)
     return;
 
-  Glib::RefPtr<type_model> model = get_selected_model();
+  auto model = get_selected_model();
 
   //Parts:
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = treeview->get_selection();
+  auto refSelection = treeview->get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
@@ -446,7 +446,7 @@ void Dialog_Layout_Report::enable_buttons()
 
       //The [Formatting] button:
       bool enable_formatting = false;
-      std::shared_ptr<LayoutItem_Field> item_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item_parent);
+      auto item_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item_parent);
       if(item_field)
         enable_formatting = true;
 
@@ -537,9 +537,9 @@ void Dialog_Layout_Report::on_button_delete()
   if(!treeview)
     return;
 
-  Glib::RefPtr<type_model> model = get_selected_model();
+  auto model = get_selected_model();
 
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = treeview->get_selection();
+  auto refTreeSelection = treeview->get_selection();
   if(refTreeSelection)
   {
     auto iter = refTreeSelection->get_selected();
@@ -558,9 +558,9 @@ void Dialog_Layout_Report::on_button_up()
   if(!treeview)
     return;
 
-  Glib::RefPtr<type_model> model = get_selected_model();
+  auto model = get_selected_model();
 
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = treeview->get_selection();
+  auto refSelection = treeview->get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
@@ -595,9 +595,9 @@ void Dialog_Layout_Report::on_button_down()
   if(!treeview)
     return;
 
-  Glib::RefPtr<type_model> model = get_selected_model();
+  auto model = get_selected_model();
 
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = treeview->get_selection();
+  auto refSelection = treeview->get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
@@ -633,8 +633,8 @@ void Dialog_Layout_Report::on_button_add()
   if(!treeview)
     return;
 
-  Glib::RefPtr<type_model> model = get_selected_model();
-  Glib::RefPtr<type_model> model_available = Glib::RefPtr<type_model>::cast_dynamic(m_treeview_available_parts->get_model());
+  auto model = get_selected_model();
+  auto model_available = Glib::RefPtr<type_model>::cast_dynamic(m_treeview_available_parts->get_model());
 
   auto parent = get_selected_group_parent();
   std::shared_ptr<const LayoutItem> pParentPart;
@@ -728,7 +728,7 @@ Gtk::TreeModel::iterator Dialog_Layout_Report::get_selected_group_parent() const
   Glib::RefPtr<const type_model> model = get_selected_model();
 
 
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = treeview->get_selection();
+  auto refTreeSelection = treeview->get_selection();
   if(refTreeSelection)
   {
     auto iter = refTreeSelection->get_selected();
@@ -758,7 +758,7 @@ Gtk::TreeModel::iterator Dialog_Layout_Report::get_selected_available() const
 
   Gtk::TreeModel::iterator iter;
 
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview_available_parts->get_selection();
+  auto refTreeSelection = m_treeview_available_parts->get_selection();
   if(refTreeSelection)
   {
     iter = refTreeSelection->get_selected();
@@ -774,10 +774,10 @@ void Dialog_Layout_Report::on_button_formatting()
   if(!treeview)
     return;
 
-  Glib::RefPtr<type_model> model = get_selected_model();
+  auto model = get_selected_model();
 
   //Get the selected item:
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = treeview->get_selection();
+  auto refTreeSelection = treeview->get_selection();
   if(refTreeSelection)
   {
     auto iter = refTreeSelection->get_selected();
@@ -786,10 +786,10 @@ void Dialog_Layout_Report::on_button_formatting()
       Gtk::TreeModel::Row row = *iter;
       std::shared_ptr<LayoutItem> item = row[model->m_columns.m_col_item];
 
-      std::shared_ptr<LayoutItem_Field> field = std::dynamic_pointer_cast<LayoutItem_Field>(item);
+      auto field = std::dynamic_pointer_cast<LayoutItem_Field>(item);
       if(field)
       {
-        std::shared_ptr<LayoutItem_Field> field_chosen = offer_field_formatting(field, m_table_name, this, false /* no editing options */);
+        auto field_chosen = offer_field_formatting(field, m_table_name, this, false /* no editing options */);
         if(field_chosen)
         {
           *field = *field_chosen;
@@ -806,10 +806,10 @@ void Dialog_Layout_Report::on_button_edit()
   if(!treeview)
     return;
 
-  Glib::RefPtr<type_model> model = get_selected_model();
+  auto model = get_selected_model();
 
   //Get the selected item:
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = treeview->get_selection();
+  auto refTreeSelection = treeview->get_selection();
   if(refTreeSelection)
   {
     auto iter = refTreeSelection->get_selected();
@@ -819,11 +819,17 @@ void Dialog_Layout_Report::on_button_edit()
       Gtk::TreeModel::Row row = *iter;
       std::shared_ptr<LayoutItem> item = row[model->m_columns.m_col_item];
 
-      std::shared_ptr<LayoutItem_FieldSummary> fieldsummary = std::dynamic_pointer_cast<LayoutItem_FieldSummary>(item);
+      auto fieldsummary = std::dynamic_pointer_cast<LayoutItem_FieldSummary>(item);
       if(fieldsummary)
       {
         Dialog_FieldSummary* dialog = nullptr;
         Utils::get_glade_widget_derived_with_warning(dialog);
+        if(!dialog)
+        {
+          std::cerr << G_STRFUNC << ": dialog is null." << std::endl;
+          return;
+        }
+
         add_view(dialog);
         dialog->set_item(fieldsummary, m_table_name);
         dialog->set_transient_for(*this);
@@ -834,7 +840,7 @@ void Dialog_Layout_Report::on_button_edit()
         if(dialog_response == Gtk::RESPONSE_OK)
         {
           //Get the chosen relationship:
-          std::shared_ptr<LayoutItem_FieldSummary> chosenitem = dialog->get_item();
+          auto chosenitem = dialog->get_item();
           if(chosenitem)
           {
             *fieldsummary = *chosenitem; //TODO_Performance.
@@ -849,10 +855,10 @@ void Dialog_Layout_Report::on_button_edit()
       }
       else
       {
-        std::shared_ptr<LayoutItem_Field> field = std::dynamic_pointer_cast<LayoutItem_Field>(item);
+        auto field = std::dynamic_pointer_cast<LayoutItem_Field>(item);
         if(field)
         {
-          std::shared_ptr<LayoutItem_Field> chosenitem = offer_field_list_select_one_field(field, m_table_name, this);
+          auto chosenitem = offer_field_list_select_one_field(field, m_table_name, this);
           if(chosenitem)
           {
             *field = *chosenitem; //TODO_Performance.
@@ -862,10 +868,10 @@ void Dialog_Layout_Report::on_button_edit()
         }
         else
         {
-          std::shared_ptr<LayoutItem_Text> layout_item_text = std::dynamic_pointer_cast<LayoutItem_Text>(item);
+          auto layout_item_text = std::dynamic_pointer_cast<LayoutItem_Text>(item);
           if(layout_item_text)
           {
-            std::shared_ptr<LayoutItem_Text> chosen = offer_textobject(layout_item_text);
+            auto chosen = offer_textobject(layout_item_text);
             if(chosen)
             {
               *layout_item_text = *chosen;
@@ -875,10 +881,10 @@ void Dialog_Layout_Report::on_button_edit()
           }
           else
           {
-            std::shared_ptr<LayoutItem_Image> layout_item_image = std::dynamic_pointer_cast<LayoutItem_Image>(item);
+            auto layout_item_image = std::dynamic_pointer_cast<LayoutItem_Image>(item);
             if(layout_item_image)
             {
-              std::shared_ptr<LayoutItem_Image> chosen = offer_imageobject(layout_item_image);
+              auto chosen = offer_imageobject(layout_item_image);
               if(chosen)
               {
                 *layout_item_image = *chosen;
@@ -888,7 +894,7 @@ void Dialog_Layout_Report::on_button_edit()
             }
             else
             {
-              std::shared_ptr<LayoutItem_GroupBy> group_by = std::dynamic_pointer_cast<LayoutItem_GroupBy>(item);
+              auto group_by = std::dynamic_pointer_cast<LayoutItem_GroupBy>(item);
               if(group_by)
               {
                 Dialog_GroupBy* dialog = nullptr;
@@ -906,7 +912,7 @@ void Dialog_Layout_Report::on_button_edit()
                 if(dialog_response == Gtk::RESPONSE_OK)
                 {
                   //Get the chosen relationship:
-                  std::shared_ptr<LayoutItem_GroupBy> chosenitem = dialog->get_item();
+                  auto chosenitem = dialog->get_item();
                   if(chosenitem)
                   {
                     *group_by = *chosenitem;
@@ -992,7 +998,7 @@ void Dialog_Layout_Report::on_cell_data_available_part(Gtk::CellRenderer* render
     if(iter)
     {
       Gtk::TreeModel::Row row = *iter;
-      Glib::RefPtr<type_model> model = Glib::RefPtr<type_model>::cast_dynamic(m_treeview_available_parts->get_model());
+      auto model = Glib::RefPtr<type_model>::cast_dynamic(m_treeview_available_parts->get_model());
       std::shared_ptr<LayoutItem> pItem = row[model->m_columns.m_col_item];
       Glib::ustring part = pItem->get_part_type_name();
 
@@ -1013,11 +1019,11 @@ std::shared_ptr<Report> Dialog_Layout_Report::get_report()
   m_report->set_title( m_entry_title->get_text() , AppWindow::get_current_locale());
   m_report->set_show_table_title( m_checkbutton_table_title->get_active() );
 
-  std::shared_ptr<LayoutGroup> group = m_report->get_layout_group();
+  auto group = m_report->get_layout_group();
   group->remove_all_items();
 
   //The Header and Footer parts are implicit (they are the whole header or footer treeview)
-  std::shared_ptr<LayoutItem_Header> header = std::make_shared<LayoutItem_Header>();
+  auto header = std::make_shared<LayoutItem_Header>();
   std::shared_ptr<LayoutGroup> group_temp = header;
   fill_report_parts(group_temp, m_model_parts_header);
   if(header->get_items_count())
@@ -1039,7 +1045,7 @@ void Dialog_Layout_Report::fill_report_parts(std::shared_ptr<LayoutGroup>& group
   for(const auto& row : parts_model->children())
   {
     //Recurse into a group if necessary:
-    std::shared_ptr<LayoutGroup> group_child = fill_group(row, parts_model);
+    auto group_child = fill_group(row, parts_model);
     if(group_child)
     {
       //Add the group:
