@@ -86,7 +86,7 @@ Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr
     sigc::mem_fun( *this, &Dialog_GroupsList::on_treeview_tables_toggled_delete) );
 
 
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_groups->get_selection();
+  auto refSelection = m_treeview_groups->get_selection();
   if(refSelection)
   {
     refSelection->signal_changed().connect( sigc::mem_fun(*this, &Dialog_GroupsList::on_treeview_groups_selection_changed) );
@@ -112,12 +112,8 @@ Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr
   show_all_children();
 }
 
-Dialog_GroupsList::~Dialog_GroupsList()
-{
-}
-
 /*
-void Dialog_GroupsList::set_document(const Glib::ustring& layout, Document* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields)
+void Dialog_GroupsList::set_document(const Glib::ustring& layout, const std::shared_ptr<Document>& document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields)
 {
   m_modified = false;
 
@@ -159,7 +155,7 @@ void Dialog_GroupsList::set_document(const Glib::ustring& layout, Document* docu
 
     for(const auto& the_pair : mapGroups)
     {
-      std::shared_ptr<const LayoutGroup> group = the_pairsecond;
+      auto group = the_pairsecond;
 
       add_group(Gtk::TreeModel::iterator(), group);
     }
@@ -180,7 +176,7 @@ void Dialog_GroupsList::enable_buttons()
   if(!m_button_group_users)
     return;
 
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_groups->get_selection();
+  auto refSelection = m_treeview_groups->get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
@@ -201,7 +197,7 @@ void Dialog_GroupsList::enable_buttons()
 
 void Dialog_GroupsList::on_button_group_delete()
 {
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview_groups->get_selection();
+  auto refTreeSelection = m_treeview_groups->get_selection();
   if(refTreeSelection)
   {
     auto iter = refTreeSelection->get_selected();
@@ -225,7 +221,7 @@ void Dialog_GroupsList::on_button_group_delete()
           const Glib::ustring strQuery = "DROP GROUP " + DbUtils::escape_sql_id(group);
           const auto test = DbUtils::query_execute_string(strQuery);
           if(!test)
-            std::cerr << G_STRFUNC << ": DROP GROUP failed." << std::endl;
+            std::cerr << G_STRFUNC << ": DROP GROUP failed.\n";
 
           fill_group_list();
         }
@@ -255,13 +251,13 @@ void Dialog_GroupsList::on_button_group_new()
 
   if(group_name.empty())
   {
-    std::cerr << G_STRFUNC << ": : group_name is empty" << std::endl;
+    std::cerr << G_STRFUNC << ": : group_name is empty\n";
     return;
   }
 
   if(!DbUtils::add_group(get_document(), group_name))
   {
-    std::cerr << G_STRFUNC << ": : DbUtils::add_group() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": : DbUtils::add_group() failed.\n";
   }
 
   fill_group_list();
@@ -271,7 +267,7 @@ void Dialog_GroupsList::on_button_group_users()
 {
 
   //Get the selected item:
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview_groups->get_selection();
+  auto refTreeSelection = m_treeview_groups->get_selection();
   if(refTreeSelection)
   {
     auto iter = refTreeSelection->get_selected();
@@ -318,7 +314,7 @@ void Dialog_GroupsList::on_treeview_tables_selection_changed()
 
 Glib::ustring Dialog_GroupsList::get_selected_group() const
 {
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_groups->get_selection();
+  auto refSelection = m_treeview_groups->get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
@@ -361,7 +357,7 @@ void Dialog_GroupsList::fill_group_list()
   if(m_treeview_groups && m_treeview_groups->get_model()) //Avoid a warning.
   {
     //Select the first item, so that there is always something in the tables TreeView:
-    Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_groups->get_selection();
+    auto refSelection = m_treeview_groups->get_selection();
     if(refSelection)
     {
       auto iterFirst = m_model_groups->children().begin();
@@ -377,21 +373,21 @@ void Dialog_GroupsList::fill_table_list(const Glib::ustring& group_name)
 {
   if(group_name.empty())
   {
-    std::cerr << G_STRFUNC << ": group_name is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": group_name is empty.\n";
   }
 
   //Fill the model rows:
   m_model_tables->clear();
 
- auto pDocument = get_document();
-  if(pDocument)
+ auto document = get_document();
+  if(document)
   {
     // Make sure that these are in the document,
     // so that the correct groups will be created if we recreate the database from the document:
     GroupInfo group_info;
     group_info.set_name(group_name);
 
-    Document::type_listTableInfo table_list = pDocument->get_tables(true /* plus system prefs */);
+    Document::type_listTableInfo table_list = document->get_tables(true /* plus system prefs */);
 
     for(const auto& table : table_list)
     {
@@ -413,7 +409,7 @@ void Dialog_GroupsList::fill_table_list(const Glib::ustring& group_name)
       group_info.m_map_privileges[table_name] = privs;
     }
 
-    pDocument->set_group(group_info);
+    document->set_group(group_info);
   }
 }
 
@@ -484,7 +480,7 @@ bool Dialog_GroupsList::set_table_privilege(const Glib::ustring& table_name, con
 
   const auto test = DbUtils::query_execute_string(strQuery); //TODO: Handle errors.
   if(!test)
-    std::cerr << G_STRFUNC << ": GRANT/REVOKE failed." << std::endl;
+    std::cerr << G_STRFUNC << ": GRANT/REVOKE failed.\n";
 
   return test;
 }
