@@ -39,7 +39,6 @@ public:
   static const bool glade_developer;
 
   Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
-  virtual ~Dialog_GroupsList();
 
   //Refresh the UI when we get the document, from add_view:
   void load_from_document() override;
@@ -50,7 +49,7 @@ public:
    * @param table_name The table name.
    * @param table_fields: The actual fields in the table, in case the document does not yet know about them all.
    */
-  //virtual void set_document(const Glib::ustring& layout, Document* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields);
+  //virtual void set_document(const Glib::ustring& layout, const std::shared_ptr<Document>& document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields);
 
 private:
 
