@@ -51,7 +51,7 @@ Dialog_UsersList::Dialog_UsersList(BaseObjectType* cobject, const Glib::RefPtr<G
   builder->get_widget("treeview_users", m_treeview_users);
   if(m_treeview_users)
   {
-    Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_users->get_selection();
+    auto refSelection = m_treeview_users->get_selection();
     if(refSelection)
     {
       refSelection->signal_changed().connect( sigc::mem_fun(*this, &Dialog_UsersList::on_treeview_users_selection_changed) );
@@ -87,17 +87,13 @@ Dialog_UsersList::Dialog_UsersList(BaseObjectType* cobject, const Glib::RefPtr<G
   show_all_children();
 }
 
-Dialog_UsersList::~Dialog_UsersList()
-{
-}
-
 void Dialog_UsersList::enable_buttons()
 {
   if(!m_button_user_edit)
    return;
 
   //Fields:
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_users->get_selection();
+  auto refSelection = m_treeview_users->get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
@@ -118,7 +114,7 @@ void Dialog_UsersList::enable_buttons()
 
 void Dialog_UsersList::on_button_user_remove()
 {
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview_users->get_selection();
+  auto refTreeSelection = m_treeview_users->get_selection();
   if(refTreeSelection)
   {
     auto iter = refTreeSelection->get_selected();
@@ -145,7 +141,7 @@ void Dialog_UsersList::on_button_user_remove()
 
 void Dialog_UsersList::on_button_user_delete()
 {
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview_users->get_selection();
+  auto refTreeSelection = m_treeview_users->get_selection();
   if(refTreeSelection)
   {
     auto iter = refTreeSelection->get_selected();
@@ -212,7 +208,7 @@ void Dialog_UsersList::on_button_user_add()
     //Add it to the group:
     const auto query_add_user = DbUtils::build_query_add_user_to_group(m_combo_group->get_active_text(), user);
     if(!DbUtils::query_execute_string(query_add_user))
-      std::cerr << G_STRFUNC << ": ALTER GROUP failed." << std::endl;
+      std::cerr << G_STRFUNC << ": ALTER GROUP failed.\n";
 
     //Remove any user rights, so that all rights come from the user's presence in the group:
     const auto document = get_document();
@@ -221,7 +217,7 @@ void Dialog_UsersList::on_button_user_add()
       const auto table_name = table->get_name();
       const Glib::ustring query_revoke = "REVOKE ALL PRIVILEGES ON " + DbUtils::escape_sql_id(table_name) + " FROM " + DbUtils::escape_sql_id(user);
       if(!DbUtils::query_execute_string(query_revoke))
-        std::cerr << G_STRFUNC << ": REVOKE failed." << std::endl;
+        std::cerr << G_STRFUNC << ": REVOKE failed.\n";
     }
 
     fill_list();
@@ -265,7 +261,7 @@ void Dialog_UsersList::on_button_user_new()
 
   if(!DbUtils::add_user(get_document(), user, password, m_combo_group->get_active_text() /* group */))
   {
-    std::cerr << G_STRFUNC << ": add_user() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": add_user() failed.\n";
   }
 
   fill_list();
@@ -274,7 +270,7 @@ void Dialog_UsersList::on_button_user_new()
 void Dialog_UsersList::on_button_user_edit()
 {
   //Get the selected item:
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview_users->get_selection();
+  auto refTreeSelection = m_treeview_users->get_selection();
   if(refTreeSelection)
   {
     auto iter = refTreeSelection->get_selected();
@@ -338,7 +334,7 @@ void Dialog_UsersList::on_button_user_edit()
         const Glib::ustring strQuery = "ALTER USER " + DbUtils::escape_sql_id(user) + " PASSWORD '" + password + "'" ; //TODO: Escape the password.
         const auto test = DbUtils::query_execute_string(strQuery);
         if(!test)
-          std::cerr << G_STRFUNC << ": ALTER USER failed." << std::endl;
+          std::cerr << G_STRFUNC << ": ALTER USER failed.\n";
 
         //Change the password in the current connection, if this is the current user.
         auto connection_pool = ConnectionPool::get_instance();
