@@ -66,15 +66,11 @@ Box_Tables::Box_Tables(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
   show_all_children();
 }
 
-Box_Tables::~Box_Tables()
-{
-}
-
 void Box_Tables::fill_table_row(const Gtk::TreeModel::iterator& iter, const std::shared_ptr<const TableInfo>& table_info)
 {
   if(!table_info)
   {
-    std::cerr << G_STRFUNC << ": table_info was null." << std::endl;
+    std::cerr << G_STRFUNC << ": table_info was null.\n";
     return;
   }
   
@@ -150,15 +146,15 @@ bool Box_Tables::fill_from_database()
     listTablesDocument = document->get_tables();
   }
   else
-    std::cerr << G_STRFUNC << ": document is null" << std::endl;
+    std::cerr << G_STRFUNC << ": document is null\n";
 
   //Get the list of tables in the database, from the server:
-  std::shared_ptr<SharedConnection> sharedconnection = connect_to_server(AppWindow::get_appwindow());
+  auto sharedconnection = connect_to_server(AppWindow::get_appwindow());
 
   if(sharedconnection)
   {
     m_AddDel.remove_all();
-    Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
+    auto connection = sharedconnection->get_gda_connection();
 
     const auto vecTables = DbUtils::get_table_names_from_database();
 
@@ -167,7 +163,7 @@ bool Box_Tables::fill_from_database()
       std::shared_ptr<TableInfo> table_info;
 
       //Check whether it should be hidden:
-      Document::type_listTableInfo::const_iterator iterFind = find_if_same_name(listTablesDocument, strName);
+      const auto iterFind = find_if_same_name(listTablesDocument, strName);
       if(iterFind != listTablesDocument.end())
       {
         table_info = *iterFind;
@@ -255,7 +251,7 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
     auto document = get_document();
     if(document)
     {
-      std::shared_ptr<TableInfo> table_info = document->get_table(table_name);
+      auto table_info = document->get_table(table_name);
       fill_table_row(row, table_info);
 
       //Save the field information directly into the database, because we cannot get all the correct information from the database.
@@ -287,7 +283,7 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
       auto document = get_document();
       if(document)
       {
-        //Don't open a table that the document does not know about, because we need information from the document:
+        //Don't delete a table that the document does not know about, because we need information from the document:
         if(!document->get_table_is_known(table_name))
         {
            //TODO: Do not show tables that are not in the document.
@@ -310,14 +306,13 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
           
           //Get a list of autoincrementing fields in the table:
           const auto fields = document->get_table_fields(table_name);
-   
 
           //Delete the table:
           if(iButtonClicked == Gtk::RESPONSE_OK)
           {
             const auto test = DbUtils::drop_table(table_name);
             if(!test)
-              std::cerr << G_STRFUNC << ": DROP TABLE failed." << std::endl;
+              std::cerr << G_STRFUNC << ": DROP TABLE failed.\n";
             else
             {
               //Forget about it in the document too.
@@ -339,7 +334,7 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
                 DbUtils::remove_auto_increment(table_name, field_name);
               else
               {
-                std::cerr << G_STRFUNC << ": field_name is empty" << std::endl;
+                std::cerr << G_STRFUNC << ": field_name is empty\n";
               }
             }
           }
@@ -381,7 +376,7 @@ void Box_Tables::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint co
       if(is_default)
       {
         //Set all the other rows to false:
-        Glib::RefPtr<Gtk::TreeModel> model = m_AddDel.get_model();
+        auto model = m_AddDel.get_model();
         for(const auto& child_row : model->children())
         {
           m_AddDel.set_value(child_row, m_colDefault, false);
@@ -469,7 +464,7 @@ void Box_Tables::save_to_document()
     for(const auto& row : m_AddDel.get_model()->children())
     {
       const auto table_name = m_AddDel.get_value(row, m_colTableName); //The name has already been changed in the document.
-      std::shared_ptr<TableInfo> table_info = document->get_table(table_name); //Start with the existing table_info, to preserve extra information, such as translations.
+      auto table_info = document->get_table(table_name); //Start with the existing table_info, to preserve extra information, such as translations.
       if(table_info)
       {
         table_info->set_name( m_AddDel.get_value(row, m_colTableName) );
@@ -482,7 +477,7 @@ void Box_Tables::save_to_document()
           //std::cout << "debug: " << G_STRFUNC << ": title=" << item_get_title(table_info) << std::endl;
           table_info->set_default( m_AddDel.get_value_as_bool(row, m_colDefault) );
 
-          listTables.push_back(table_info);
+          listTables.emplace_back(table_info);
         }
       }
     }
