@@ -75,7 +75,6 @@ AddDelColumnInfo& AddDelColumnInfo::operator=(const AddDelColumnInfo& src)
 AddDel::AddDel()
 : Gtk::Box(Gtk::ORIENTATION_VERTICAL),
   m_col_key(0),
-  m_pMenuPopup(nullptr),
   m_auto_add(true),
   m_allow_add(true),
   m_allow_delete(true)
@@ -87,7 +86,6 @@ AddDel::AddDel()
 AddDel::AddDel(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
 : Gtk::Box(cobject),
   m_col_key(0),
-  m_pMenuPopup(nullptr),
   m_auto_add(true),
   m_allow_add(true),
   m_allow_delete(true)
@@ -134,11 +132,6 @@ void AddDel::init()
   show_all_children();
 }
 
-
-AddDel::~AddDel()
-{
-}
-
 void AddDel::set_treeview_accessible_name(const Glib::ustring& name)
 {
 #ifdef GTKMM_ATKMM_ENABLED
@@ -166,7 +159,7 @@ void AddDel::warn_about_duplicate()
 void
 AddDel::on_MenuPopup_activate_Edit()
 {
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_TreeView.get_selection();
+  auto refSelection = m_TreeView.get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
@@ -212,7 +205,7 @@ void AddDel::on_MenuPopup_activate_Delete()
 {
   finish_editing();
 
-  Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_TreeView.get_selection();
+  auto refSelection = m_TreeView.get_selection();
   if(refSelection)
   {
     auto iter = refSelection->get_selected();
@@ -242,11 +235,11 @@ void AddDel::setup_menu(Gtk::Widget* /* widget */)
 
   //TODO: add_accel_group(builder->get_accel_group());
 
-  Glib::RefPtr<Gio::Menu> menu = Gio::Menu::create();
+  auto menu = Gio::Menu::create();
   menu->append(_("_Edit"), "context.edit");
   menu->append(_("_Delete"), "context.delete");
 
-  m_pMenuPopup = new Gtk::Menu(menu);
+  m_pMenuPopup = std::make_unique<Gtk::Menu>(menu);
   m_pMenuPopup->attach_to_widget(*this);
 }
 
@@ -383,7 +376,7 @@ Glib::ustring AddDel::get_value_selected(guint col)
 
 Gtk::TreeModel::iterator AddDel::get_item_selected()
 {
-  Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_TreeView.get_selection();
+  auto refTreeSelection = m_TreeView.get_selection();
   if(refTreeSelection)
   {
      return refTreeSelection->get_selected();
@@ -424,7 +417,7 @@ bool AddDel::select_item(const Gtk::TreeModel::iterator& iter, guint column, boo
 
   if(iter)
   {
-    Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_TreeView.get_selection();
+    auto refTreeSelection = m_TreeView.get_selection();
     if(refTreeSelection)
     {
       refTreeSelection->select(iter);
@@ -724,7 +717,7 @@ void AddDel::construct_specified_columns()
     }
     else
     {
-      std::cerr << G_STRFUNC << ": Leaking a Gtk::TreeModelColumn<>." << std::endl;
+      std::cerr << G_STRFUNC << ": Leaking a Gtk::TreeModelColumn<>.\n";
     }
 
     ++model_column_index;
@@ -741,7 +734,7 @@ void AddDel::set_value(const Gtk::TreeModel::iterator& iter, guint col, const Gn
   {
     case(AddDelColumnInfo::enumStyles::Boolean):
     {
-      std::cerr << G_STRFUNC << ": boolean column being set as bool." << std::endl;
+      std::cerr << G_STRFUNC << ": boolean column being set as bool.\n";
       set_value(iter, col, value.get_bool());
       break;
     }
@@ -759,7 +752,7 @@ void AddDel::set_value(const Gtk::TreeModel::iterator& iter, guint col, const Gl
   InnerIgnore innerIgnore(this);
 
   if(!m_refListStore)
-    std::cerr << G_STRFUNC << ": No model." << std::endl;
+    std::cerr << G_STRFUNC << ": No model.\n";
   else
   {
     Gtk::TreeModel::Row treerow = *iter;
@@ -809,7 +802,7 @@ void AddDel::set_value(const Gtk::TreeModel::iterator& iter, guint col, bool bVa
   InnerIgnore innerIgnore(this);
 
   if(!m_refListStore)
-    std::cerr << G_STRFUNC << ": No model." << std::endl;
+    std::cerr << G_STRFUNC << ": No model.\n";
   else
   {
     Gtk::TreeModel::Row treerow = *iter;
@@ -856,7 +849,7 @@ void AddDel::remove_all_columns()
 
 guint AddDel::add_column(const AddDelColumnInfo& column_info)
 {
-  m_ColumnTypes.push_back(column_info);
+  m_ColumnTypes.emplace_back(column_info);
 
   //Generate appropriate model columns:
   construct_specified_columns();
@@ -1224,7 +1217,7 @@ void AddDel::on_treeview_cell_edited(const Glib::ustring& path_string, const Gli
              {
                //Reactivate the cell so that the data can be corrected.
 
-                Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_TreeView.get_selection();
+                auto refTreeSelection = m_TreeView.get_selection();
                 if(refTreeSelection)
                 {
                   refTreeSelection->select(row); //TODO: This does not seem to work.
@@ -1340,7 +1333,7 @@ void AddDel::on_treeview_columns_changed()
       if(pViewColumn)
       {
         const auto column_id = pViewColumn->get_column_id();
-        m_vecColumnIDs.push_back(column_id);
+        m_vecColumnIDs.emplace_back(column_id);
 
       }
     }
