@@ -34,10 +34,6 @@ LayoutWidgetBase::LayoutWidgetBase()
 {
 }
 
-LayoutWidgetBase::~LayoutWidgetBase()
-{
-}
-
 void LayoutWidgetBase::set_layout_item(const std::shared_ptr<LayoutItem>& layout_item, const Glib::ustring& table_name)
 {
   m_pLayoutItem = layout_item;
@@ -104,7 +100,7 @@ void LayoutWidgetBase::apply_formatting(Gtk::Widget& widget, const std::shared_p
 
   if(!widget_to_change)
   {
-    std::cerr << G_STRFUNC << ": widget_to_change is null." << std::endl;
+    std::cerr << G_STRFUNC << ": widget_to_change is null.\n";
     return;
   }
 
