@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "layoutwidgetfield.h"
@@ -28,10 +28,6 @@ LayoutWidgetField::LayoutWidgetField()
 {
 }
 
-LayoutWidgetField::~LayoutWidgetField()
-{
-}
-
 LayoutWidgetField::type_signal_edited LayoutWidgetField::signal_edited()
 {
   return m_signal_edited;
