@@ -29,18 +29,12 @@
 namespace Glom
 {
   
-LayoutWidgetUtils::LayoutWidgetUtils() :
-  m_pPopupMenuUtils(nullptr)
+LayoutWidgetUtils::LayoutWidgetUtils()
 {
   //Derived class's constructors must call this:
   //setup_util_menu(this);
 }
 
-LayoutWidgetUtils::~LayoutWidgetUtils()
-{
-	
-}
-
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void LayoutWidgetUtils::setup_util_menu(Gtk::Widget* widget)
 {
@@ -54,11 +48,11 @@ void LayoutWidgetUtils::setup_util_menu(Gtk::Widget* widget)
   
   widget->insert_action_group("utility", m_refActionGroup);
 
-  Glib::RefPtr<Gio::Menu> menu = Gio::Menu::create();
+  auto menu = Gio::Menu::create();
   menu->append(_("Properties"), "context.properties");
   menu->append(_("_Delete"), "context.delete");
 
-  m_pPopupMenuUtils = new Gtk::Menu(menu);
+  m_pPopupMenuUtils = std::make_unique<Gtk::Menu>(menu);
   m_pPopupMenuUtils->attach_to_widget(*widget);
 #endif
 }
@@ -69,7 +63,7 @@ void LayoutWidgetUtils::on_menu_delete_activate()
   if(!parent)
   {
     // Should never happen!
-    std::cerr << G_STRFUNC << ": LayoutWidgetUtils is no Gtk::Widget" << std::endl;
+    std::cerr << G_STRFUNC << ": LayoutWidgetUtils is no Gtk::Widget\n";
     return;
   }
 
@@ -86,7 +80,7 @@ void LayoutWidgetUtils::on_menu_delete_activate()
 
   if(base)
   {
-    std::shared_ptr<LayoutGroup> group = 
+    auto group = 
       std::dynamic_pointer_cast<LayoutGroup>(base->get_layout_item());
     if(!group)
       return;
@@ -99,7 +93,7 @@ void LayoutWidgetUtils::on_menu_delete_activate()
 void LayoutWidgetUtils::on_menu_properties_activate()
 {
   //This is not pure virtual, so we can easily use this base class in unit tests.
-  std::cerr << G_STRFUNC << ": Not imlemented. Derived classes should override this." << std::endl;
+  std::cerr << G_STRFUNC << ": Not imlemented. Derived classes should override this.\n";
 }
 
 #endif // !GLOM_ENABLE_CLIENT_ONLY
