@@ -38,7 +38,6 @@ class NotebookLabel
 public:
   explicit NotebookLabel(NotebookGlom* notebook);
   explicit NotebookLabel(const Glib::ustring& label, NotebookGlom* notebook);
-  virtual ~NotebookLabel();
 
   void set_label(const Glib::ustring& title);  
     
@@ -51,7 +50,7 @@ private:
   NotebookGlom* m_notebook;
   
   void setup_menu(Gtk::Widget* widget);
-  Gtk::Menu* m_pPopupMenu;
+  std::unique_ptr<Gtk::Menu> m_pPopupMenu;
   
   void on_menu_new_group_activate();
   void on_menu_delete_activate();
