@@ -13,7 +13,7 @@ static bool finished_parsing = true;
 bool check(const std::string& name, bool test, std::stringstream& report)
 {
   if(!test)
-    report << name << ": FAILED" << std::endl;
+    report << name << ": FAILED\n";
 
   return test;
 }
@@ -24,11 +24,11 @@ static Glib::ustring create_file_from_buffer(const char* input, guint input_size
   const auto file_uri = Glom::Utils::get_temp_file_uri("glom_import_testdata");
   if(file_uri.empty())
   {
-    std::cerr << G_STRFUNC << ": file_uri was empty." << std::endl;
+    std::cerr << G_STRFUNC << ": file_uri was empty.\n";
     return std::string();
   }
 
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(file_uri);
+  auto file = Gio::File::create_for_uri(file_uri);
 
   gssize result = 0;
  
@@ -85,7 +85,7 @@ bool run_parser_from_buffer(const FuncConnectParserSignals& connect_parser_signa
 
   //Start a mainloop because the parser uses an idle handler.
   //TODO: Stop the parser from doing that.
-  Glib::RefPtr<Glib::MainLoop> mainloop = Glib::MainLoop::create();
+  auto mainloop = Glib::MainLoop::create();
   Glom::CsvParser parser("UTF-8");
 
   parser.signal_encoding_error().connect(sigc::bind(&on_parser_encoding_error, mainloop));
@@ -105,7 +105,7 @@ bool run_parser_from_buffer(const FuncConnectParserSignals& connect_parser_signa
 
   mainloop->run();
 
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(file_uri);
+  auto file = Gio::File::create_for_uri(file_uri);
 
   try
   {
@@ -127,7 +127,7 @@ bool run_parser_on_file(const FuncConnectParserSignals& connect_parser_signals,
 
   //Start a mainloop because the parser uses an idle handler.
   //TODO: Stop the parser from doing that.
-  Glib::RefPtr<Glib::MainLoop> mainloop = Glib::MainLoop::create();
+  auto mainloop = Glib::MainLoop::create();
   Glom::CsvParser parser("UTF-8");
 
   parser.signal_encoding_error().connect(sigc::bind(&on_parser_encoding_error, mainloop));
