@@ -30,7 +30,7 @@
 #include <boost/python.hpp>
 #include <iostream>
 
-static bool get_field_result(const Glom::Document& document,
+static bool get_field_result(const std::shared_ptr<Glom::Document>& document,
   const Glib::RefPtr<Gnome::Gda::Connection>& gda_connection,
   const Glib::ustring& table_name,
   const std::shared_ptr<const Glom::Field>& primary_key_field,
@@ -50,7 +50,7 @@ static bool get_field_result(const Glom::Document& document,
     value = Glom::glom_evaluate_python_function_implementation(
       Glom::Field::get_glom_type_for_gda_type(expected_value_gtype),
       calculation, field_values,
-      &document, table_name,
+      document, table_name,
       primary_key_field, primary_key_value,
       gda_connection,
       error_message);
@@ -62,7 +62,7 @@ static bool get_field_result(const Glom::Document& document,
   }
   catch(const boost::python::error_already_set& ex)
   {
-    std::cerr << G_STRFUNC << ": Exception: boost::python::error_already_set" << std::endl;
+    std::cerr << G_STRFUNC << ": Exception: boost::python::error_already_set\n";
     return false;
   }
 
@@ -95,17 +95,17 @@ static bool get_field_result(const Glom::Document& document,
 static bool test(Glom::Document::HostingMode hosting_mode)
 {
   //Connect to a Glom database
-  Glom::Document document;
+  auto document = std::make_shared<Glom::Document>();
   const bool recreated = 
     test_create_and_selfhost_from_example("example_smallbusiness.glom", document, hosting_mode);
   if(!recreated)
   {
-    std::cerr << G_STRFUNC << ": Recreation failed." << std::endl;
+    std::cerr << G_STRFUNC << ": Recreation failed.\n";
     return false;
   }
 
   auto connection_pool = Glom::ConnectionPool::get_instance();
-  std::shared_ptr<Glom::SharedConnection> connection = connection_pool->connect();
+  auto connection = connection_pool->connect();
   g_assert(connection);
 
   const auto gda_connection = connection->get_gda_connection();
@@ -114,24 +114,24 @@ static bool test(Glom::Document::HostingMode hosting_mode)
 
   //Some python code just to exercise our PyGlomRecord API:
   const Glib::ustring table_name = "products";
-  const std::shared_ptr<const Glom::Field> primary_key_field =
-    document.get_field_primary_key(table_name);
+  const auto primary_key_field =
+    document->get_field_primary_key(table_name);
   if(!primary_key_field)
   {
-    std::cerr << G_STRFUNC << ": Failure: primary_key_field is empty." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: primary_key_field is empty.\n";
     return false;
   }
 
   const Gnome::Gda::Value primary_key_value(2);
 
   const Glom::type_map_fields field_values =
-    Glom::DbUtils::get_record_field_values(&document,
+    Glom::DbUtils::get_record_field_values(document,
       table_name,
       primary_key_field,
       primary_key_value);
   if(field_values.empty())
   {
-    std::cerr << G_STRFUNC << ": field_values was empty: " << std::endl;
+    std::cerr << G_STRFUNC << ": field_values was empty: \n";
     return false;
   }
 
