@@ -21,6 +21,7 @@
 #include "config.h"
 
 #include <libglom/document/document.h>
+#include <libglom/algorithms_utils.h>
 #include <libglom/init.h>
 #include <libglom/db_utils.h>
 #include <giomm/file.h>
@@ -33,9 +34,7 @@
 template<typename T_Container, typename T_Value>
 bool contains(const T_Container& container, const T_Value& name)
 {
-  typename T_Container::const_iterator iter =
-    std::find(container.begin(), container.end(), name);
-  return iter != container.end();
+  return Glom::Utils::find_exists(container, name);
 }
 
 template<typename T_Container>
@@ -44,8 +43,8 @@ typename T_Container::value_type get_titled(const T_Container& container, const
   typedef typename T_Container::value_type type_sharedptr;
   type_sharedptr result;
 
-  typename T_Container::const_iterator iter =
-    std::find_if(container.begin(), container.end(),
+  const auto iter =
+    Glom::Utils::find_if(container,
       [&title] (const typename T_Container::value_type& element)
       {
         return (element && element->get_title_original() == title);
@@ -60,34 +59,29 @@ typename T_Container::value_type get_titled(const T_Container& container, const
 template<typename T_TypeToFind>
 bool contains_item_type(const Glom::Document::type_list_translatables& container)
 {
-  Glom::Document::type_list_translatables::const_iterator iter =
-    std::find_if(container.begin(), container.end(),
-      [] (const Glom::Document::type_list_translatables::value_type& element)
-      {
-        std::shared_ptr<Glom::TranslatableItem> item = element.first;
-        std::shared_ptr<T_TypeToFind> derived = std::dynamic_pointer_cast<T_TypeToFind>(item);
-        if(derived)
-          return true;
-        else
-          return false;
-      }
-    );
-  if(iter != container.end())
-    return true;
-
-  return false;
+  return Glom::Utils::find_if_exists(container,
+    [] (const Glom::Document::type_list_translatables::value_type& element)
+    {
+      auto item = element.first;
+      auto derived = std::dynamic_pointer_cast<T_TypeToFind>(item);
+      if(derived)
+        return true;
+      else
+        return false;
+    }
+  );
 }
 
-static std::shared_ptr<const Glom::LayoutItem_Field> get_field_on_layout(const Glom::Document& document, const Glib::ustring& layout_table_name, const Glib::ustring& table_name, const Glib::ustring& field_name)
+static std::shared_ptr<const Glom::LayoutItem_Field> get_field_on_layout(const std::shared_ptr<Glom::Document>& document, const Glib::ustring& layout_table_name, const Glib::ustring& table_name, const Glib::ustring& field_name)
 {
-  for(const auto& group : document.get_data_layout_groups("details", layout_table_name))
+  for(const auto& group : document->get_data_layout_groups("details", layout_table_name))
   {
     if(!group)
       continue;
     
     for(const auto& layout_item : group->get_items_recursive())
     {
-      const std::shared_ptr<const Glom::LayoutItem_Field> layout_item_field =
+      const auto layout_item_field =
         std::dynamic_pointer_cast<const Glom::LayoutItem_Field>(layout_item);
       if(!layout_item_field)
         continue;
@@ -113,7 +107,7 @@ void check_title(const T_Item& item, const char* title_en, const char* title_de)
   //The get_title_original() and get_title_translation() should not be called 
   //on items that delegate to a child item:
   bool has_own_title = true;
-  std::shared_ptr<const Glom::LayoutItem_Field> field = 
+  auto field = 
     std::dynamic_pointer_cast<const Glom::LayoutItem_Field>(item);
   if(field)
      has_own_title = false;
@@ -177,10 +171,10 @@ int main()
 
 
   // Load the document:
-  Glom::Document document;
-  document.set_file_uri(uri);
+  auto document = std::make_shared<Glom::Document>();
+  document->set_file_uri(uri);
   int failure_code = 0;
-  const auto test = document.load(failure_code);
+  const auto test = document->load(failure_code);
   //std::cout << "Document load result=" << test << std::endl;
 
   if(!test)
@@ -189,26 +183,26 @@ int main()
     return EXIT_FAILURE;
   }
 
-  const auto locales = document.get_translation_available_locales();
+  const auto locales = document->get_translation_available_locales();
   g_assert(locales.size() == 16);
   g_assert(contains(locales, "de"));
 
-  const auto table_names = document.get_table_names();
+  const auto table_names = document->get_table_names();
   g_assert(contains(table_names, "scenes"));
 
-  g_assert( document.get_table_title_original("scenes") == "Scenes" );
-  g_assert( document.get_table_title_singular_original("scenes") == "Scene" );
+  g_assert( document->get_table_title_original("scenes") == "Scenes" );
+  g_assert( document->get_table_title_singular_original("scenes") == "Scene" );
   
-  g_assert( document.get_table_title("scenes", locale_de) == "Szenen" );
-  g_assert( document.get_table_title_singular("scenes", locale_de) == "Szene" );
+  g_assert( document->get_table_title("scenes", locale_de) == "Szenen" );
+  g_assert( document->get_table_title_singular("scenes", locale_de) == "Szene" );
 
   //Check a field:
-  std::shared_ptr<const Glom::Field> field = document.get_field("contacts", "contact_id");
+  auto field = document->get_field("contacts", "contact_id");
   g_assert(field);
   check_title(field, "Contact ID", "Kontaktkennung");
 
   //Check a field and its custom choices:
-  field = document.get_field("scenes", "day_or_night");
+  field = document->get_field("scenes", "day_or_night");
   g_assert(field);
   check_title(field, "Day/Night", "Tag/Nacht");
 
@@ -216,7 +210,7 @@ int main()
   g_assert(formatting.get_has_custom_choices());
   Glom::Formatting::type_list_values values = formatting.get_choices_custom();
   //g_assert(contains(values, "Day"));
-  std::shared_ptr<Glom::ChoiceValue> value = get_titled(values, "Day");
+  auto value = get_titled(values, "Day");
   g_assert(value);
   check_title(value, "Day", "Tag");
   g_assert(value->get_value() == Gnome::Gda::Value("Day"));
@@ -229,12 +223,12 @@ int main()
   g_assert( value->get_title_original() == "Day" );
 
   //Check a relationship:
-  const std::shared_ptr<const Glom::Relationship> relationship = document.get_relationship("characters", "contacts_actor");
+  const auto relationship = document->get_relationship("characters", "contacts_actor");
   g_assert(relationship);
   check_title(relationship, "Actor", "Schauspieler");
 
   //Check a LayoutItemField's CustomTitle:
-  std::shared_ptr<const Glom::LayoutItem_Field> field_on_layout = 
+  auto field_on_layout = 
     get_field_on_layout(document, "characters", "contacts", "name_full");
   g_assert(field_on_layout);
   g_assert(field_on_layout->get_has_relationship_name());
@@ -254,12 +248,12 @@ int main()
   g_assert(field_on_layout->get_formatting_used_has_translatable_choices());
 
   //Check a print layout:
-  const std::shared_ptr<const Glom::PrintLayout> print_layout = document.get_print_layout("contacts", "contact_details");
+  const auto print_layout = document->get_print_layout("contacts", "contact_details");
   g_assert(print_layout);
   check_title(print_layout, "Contact Details", "Kontakt Details" );
 
   //Check the whole list of translatable items:
-  Glom::Document::type_list_translatables list_layout_items = document.get_translatable_items();
+  Glom::Document::type_list_translatables list_layout_items = document->get_translatable_items();
   g_assert(!list_layout_items.empty());
   const bool contains_databasetitle =
     contains_item_type<Glom::DatabaseTitle>(list_layout_items);
