@@ -19,6 +19,8 @@
  */
 
 #include "tests/test_selfhosting_utils.h"
+#include <libglom/algorithms_utils.h>
+#include <libglom/db_utils.h>
 #include <libglom/init.h>
 #include <libglom/utils.h>
 #include <libglom/db_utils.h>
@@ -31,9 +33,7 @@
 template<typename T_Container, typename T_Value>
 bool contains(const T_Container& container, const T_Value& name)
 {
-  typename T_Container::const_iterator iter =
-    std::find(container.begin(), container.end(), name);
-  return iter != container.end();
+  return Glom::Utils::find_exists(container, name);
 }
 
 static bool test(Glom::Document::HostingMode hosting_mode)
@@ -52,19 +52,19 @@ static bool test(Glom::Document::HostingMode hosting_mode)
 
   //Create and self-host the document:
   {
-    Glom::Document document;
+    auto document = std::make_shared<Glom::Document>();
     const bool recreated = 
       test_create_and_selfhost_from_example("example_smallbusiness.glom", document, hosting_mode);
     if(!recreated)
     {
-      std::cerr << G_STRFUNC << ": Recreation failed." << std::endl;
+      std::cerr << G_STRFUNC << ": Recreation failed.\n";
       return false;
     }
 
     temp_file_uri = test_get_temp_file_uri();
     if(temp_file_uri.empty())
     {
-      std::cerr << G_STRFUNC << ": temp_file_uri is empty." << std::endl;
+      std::cerr << G_STRFUNC << ": temp_file_uri is empty.\n";
       return false;
     }
 
@@ -81,13 +81,13 @@ static bool test(Glom::Document::HostingMode hosting_mode)
       Glom::Privs::get_database_groups();
     if(!contains(group_list, operator_group_name))
     {
-      std::cerr << G_STRFUNC << ": The expected group was not found." << std::endl;
+      std::cerr << G_STRFUNC << ": The expected group was not found.\n";
       return false;
     }
 
-    if(!Glom::DbUtils::add_user(&document, operator_user, operator_password, operator_group_name))
+    if(!Glom::DbUtils::add_user(document, operator_user, operator_password, operator_group_name))
     {
-      std::cerr << G_STRFUNC << ": DbUtils::add_user() failed." << std::endl;
+      std::cerr << G_STRFUNC << ": DbUtils::add_user() failed.\n";
       test_selfhosting_cleanup();
       return false;
     }
@@ -97,7 +97,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
       Glom::DbUtils::get_table_names_from_database(true /* ignore system tables */);
     if(tables.empty())
     {
-      std::cerr << G_STRFUNC << ": get_table_names_from_database() failed for developer user." << std::endl;
+      std::cerr << G_STRFUNC << ": get_table_names_from_database() failed for developer user.\n";
       return false;
     }
 
@@ -106,11 +106,11 @@ static bool test(Glom::Document::HostingMode hosting_mode)
   
   //Self-host the document again, this time as operator:
   {
-    Glom::Document document;
-    document.set_allow_autosave(false); //To simplify things and to not depend implicitly on autosave.
-    document.set_file_uri(temp_file_uri);
+    auto document = std::make_shared<Glom::Document>();
+    document->set_allow_autosave(false); //To simplify things and to not depend implicitly on autosave.
+    document->set_file_uri(temp_file_uri);
     int failure_code = 0;
-    const auto test = document.load(failure_code);
+    const auto test = document->load(failure_code);
     //std::cout << "Document load result=" << test << std::endl;
     if(!test)
     {
@@ -120,7 +120,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
 
     if(!test_selfhost(document, operator_user, operator_password))
     {
-      std::cerr << G_STRFUNC << ": test_selfhost() failed." << std::endl;
+      std::cerr << G_STRFUNC << ": test_selfhost() failed.\n";
       return false;
     }
 
@@ -130,13 +130,13 @@ static bool test(Glom::Document::HostingMode hosting_mode)
     const auto field_types = connection_pool->get_field_types();
     if(!field_types)
     {
-      std::cerr << G_STRFUNC << ": get_field_types() returned null." << std::endl;
+      std::cerr << G_STRFUNC << ": get_field_types() returned null.\n";
       return false;
     }
 
     if(field_types->get_types_count() == 0)
     {
-      std::cerr << G_STRFUNC << ": get_field_types() returned no types." << std::endl;
+      std::cerr << G_STRFUNC << ": get_field_types() returned no types.\n";
       return false;
     }
 
@@ -146,13 +146,13 @@ static bool test(Glom::Document::HostingMode hosting_mode)
       Glom::DbUtils::get_table_names_from_database(true /* ignore system tables */);
     if(tables.empty())
     {
-      std::cerr << G_STRFUNC << ": get_table_names_from_database() failed for operator user." << std::endl;
+      std::cerr << G_STRFUNC << ": get_table_names_from_database() failed for operator user.\n";
       return false;
     }
 
     if(Glom::Privs::get_user_is_in_group(connection_pool->get_user(), GLOM_STANDARD_GROUP_NAME_DEVELOPER))
     {
-      std::cerr << G_STRFUNC << ": The operator user is in the developer group, but should not be." << std::endl;
+      std::cerr << G_STRFUNC << ": The operator user is in the developer group, but should not be.\n";
       return false;
     }
 
