@@ -34,28 +34,28 @@
 
 static bool test(Glom::Document::HostingMode hosting_mode)
 {
-  Glom::Document document;
+  auto document = std::make_shared<Glom::Document>();
   const bool recreated = 
     test_create_and_selfhost_from_example("example_smallbusiness.glom", document, hosting_mode);
   if(!recreated)
   {
-    std::cerr << G_STRFUNC << ": Recreation failed." << std::endl;
+    std::cerr << G_STRFUNC << ": Recreation failed.\n";
     return false;
   }
   
   const Glib::ustring table_name = "contacts";
   const Glib::ustring field_name_original = "date_of_birth";
-  std::shared_ptr<const Glom::Field> field_original = document.get_field(table_name, field_name_original);
+  auto field_original = document->get_field(table_name, field_name_original);
   if(!field_original)
   {
-    std::cerr << G_STRFUNC << ": Failure: Could not get field." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: Could not get field.\n";
     return false;
   }
 
-  std::shared_ptr<Glom::Field> field_new = Glom::glom_sharedptr_clone(field_original);
+  auto field_new = Glom::glom_sharedptr_clone(field_original);
   if(!field_new)
   {
-    std::cerr << G_STRFUNC << ": Failure: field_new is null." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: field_new is null.\n";
     return false;
   }
   field_new->set_glom_type(Glom::Field::glom_field_type::TEXT);
@@ -63,7 +63,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
   auto connection_pool = Glom::ConnectionPool::get_instance();
   if(!connection_pool)
   {
-    std::cerr << G_STRFUNC << ": Failure: connection_pool is null." << std::endl;
+    std::cerr << G_STRFUNC << ": Failure: connection_pool is null.\n";
     return false;
   }
 
@@ -75,7 +75,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
     const auto test = connection_pool->change_column(table_name, field_original, field_new);
     if(!test)
     {
-      std::cerr << G_STRFUNC << ": Failure: change_column() failed." << std::endl;
+      std::cerr << G_STRFUNC << ": Failure: change_column() failed.\n";
       return false;
     }
   }
@@ -93,7 +93,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
     const auto test = connection_pool->change_column(table_name, field_original, field_new);
     if(!test)
     {
-      std::cerr << G_STRFUNC << ": Failure: change_column() failed." << std::endl;
+      std::cerr << G_STRFUNC << ": Failure: change_column() failed.\n";
       return false;
     }
   }
@@ -111,7 +111,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
     const auto test = connection_pool->change_column(table_name, field_original, field_new);
     if(!test)
     {
-      std::cerr << G_STRFUNC << ": Failure: change_column() failed." << std::endl;
+      std::cerr << G_STRFUNC << ": Failure: change_column() failed.\n";
       return false;
     }
   }
@@ -129,7 +129,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
     const auto test = connection_pool->change_column(table_name, field_original, field_new);
     if(!test)
     {
-      std::cerr << G_STRFUNC << ": Failure: change_column() failed." << std::endl;
+      std::cerr << G_STRFUNC << ": Failure: change_column() failed.\n";
       return false;
     }
   }
@@ -156,10 +156,10 @@ static bool test(Glom::Document::HostingMode hosting_mode)
   try
   {
     //TODO: Avoid the need for this awkward use of set_g_type():
-    std::shared_ptr<Glom::Field> field_numeric = std::make_shared<Glom::Field>();
+    auto field_numeric = std::make_shared<Glom::Field>();
     field_numeric->set_name("newfield");
     field_numeric->set_glom_type(Glom::Field::glom_field_type::NUMERIC);
-    Glib::RefPtr<Gnome::Gda::Column> field_info = field_numeric->get_field_info();
+    auto field_info = field_numeric->get_field_info();
     field_info->set_g_type( Glom::Field::get_gda_type_for_glom_type(field_numeric->get_glom_type()) );
     field_numeric->set_field_info(field_info);
     
@@ -170,7 +170,7 @@ static bool test(Glom::Document::HostingMode hosting_mode)
     const auto test = connection_pool->add_column(table_name, field_numeric);
     if(!test)
     {
-      std::cerr << G_STRFUNC << ": Failure: add_column() failed." << std::endl;
+      std::cerr << G_STRFUNC << ": Failure: add_column() failed.\n";
       return false;
     }
   }
