@@ -28,36 +28,36 @@
 
 static bool test(Glom::Document::HostingMode hosting_mode)
 {
-  Glom::Document document;
+  auto document = std::make_shared<Glom::Document>();
   const bool recreated = 
     test_create_and_selfhost_from_example("example_music_collection.glom", document, hosting_mode);
   if(!recreated)
   {
-    std::cerr << G_STRFUNC << ": Recreation failed." << std::endl;
+    std::cerr << G_STRFUNC << ": Recreation failed.\n";
     return false;
   }
 
-  const std::shared_ptr<const Glom::Report> report_temp = 
-    Glom::ReportBuilder::create_standard_list_report(&document, "albums");
+  const auto report_temp = 
+    Glom::ReportBuilder::create_standard_list_report(document, "albums");
 
   Glom::FoundSet found_set; //TODO: Test a where clause.
   found_set.m_table_name = "albums";
 
   const std::locale locale("en_US.UTF-8"); //Instead of just "" (current locale) so we get the same results each time.
   Glom::ReportBuilder report_builder(locale);
-  report_builder.set_document(&document);
+  report_builder.set_document(document);
   const Glib::ustring html = 
     report_builder.report_build(found_set, report_temp);
 
   if(html.empty())
   {
-    std::cerr << G_STRFUNC << ": Failed: html was empty." << std::endl;
+    std::cerr << G_STRFUNC << ": Failed: html was empty.\n";
     return false;
   }
 
   if(html.find("Bruce Springsteen") == std::string::npos)
   {
-    std::cerr << G_STRFUNC << ": Failed: html did not contain the expected text." << std::endl;
+    std::cerr << G_STRFUNC << ": Failed: html did not contain the expected text.\n";
     return false;
   }
 
