@@ -23,16 +23,16 @@
 #include <glibmm/fileutils.h>
 #include <iostream>
 
-std::shared_ptr<const Glom::LayoutItem_Field> get_field_on_layout(const Glom::Document& document, const Glib::ustring& layout_table_name, const Glib::ustring& table_name, const Glib::ustring& field_name)
+std::shared_ptr<const Glom::LayoutItem_Field> get_field_on_layout(const std::shared_ptr<Glom::Document>& document, const Glib::ustring& layout_table_name, const Glib::ustring& table_name, const Glib::ustring& field_name)
 {
-  for(const auto& group : document.get_data_layout_groups("details", layout_table_name))
+  for(const auto& group : document->get_data_layout_groups("details", layout_table_name))
   {
     if(!group)
       continue;
     
     for(const auto& layout_item : group->get_items_recursive())
     {
-      const std::shared_ptr<const Glom::LayoutItem_Field> layout_item_field =
+      const auto layout_item_field =
         std::dynamic_pointer_cast<const Glom::LayoutItem_Field>(layout_item);
       if(!layout_item_field)
         continue;
@@ -48,11 +48,9 @@ std::shared_ptr<const Glom::LayoutItem_Field> get_field_on_layout(const Glom::Do
   return std::shared_ptr<const Glom::LayoutItem_Field>();
 }
 
-Gnome::Gda::Value get_value_for_image()
+
+Gnome::Gda::Value get_value_for_image_from_file(const std::string& filename)
 {
-  //Fill a value from a file:
-  const std::string filename =
-    Glib::build_filename(GLOM_TESTS_IMAGE_DATA_NOTINSTALLED, "test_image.jpg");
   std::string data;
   try
   {
@@ -73,3 +71,11 @@ Gnome::Gda::Value get_value_for_image()
   //Set the value:
   return Gnome::Gda::Value((const guchar*)data.c_str(), data.size());
 }
+
+Gnome::Gda::Value get_value_for_image()
+{
+  //Fill a value from a file:
+  const std::string filename =
+    Glib::build_filename(GLOM_TESTS_IMAGE_DATA_NOTINSTALLED, "test_image.jpg");
+  return get_value_for_image_from_file(filename);
+}
